/****************************************************************************
** Meta object code from reading C++ file 'screensaver_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-wallpapersetting/dbus/screensaver_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screensaver_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ComDeepinScreenSaverInterface::qt_create_metaobjectdata<qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComDeepinScreenSaverInterface",
        "ConfigurableItems",
        "QDBusPendingReply<QStringList>",
        "",
        "GetScreenSaverCover",
        "QDBusPendingReply<QString>",
        "name",
        "IsConfigurable",
        "QDBusPendingReply<bool>",
        "Preview",
        "staysOn",
        "RefreshScreenSaverList",
        "QDBusPendingReply<>",
        "Start",
        "StartCustomConfig",
        "Stop",
        "allScreenSaver",
        "batteryScreenSaverTimeout",
        "currentScreenSaver",
        "isRunning",
        "linePowerScreenSaverTimeout",
        "lockScreenAtAwake",
        "lockScreenDelay"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'ConfigurableItems'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'GetScreenSaverCover'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(4, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'IsConfigurable'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(7, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'Preview'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, int)>(9, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 6 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'RefreshScreenSaverList'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(11, 3, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'Start'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 3, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'StartCustomConfig'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(14, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'Stop'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 3, QMC::AccessPublic, 0x80000000 | 12),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'allScreenSaver'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'batteryScreenSaverTimeout'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'currentScreenSaver'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isRunning'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'linePowerScreenSaverTimeout'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lockScreenAtAwake'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'lockScreenDelay'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComDeepinScreenSaverInterface, qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ComDeepinScreenSaverInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>.metaTypes,
    nullptr
} };

void ComDeepinScreenSaverInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComDeepinScreenSaverInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QStringList> _r = _t->ConfigurableItems();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<QString> _r = _t->GetScreenSaverCover((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<bool> _r = _t->IsConfigurable((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<bool> _r = _t->Preview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->RefreshScreenSaverList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->Start();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->StartCustomConfig((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->Stop();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->allScreenSaver(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->batteryScreenSaverTimeout(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->currentScreenSaver(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isRunning(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->linePowerScreenSaverTimeout(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->lockScreenAtAwake(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->lockScreenDelay(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setBatteryScreenSaverTimeout(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setCurrentScreenSaver(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setLinePowerScreenSaverTimeout(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setLockScreenAtAwake(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setLockScreenDelay(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ComDeepinScreenSaverInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComDeepinScreenSaverInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ComDeepinScreenSaverInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ComDeepinScreenSaverInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
