/****************************************************************************
** Meta object code from reading C++ file 'renamebar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/views/renamebar.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'renamebar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::RenameBar::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::RenameBar",
        "requestReplaceOperator",
        "",
        "clickCancelButton",
        "clickRenameButton",
        "visibleChanged",
        "value",
        "setVisible",
        "visible",
        "onVisibleChanged",
        "onRenamePatternChanged",
        "index",
        "onReplaceOperatorFileNameChanged",
        "text",
        "onReplaceOperatorDestNameChanged",
        "textChanged",
        "onAddOperatorAddedContentChanged",
        "onAddTextPatternChanged",
        "onCustomOperatorFileNameChanged",
        "onCustomOperatorSNNumberChanged",
        "eventDispatcher",
        "hideRenameBar",
        "onSelectUrlChanged",
        "QList<QUrl>",
        "urls"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestReplaceOperator'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickCancelButton'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clickRenameButton'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'setVisible'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'onVisibleChanged'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'onRenamePatternChanged'
        QtMocHelpers::SlotData<void(const int &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'onReplaceOperatorFileNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'onReplaceOperatorDestNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onAddOperatorAddedContentChanged'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'onAddTextPatternChanged'
        QtMocHelpers::SlotData<void(const int &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'onCustomOperatorFileNameChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCustomOperatorSNNumberChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'eventDispatcher'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hideRenameBar'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onSelectUrlChanged'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenameBar, qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::RenameBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::RenameBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenameBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestReplaceOperator(); break;
        case 1: _t->clickCancelButton(); break;
        case 2: _t->clickRenameButton(); break;
        case 3: _t->visibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->onVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->onRenamePatternChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->onReplaceOperatorFileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->onReplaceOperatorDestNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->onAddOperatorAddedContentChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->onAddTextPatternChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->onCustomOperatorFileNameChanged(); break;
        case 12: _t->onCustomOperatorSNNumberChanged(); break;
        case 13: _t->eventDispatcher(); break;
        case 14: _t->hideRenameBar(); break;
        case 15: _t->onSelectUrlChanged((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RenameBar::*)()>(_a, &RenameBar::requestReplaceOperator, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenameBar::*)()>(_a, &RenameBar::clickCancelButton, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenameBar::*)()>(_a, &RenameBar::clickRenameButton, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenameBar::*)(bool )>(_a, &RenameBar::visibleChanged, 3))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::RenameBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::RenameBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace9RenameBarE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dfmplugin_workspace::RenameBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::RenameBar::requestReplaceOperator()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmplugin_workspace::RenameBar::clickCancelButton()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_workspace::RenameBar::clickRenameButton()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dfmplugin_workspace::RenameBar::visibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
