/****************************************************************************
** Meta object code from reading C++ file 'filesortworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/utils/filesortworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filesortworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::FileSortWorker::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::FileSortWorker",
        "insertRows",
        "",
        "first",
        "count",
        "insertFinish",
        "removeRows",
        "removeFinish",
        "requestFetchMore",
        "selectAndEditFile",
        "QUrl",
        "url",
        "dataChanged",
        "last",
        "requestSetIdel",
        "visiableCount",
        "totalCount",
        "updateRow",
        "row",
        "getSourceData",
        "key",
        "requestUpdateView",
        "requestCursorWait",
        "reqUestCloseCursor",
        "requestUpdateTimerStart",
        "requestSortByMimeType",
        "handleIteratorLocalChildren",
        "QList<SortInfoPointer>",
        "children",
        "dfmio::DEnumerator::SortRoleCompareFlag",
        "sortRole",
        "Qt::SortOrder",
        "sortOrder",
        "isMixDirAndFile",
        "handleSourceChildren",
        "isFinished",
        "handleIteratorChildren",
        "QList<FileInfoPointer>",
        "infos",
        "handleTraversalFinish",
        "handleSortDir",
        "parent",
        "handleModelGetSourceData",
        "handleFilters",
        "QDir::Filters",
        "filters",
        "HandleNameFilters",
        "handleFilterData",
        "QVariant",
        "data",
        "handleFilterCallFunc",
        "FileViewFilterCallback",
        "callback",
        "onToggleHiddenFiles",
        "onShowHiddenFileChanged",
        "isShow",
        "handleWatcherAddChildren",
        "handleWatcherRemoveChildren",
        "handleWatcherUpdateFile",
        "SortInfoPointer",
        "child",
        "handleWatcherUpdateFiles",
        "handleWatcherUpdateHideFile",
        "hidUrl",
        "handleResort",
        "order",
        "Global::ItemRoles",
        "onAppAttributeChanged",
        "Application::ApplicationAttribute",
        "aa",
        "value",
        "handleUpdateFile",
        "handleUpdateFiles",
        "QList<QUrl>",
        "urls",
        "handleRefresh",
        "handleClearThumbnail",
        "handleFileInfoUpdated",
        "infoPtr",
        "isLinkOrg",
        "handleUpdateRefreshFiles",
        "handleSortByMimeType",
        "handleCloseExpand",
        "handleSwitchTreeView",
        "isTree"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'insertRows'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'insertFinish'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeRows'
        QtMocHelpers::SignalData<void(int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'removeFinish'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestFetchMore'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAndEditFile'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(int, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 13 },
        }}),
        // Signal 'requestSetIdel'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'updateRow'
        QtMocHelpers::SignalData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Signal 'getSourceData'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'requestUpdateView'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestCursorWait'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqUestCloseCursor'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateTimerStart'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSortByMimeType'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleIteratorLocalChildren'
        QtMocHelpers::SlotData<void(const QString &, const QList<SortInfoPointer>, const dfmio::DEnumerator::SortRoleCompareFlag, const Qt::SortOrder, const bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 27, 28 }, { 0x80000000 | 29, 30 }, { 0x80000000 | 31, 32 },
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'handleSourceChildren'
        QtMocHelpers::SlotData<void(const QString &, const QList<SortInfoPointer>, const dfmio::DEnumerator::SortRoleCompareFlag, const Qt::SortOrder, const bool, const bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 27, 28 }, { 0x80000000 | 29, 30 }, { 0x80000000 | 31, 32 },
            { QMetaType::Bool, 33 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'handleIteratorChildren'
        QtMocHelpers::SlotData<void(const QString &, const QList<SortInfoPointer>, const QList<FileInfoPointer>)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 27, 28 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'handleTraversalFinish'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'handleSortDir'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 10, 41 },
        }}),
        // Slot 'handleModelGetSourceData'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleFilters'
        QtMocHelpers::SlotData<void(QDir::Filters)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'HandleNameFilters'
        QtMocHelpers::SlotData<void(const QStringList &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 45 },
        }}),
        // Slot 'handleFilterData'
        QtMocHelpers::SlotData<void(const QVariant &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'handleFilterCallFunc'
        QtMocHelpers::SlotData<void(FileViewFilterCallback)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'onToggleHiddenFiles'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onShowHiddenFileChanged'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 55 },
        }}),
        // Slot 'handleWatcherAddChildren'
        QtMocHelpers::SlotData<void(const QList<SortInfoPointer> &)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'handleWatcherRemoveChildren'
        QtMocHelpers::SlotData<void(const QList<SortInfoPointer> &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'handleWatcherUpdateFile'
        QtMocHelpers::SlotData<bool(const SortInfoPointer)>(58, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'handleWatcherUpdateFiles'
        QtMocHelpers::SlotData<void(const QList<SortInfoPointer> &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'handleWatcherUpdateHideFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 63 },
        }}),
        // Slot 'handleResort'
        QtMocHelpers::SlotData<void(const Qt::SortOrder, const Global::ItemRoles, const bool)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 65 }, { 0x80000000 | 66, 30 }, { QMetaType::Bool, 33 },
        }}),
        // Slot 'onAppAttributeChanged'
        QtMocHelpers::SlotData<void(Application::ApplicationAttribute, const QVariant &)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 68, 69 }, { 0x80000000 | 48, 70 },
        }}),
        // Slot 'handleUpdateFile'
        QtMocHelpers::SlotData<bool(const QUrl &)>(71, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleUpdateFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 73, 74 },
        }}),
        // Slot 'handleRefresh'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleClearThumbnail'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleFileInfoUpdated'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const bool)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::QString, 78 }, { QMetaType::Bool, 79 },
        }}),
        // Slot 'handleUpdateRefreshFiles'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleSortByMimeType'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleCloseExpand'
        QtMocHelpers::SlotData<void(const QString &, const QUrl &)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 10, 41 },
        }}),
        // Slot 'handleSwitchTreeView'
        QtMocHelpers::SlotData<void(const bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileSortWorker, qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::FileSortWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::FileSortWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileSortWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->insertRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->insertFinish(); break;
        case 2: _t->removeRows((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->removeFinish(); break;
        case 4: _t->requestFetchMore(); break;
        case 5: _t->selectAndEditFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->requestSetIdel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->updateRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->getSourceData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->requestUpdateView(); break;
        case 11: _t->requestCursorWait(); break;
        case 12: _t->reqUestCloseCursor(); break;
        case 13: _t->requestUpdateTimerStart(); break;
        case 14: _t->requestSortByMimeType(); break;
        case 15: _t->handleIteratorLocalChildren((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 16: _t->handleSourceChildren((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 17: _t->handleIteratorChildren((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<FileInfoPointer>>>(_a[3]))); break;
        case 18: _t->handleTraversalFinish((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->handleSortDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 20: _t->handleModelGetSourceData(); break;
        case 21: _t->handleFilters((*reinterpret_cast<std::add_pointer_t<QDir::Filters>>(_a[1]))); break;
        case 22: _t->HandleNameFilters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 23: _t->handleFilterData((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 24: _t->handleFilterCallFunc((*reinterpret_cast<std::add_pointer_t<FileViewFilterCallback>>(_a[1]))); break;
        case 25: _t->onToggleHiddenFiles(); break;
        case 26: _t->onShowHiddenFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->handleWatcherAddChildren((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 28: _t->handleWatcherRemoveChildren((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 29: { bool _r = _t->handleWatcherUpdateFile((*reinterpret_cast<std::add_pointer_t<SortInfoPointer>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->handleWatcherUpdateFiles((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 31: _t->handleWatcherUpdateHideFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 32: _t->handleResort((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Global::ItemRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 33: _t->onAppAttributeChanged((*reinterpret_cast<std::add_pointer_t<Application::ApplicationAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 34: { bool _r = _t->handleUpdateFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->handleUpdateFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 36: _t->handleRefresh(); break;
        case 37: _t->handleClearThumbnail(); break;
        case 38: _t->handleFileInfoUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 39: _t->handleUpdateRefreshFiles(); break;
        case 40: _t->handleSortByMimeType(); break;
        case 41: _t->handleCloseExpand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 42: _t->handleSwitchTreeView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<FileInfoPointer> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDir::Filters >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SortInfoPointer >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(int , int )>(_a, &FileSortWorker::insertRows, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::insertFinish, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(int , int )>(_a, &FileSortWorker::removeRows, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::removeFinish, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::requestFetchMore, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(const QUrl & )>(_a, &FileSortWorker::selectAndEditFile, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(int , int )>(_a, &FileSortWorker::dataChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(int , int )>(_a, &FileSortWorker::requestSetIdel, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(int )>(_a, &FileSortWorker::updateRow, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)(const QString & )>(_a, &FileSortWorker::getSourceData, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::requestUpdateView, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::requestCursorWait, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::reqUestCloseCursor, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::requestUpdateTimerStart, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileSortWorker::*)()>(_a, &FileSortWorker::requestSortByMimeType, 14))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::FileSortWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::FileSortWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace14FileSortWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_workspace::FileSortWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::FileSortWorker::insertRows(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmplugin_workspace::FileSortWorker::insertFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_workspace::FileSortWorker::removeRows(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmplugin_workspace::FileSortWorker::removeFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dfmplugin_workspace::FileSortWorker::requestFetchMore()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dfmplugin_workspace::FileSortWorker::selectAndEditFile(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmplugin_workspace::FileSortWorker::dataChanged(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dfmplugin_workspace::FileSortWorker::requestSetIdel(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void dfmplugin_workspace::FileSortWorker::updateRow(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dfmplugin_workspace::FileSortWorker::getSourceData(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dfmplugin_workspace::FileSortWorker::requestUpdateView()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dfmplugin_workspace::FileSortWorker::requestCursorWait()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dfmplugin_workspace::FileSortWorker::reqUestCloseCursor()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void dfmplugin_workspace::FileSortWorker::requestUpdateTimerStart()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dfmplugin_workspace::FileSortWorker::requestSortByMimeType()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
