/****************************************************************************
** Meta object code from reading C++ file 'filedialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filedialog/core/views/filedialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15filedialog_core10FileDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto filedialog_core::FileDialog::qt_create_metaobjectdata<qt_meta_tag_ZN15filedialog_core10FileDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "filedialog_core::FileDialog",
        "finished",
        "",
        "result",
        "accepted",
        "rejected",
        "selectionFilesChanged",
        "selectedNameFilterChanged",
        "initialized",
        "accept",
        "done",
        "r",
        "exec",
        "open",
        "reject",
        "onAcceptButtonClicked",
        "onRejectButtonClicked",
        "onCurrentInputNameChanged",
        "updateAcceptButtonState",
        "handleEnterPressed",
        "handleUrlChanged",
        "QUrl",
        "url",
        "onViewSelectionChanged",
        "windowID",
        "QItemSelection",
        "selected",
        "deselected",
        "onViewItemClicked",
        "QVariantMap",
        "data",
        "handleRenameStartAcceptBtn",
        "handleRenameEndAcceptBtn"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'accepted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rejected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionFilesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedNameFilterChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialized'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'done'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'exec'
        QtMocHelpers::SlotData<int()>(12, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'open'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAcceptButtonClicked'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRejectButtonClicked'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onCurrentInputNameChanged'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateAcceptButtonState'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleEnterPressed'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'onViewSelectionChanged'
        QtMocHelpers::SlotData<void(const quint64, const QItemSelection &, const QItemSelection &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 25, 27 },
        }}),
        // Slot 'onViewItemClicked'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'handleRenameStartAcceptBtn'
        QtMocHelpers::SlotData<void(const quint64, const QUrl &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'handleRenameEndAcceptBtn'
        QtMocHelpers::SlotData<void(const quint64, const QUrl &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 }, { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileDialog, qt_meta_tag_ZN15filedialog_core10FileDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject filedialog_core::FileDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<dfmbase::FileManagerWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15filedialog_core10FileDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15filedialog_core10FileDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15filedialog_core10FileDialogE_t>.metaTypes,
    nullptr
} };

void filedialog_core::FileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->accepted(); break;
        case 2: _t->rejected(); break;
        case 3: _t->selectionFilesChanged(); break;
        case 4: _t->selectedNameFilterChanged(); break;
        case 5: _t->initialized(); break;
        case 6: _t->accept(); break;
        case 7: _t->done((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->open(); break;
        case 10: _t->reject(); break;
        case 11: _t->onAcceptButtonClicked(); break;
        case 12: _t->onRejectButtonClicked(); break;
        case 13: _t->onCurrentInputNameChanged(); break;
        case 14: _t->updateAcceptButtonState(); break;
        case 15: _t->handleEnterPressed(); break;
        case 16: _t->handleUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->onViewSelectionChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[3]))); break;
        case 18: _t->onViewItemClicked((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 19: _t->handleRenameStartAcceptBtn((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 20: _t->handleRenameEndAcceptBtn((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)(int )>(_a, &FileDialog::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)()>(_a, &FileDialog::accepted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)()>(_a, &FileDialog::rejected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)()>(_a, &FileDialog::selectionFilesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)()>(_a, &FileDialog::selectedNameFilterChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialog::*)()>(_a, &FileDialog::initialized, 5))
            return;
    }
}

const QMetaObject *filedialog_core::FileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *filedialog_core::FileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15filedialog_core10FileDialogE_t>.strings))
        return static_cast<void*>(this);
    return dfmbase::FileManagerWindow::qt_metacast(_clname);
}

int filedialog_core::FileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dfmbase::FileManagerWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void filedialog_core::FileDialog::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void filedialog_core::FileDialog::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void filedialog_core::FileDialog::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void filedialog_core::FileDialog::selectionFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void filedialog_core::FileDialog::selectedNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void filedialog_core::FileDialog::initialized()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
