/****************************************************************************
** Meta object code from reading C++ file 'appearance_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-background/appearance_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appearance_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_background::Appearance_Interface::qt_create_metaobjectdata<qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_background::Appearance_Interface",
        "Changed",
        "",
        "ty",
        "value",
        "Refreshed",
        "type",
        "Delete",
        "QDBusPendingReply<>",
        "name",
        "GetCurrentWorkspaceBackground",
        "QDBusPendingReply<QString>",
        "GetCurrentWorkspaceBackgroundForMonitor",
        "strMonitorName",
        "GetScaleFactor",
        "QDBusPendingReply<double>",
        "GetScreenScaleFactors",
        "QDBusPendingReply<ScaleFactors>",
        "GetWallpaperSlideShow",
        "monitorName",
        "GetWorkspaceBackgroundForMonitor",
        "index",
        "List",
        "Reset",
        "Set",
        "SetCurrentWorkspaceBackground",
        "uri",
        "SetCurrentWorkspaceBackgroundForMonitor",
        "SetMonitorBackground",
        "imageGile",
        "SetScaleFactor",
        "scale",
        "SetScreenScaleFactors",
        "ScaleFactors",
        "scaleFactor",
        "SetWallpaperSlideShow",
        "slideShow",
        "SetWorkspaceBackgroundForMonitor",
        "Show",
        "names",
        "Thumbnail",
        "Background",
        "CursorTheme",
        "FontSize",
        "GlobalTheme",
        "GtkTheme",
        "IconTheme",
        "MonospaceFont",
        "Opacity",
        "QtActiveColor",
        "StandardFont",
        "WallpaperSlideShow",
        "WallpaperURls",
        "WindowRadius"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'Changed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'Refreshed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(7, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'GetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'GetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'GetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<double>()>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'GetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<ScaleFactors>()>(16, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'GetWallpaperSlideShow'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'GetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(int, const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'List'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Slot 'Set'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'SetCurrentWorkspaceBackground'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'SetCurrentWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 26 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'SetMonitorBackground'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'SetScaleFactor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(double)>(30, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::Double, 31 },
        }}),
        // Slot 'SetScreenScaleFactors'
        QtMocHelpers::SlotData<QDBusPendingReply<>(ScaleFactors)>(32, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'SetWallpaperSlideShow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'SetWorkspaceBackgroundForMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &, const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 13 }, { QMetaType::QString, 26 },
        }}),
        // Slot 'Show'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QStringList &)>(38, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::QStringList, 39 },
        }}),
        // Slot 'Thumbnail'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &, const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Background'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'CursorTheme'
        QtMocHelpers::PropertyData<QString>(42, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'FontSize'
        QtMocHelpers::PropertyData<double>(43, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'GlobalTheme'
        QtMocHelpers::PropertyData<QString>(44, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'GtkTheme'
        QtMocHelpers::PropertyData<QString>(45, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IconTheme'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MonospaceFont'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Opacity'
        QtMocHelpers::PropertyData<double>(48, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'QtActiveColor'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'StandardFont'
        QtMocHelpers::PropertyData<QString>(50, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WallpaperSlideShow'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WallpaperURls'
        QtMocHelpers::PropertyData<QString>(52, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'WindowRadius'
        QtMocHelpers::PropertyData<int>(53, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Appearance_Interface, qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_background::Appearance_Interface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>.metaTypes,
    nullptr
} };

void ddplugin_background::Appearance_Interface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Appearance_Interface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Changed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->Refreshed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: { QDBusPendingReply<> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->GetCurrentWorkspaceBackground();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QString> _r = _t->GetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<double> _r = _t->GetScaleFactor();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<double>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<ScaleFactors> _r = _t->GetScreenScaleFactors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ScaleFactors>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QString> _r = _t->GetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QString> _r = _t->GetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QString> _r = _t->List((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->Set((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->SetCurrentWorkspaceBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->SetCurrentWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<> _r = _t->SetMonitorBackground((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->SetScaleFactor((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->SetScreenScaleFactors((*reinterpret_cast<std::add_pointer_t<ScaleFactors>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->SetWallpaperSlideShow((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->SetWorkspaceBackgroundForMonitor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QString> _r = _t->Show((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QString> _r = _t->Thumbnail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Appearance_Interface::*)(const QString & , const QString & )>(_a, &Appearance_Interface::Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Appearance_Interface::*)(const QString & )>(_a, &Appearance_Interface::Refreshed, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->background(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->cursorTheme(); break;
        case 2: *reinterpret_cast<double*>(_v) = _t->fontSize(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->globalTheme(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->gtkTheme(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->iconTheme(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->monospaceFont(); break;
        case 7: *reinterpret_cast<double*>(_v) = _t->opacity(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->qtActiveColor(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->standardFont(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->wallpaperSlideShow(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->wallpaperURls(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->windowRadius(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setFontSize(*reinterpret_cast<double*>(_v)); break;
        case 7: _t->setOpacity(*reinterpret_cast<double*>(_v)); break;
        case 8: _t->setQtActiveColor(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setWallpaperSlideShow(*reinterpret_cast<QString*>(_v)); break;
        case 12: _t->setWindowRadius(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ddplugin_background::Appearance_Interface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_background::Appearance_Interface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ddplugin_background20Appearance_InterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ddplugin_background::Appearance_Interface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_background::Appearance_Interface::Changed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ddplugin_background::Appearance_Interface::Refreshed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
