/****************************************************************************
** Meta object code from reading C++ file 'vaulthelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-vault/utils/vaulthelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaulthelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_vault::VaultHelper::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_vault::VaultHelper",
        "sigCreateVault",
        "",
        "state",
        "sigUnlocked",
        "sigLocked",
        "sigCloseWindow",
        "slotlockVault",
        "createVault",
        "QString&",
        "password",
        "unlockVault",
        "lockVault",
        "isForced",
        "defaultCdAction",
        "windowId",
        "QUrl",
        "url",
        "openNewWindow",
        "createVaultDialog",
        "unlockVaultDialog",
        "showRemoveVaultDialog",
        "openWindow",
        "openWidWindow",
        "winID",
        "newOpenWindow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigCreateVault'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sigUnlocked'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sigLocked'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sigCloseWindow'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotlockVault'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'createVault'
        QtMocHelpers::SlotData<void(QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'unlockVault'
        QtMocHelpers::SlotData<bool(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'lockVault'
        QtMocHelpers::SlotData<bool(bool)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'defaultCdAction'
        QtMocHelpers::SlotData<void(const quint64, const QUrl &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'openNewWindow'
        QtMocHelpers::SlotData<void(const QUrl &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'createVaultDialog'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'unlockVaultDialog'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showRemoveVaultDialog'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openWindow'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openWidWindow'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'newOpenWindow'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VaultHelper, qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_vault::VaultHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>.metaTypes,
    nullptr
} };

void dfmplugin_vault::VaultHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigCreateVault((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->sigUnlocked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sigLocked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->sigCloseWindow(); break;
        case 4: _t->slotlockVault((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->createVault((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1]))); break;
        case 6: { bool _r = _t->unlockVault((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->lockVault((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->defaultCdAction((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 9: _t->openNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->createVaultDialog(); break;
        case 11: _t->unlockVaultDialog(); break;
        case 12: _t->showRemoveVaultDialog(); break;
        case 13: _t->openWindow(); break;
        case 14: _t->openWidWindow((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 15: _t->newOpenWindow(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VaultHelper::*)(int )>(_a, &VaultHelper::sigCreateVault, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VaultHelper::*)(int )>(_a, &VaultHelper::sigUnlocked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VaultHelper::*)(int )>(_a, &VaultHelper::sigLocked, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VaultHelper::*)()>(_a, &VaultHelper::sigCloseWindow, 3))
            return;
    }
}

const QMetaObject *dfmplugin_vault::VaultHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::VaultHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault11VaultHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_vault::VaultHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_vault::VaultHelper::sigCreateVault(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_vault::VaultHelper::sigUnlocked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_vault::VaultHelper::sigLocked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmplugin_vault::VaultHelper::sigCloseWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
