/****************************************************************************
** Meta object code from reading C++ file 'operationsstackmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "operationsstackmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'operationsstackmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto OperationsStackManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OperationsStackManagerAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.OperationsStackManager",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.Daemon.OperationsStackM"
        "anager\">\n    <method name=\"SaveOperations\">\n      <arg direct"
        "ion=\"in\" type=\"a{sv}\" name=\"values\"/>\n      <annotation val"
        "ue=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
        "    </method>\n    <method name=\"CleanOperations\"/>\n    <method"
        " name=\"RevocationOperations\">\n      <arg direction=\"out\" type"
        "=\"a{sv}\"/>\n      <annotation value=\"QVariantMap\" name=\"org.q"
        "tproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method na"
        "me=\"SaveRedoOperations\">\n      <arg direction=\"in\" type=\"a{s"
        "v}\" name=\"values\"/>\n      <annotation value=\"QVariantMap\" na"
        "me=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <"
        "method name=\"RevocationRedoOperations\">\n      <arg direction=\""
        "out\" type=\"a{sv}\"/>\n      <annotation value=\"QVariantMap\" na"
        "me=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    "
        "<method name=\"CleanOperationsByUrl\">\n      <arg direction=\"in\""
        " type=\"as\" name=\"urls\"/>\n    </method>\n  </interface>\n",
        "CleanOperations",
        "",
        "CleanOperationsByUrl",
        "urls",
        "RevocationOperations",
        "QVariantMap",
        "RevocationRedoOperations",
        "SaveOperations",
        "values",
        "SaveRedoOperations"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CleanOperations'
        QtMocHelpers::SlotData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'CleanOperationsByUrl'
        QtMocHelpers::SlotData<void(const QStringList &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 },
        }}),
        // Slot 'RevocationOperations'
        QtMocHelpers::SlotData<QVariantMap()>(9, 6, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'RevocationRedoOperations'
        QtMocHelpers::SlotData<QVariantMap()>(11, 6, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'SaveOperations'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 13 },
        }}),
        // Slot 'SaveRedoOperations'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<OperationsStackManagerAdaptor, qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject OperationsStackManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void OperationsStackManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OperationsStackManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CleanOperations(); break;
        case 1: _t->CleanOperationsByUrl((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: { QVariantMap _r = _t->RevocationOperations();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantMap _r = _t->RevocationRedoOperations();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->SaveOperations((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 5: _t->SaveRedoOperations((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *OperationsStackManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OperationsStackManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29OperationsStackManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int OperationsStackManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
