/****************************************************************************
** Meta object code from reading C++ file 'deviceproxymanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/base/device/deviceproxymanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'deviceproxymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::DeviceProxyManager::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::DeviceProxyManager",
        "devSizeChanged",
        "",
        "id",
        "total",
        "avai",
        "blockDevPropertyChanged",
        "property",
        "QVariant",
        "val",
        "blockDriveAdded",
        "blockDriveRemoved",
        "blockDevAdded",
        "blockDevRemoved",
        "oldMpt",
        "blockDevMounted",
        "mpt",
        "blockDevUnmounted",
        "blockDevLocked",
        "blockDevUnlocked",
        "cleartextId",
        "blockDevFsAdded",
        "blockDevFsRemoved",
        "protocolDevAdded",
        "protocolDevRemoved",
        "protocolDevMounted",
        "protocolDevUnmounted",
        "devMngDBusRegistered",
        "devMngDBusUnregistered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'devSizeChanged'
        QtMocHelpers::SignalData<void(const QString &, qint64, qint64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::LongLong, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'blockDevPropertyChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QVariant &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'blockDriveAdded'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockDriveRemoved'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockDevAdded'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'blockDevRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'blockDevMounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'blockDevUnmounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'blockDevLocked'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'blockDevUnlocked'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'blockDevFsAdded'
        QtMocHelpers::SignalData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'blockDevFsRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'protocolDevAdded'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'protocolDevRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'protocolDevMounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'protocolDevUnmounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'devMngDBusRegistered'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'devMngDBusUnregistered'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeviceProxyManager, qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::DeviceProxyManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>.metaTypes,
    nullptr
} };

void dfmbase::DeviceProxyManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceProxyManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->devSizeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 1: _t->blockDevPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 2: _t->blockDriveAdded(); break;
        case 3: _t->blockDriveRemoved(); break;
        case 4: _t->blockDevAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->blockDevRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->blockDevMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->blockDevUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->blockDevLocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->blockDevUnlocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->blockDevFsAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->blockDevFsRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->protocolDevAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->protocolDevRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->protocolDevMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->protocolDevUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->devMngDBusRegistered(); break;
        case 17: _t->devMngDBusUnregistered(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , qint64 , qint64 )>(_a, &DeviceProxyManager::devSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & , const QVariant & )>(_a, &DeviceProxyManager::blockDevPropertyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)()>(_a, &DeviceProxyManager::blockDriveAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)()>(_a, &DeviceProxyManager::blockDriveRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & )>(_a, &DeviceProxyManager::blockDevAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::blockDevRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::blockDevMounted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::blockDevUnmounted, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & )>(_a, &DeviceProxyManager::blockDevLocked, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::blockDevUnlocked, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & )>(_a, &DeviceProxyManager::blockDevFsAdded, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & )>(_a, &DeviceProxyManager::blockDevFsRemoved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & )>(_a, &DeviceProxyManager::protocolDevAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::protocolDevRemoved, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::protocolDevMounted, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)(const QString & , const QString & )>(_a, &DeviceProxyManager::protocolDevUnmounted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)()>(_a, &DeviceProxyManager::devMngDBusRegistered, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceProxyManager::*)()>(_a, &DeviceProxyManager::devMngDBusUnregistered, 17))
            return;
    }
}

const QMetaObject *dfmbase::DeviceProxyManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::DeviceProxyManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18DeviceProxyManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::DeviceProxyManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::DeviceProxyManager::devSizeChanged(const QString & _t1, qint64 _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void dfmbase::DeviceProxyManager::blockDevPropertyChanged(const QString & _t1, const QString & _t2, const QVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void dfmbase::DeviceProxyManager::blockDriveAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dfmbase::DeviceProxyManager::blockDriveRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dfmbase::DeviceProxyManager::blockDevAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmbase::DeviceProxyManager::blockDevRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dfmbase::DeviceProxyManager::blockDevMounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dfmbase::DeviceProxyManager::blockDevUnmounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void dfmbase::DeviceProxyManager::blockDevLocked(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dfmbase::DeviceProxyManager::blockDevUnlocked(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void dfmbase::DeviceProxyManager::blockDevFsAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dfmbase::DeviceProxyManager::blockDevFsRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dfmbase::DeviceProxyManager::protocolDevAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dfmbase::DeviceProxyManager::protocolDevRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void dfmbase::DeviceProxyManager::protocolDevMounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void dfmbase::DeviceProxyManager::protocolDevUnmounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void dfmbase::DeviceProxyManager::devMngDBusRegistered()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void dfmbase::DeviceProxyManager::devMngDBusUnregistered()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
