/****************************************************************************
** Meta object code from reading C++ file 'fileview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/views/fileview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::FileView::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::FileView",
        "reqOpenNewWindow",
        "",
        "QList<QUrl>",
        "urls",
        "viewStateChanged",
        "selectUrlChanged",
        "onHeaderViewMousePressed",
        "onHeaderViewMouseReleased",
        "onHeaderSectionResized",
        "logicalIndex",
        "oldSize",
        "newSize",
        "onHeaderSectionMoved",
        "oldVisualIndex",
        "newVisualIndex",
        "onHeaderHiddenChanged",
        "roleName",
        "isHidden",
        "onSortIndicatorChanged",
        "Qt::SortOrder",
        "order",
        "onSectionHandleDoubleClicked",
        "onClicked",
        "QModelIndex",
        "index",
        "onDoubleClicked",
        "onScalingValueChanged",
        "value",
        "viewModeChanged",
        "windowId",
        "viewMode",
        "onRowCountChanged",
        "trashStateChanged",
        "onHeaderViewSectionChanged",
        "QUrl",
        "url",
        "onAppAttributeChanged",
        "group",
        "key",
        "QVariant",
        "onSelectAndEdit",
        "edit",
        "EditTrigger",
        "trigger",
        "QEvent*",
        "event",
        "currentDirOpenMode",
        "DirOpenMode",
        "onWidgetUpdate",
        "onRenameProcessStarted",
        "loadViewState",
        "saveViewModeState",
        "onModelStateChanged",
        "setIconSizeBySizeIndex",
        "sizeIndex",
        "onShowFileSuffixChanged",
        "isShow",
        "updateHorizontalOffset",
        "updateView",
        "updateOneView",
        "onSelectionChanged",
        "QItemSelection",
        "indexInRect",
        "deselected",
        "onDefaultViewModeChanged",
        "mode",
        "onIconSizeChanged",
        "onItemWidthLevelChanged",
        "level",
        "onItemHeightLevelChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reqOpenNewWindow'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'viewStateChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectUrlChanged'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onHeaderViewMousePressed'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onHeaderViewMouseReleased'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onHeaderSectionResized'
        QtMocHelpers::SlotData<void(int, int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'onHeaderSectionMoved'
        QtMocHelpers::SlotData<void(int, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'onHeaderHiddenChanged'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'onSortIndicatorChanged'
        QtMocHelpers::SlotData<void(int, Qt::SortOrder)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'onSectionHandleDoubleClicked'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Slot 'onClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onScalingValueChanged'
        QtMocHelpers::SlotData<void(const int)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'viewModeChanged'
        QtMocHelpers::SlotData<void(quint64, int)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 30 }, { QMetaType::Int, 31 },
        }}),
        // Slot 'onRowCountChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'trashStateChanged'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onHeaderViewSectionChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'onAppAttributeChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QVariant &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { QMetaType::QString, 39 }, { 0x80000000 | 40, 28 },
        }}),
        // Slot 'onSelectAndEdit'
        QtMocHelpers::SlotData<void(const QUrl &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'edit'
        QtMocHelpers::SlotData<bool(const QModelIndex &, EditTrigger, QEvent *)>(42, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 43, 44 }, { 0x80000000 | 45, 46 },
        }}),
        // Slot 'currentDirOpenMode'
        QtMocHelpers::SlotData<DirOpenMode() const>(47, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'onWidgetUpdate'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRenameProcessStarted'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadViewState'
        QtMocHelpers::SlotData<void(const QUrl &)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'saveViewModeState'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onModelStateChanged'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setIconSizeBySizeIndex'
        QtMocHelpers::SlotData<void(const int)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'onShowFileSuffixChanged'
        QtMocHelpers::SlotData<void(bool)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'updateHorizontalOffset'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateOneView'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 62, 63 }, { 0x80000000 | 62, 64 },
        }}),
        // Slot 'onDefaultViewModeChanged'
        QtMocHelpers::SlotData<void(int)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 66 },
        }}),
        // Slot 'onIconSizeChanged'
        QtMocHelpers::SlotData<void(int)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'onItemWidthLevelChanged'
        QtMocHelpers::SlotData<void(int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 69 },
        }}),
        // Slot 'onItemHeightLevelChanged'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 69 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileView, qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::FileView::staticMetaObject = { {
    QMetaObject::SuperData::link<DListView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::FileView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reqOpenNewWindow((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 1: _t->viewStateChanged(); break;
        case 2: _t->selectUrlChanged((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 3: _t->onHeaderViewMousePressed(); break;
        case 4: _t->onHeaderViewMouseReleased(); break;
        case 5: _t->onHeaderSectionResized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->onHeaderSectionMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->onHeaderHiddenChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->onSortIndicatorChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[2]))); break;
        case 9: _t->onSectionHandleDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->onClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 11: _t->onDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 12: _t->onScalingValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->viewModeChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->onRowCountChanged(); break;
        case 15: _t->trashStateChanged(); break;
        case 16: _t->onHeaderViewSectionChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->onAppAttributeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 18: _t->onSelectAndEdit((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 19: { bool _r = _t->edit((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<EditTrigger>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QEvent*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { DirOpenMode _r = _t->currentDirOpenMode();
            if (_a[0]) *reinterpret_cast<DirOpenMode*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->onWidgetUpdate(); break;
        case 22: _t->onRenameProcessStarted(); break;
        case 23: _t->loadViewState((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 24: _t->saveViewModeState(); break;
        case 25: _t->onModelStateChanged(); break;
        case 26: _t->setIconSizeBySizeIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->onShowFileSuffixChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->updateHorizontalOffset(); break;
        case 29: _t->updateView(); break;
        case 30: _t->updateOneView((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 31: _t->onSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 32: _t->onDefaultViewModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->onIconSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->onItemWidthLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->onItemHeightLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileView::*)(const QList<QUrl> & )>(_a, &FileView::reqOpenNewWindow, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileView::*)()>(_a, &FileView::viewStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileView::*)(const QList<QUrl> & )>(_a, &FileView::selectUrlChanged, 2))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::FileView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::FileView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8FileViewE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "dfmbase::AbstractBaseView"))
        return static_cast< dfmbase::AbstractBaseView*>(this);
    return DListView::qt_metacast(_clname);
}

int dfmplugin_workspace::FileView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::FileView::reqOpenNewWindow(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_workspace::FileView::viewStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_workspace::FileView::selectUrlChanged(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
