/****************************************************************************
** Meta object code from reading C++ file 'emblemhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-emblem/utils/emblemhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'emblemhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_emblem::GioEmblemWorker::qt_create_metaobjectdata<qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_emblem::GioEmblemWorker",
        "emblemChanged",
        "",
        "QUrl",
        "url",
        "Product",
        "product",
        "onProduce",
        "FileInfoPointer",
        "info",
        "onClear"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'emblemChanged'
        QtMocHelpers::SignalData<void(const QUrl &, const Product &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'onProduce'
        QtMocHelpers::SlotData<void(const FileInfoPointer &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'onClear'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GioEmblemWorker, qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_emblem::GioEmblemWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_emblem::GioEmblemWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GioEmblemWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->emblemChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Product>>(_a[2]))); break;
        case 1: _t->onProduce((*reinterpret_cast<std::add_pointer_t<FileInfoPointer>>(_a[1]))); break;
        case 2: _t->onClear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileInfoPointer >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GioEmblemWorker::*)(const QUrl & , const Product & )>(_a, &GioEmblemWorker::emblemChanged, 0))
            return;
    }
}

const QMetaObject *dfmplugin_emblem::GioEmblemWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_emblem::GioEmblemWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem15GioEmblemWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_emblem::GioEmblemWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_emblem::GioEmblemWorker::emblemChanged(const QUrl & _t1, const Product & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_emblem::EmblemHelper::qt_create_metaobjectdata<qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_emblem::EmblemHelper",
        "requestProduce",
        "",
        "FileInfoPointer",
        "info",
        "requestClear",
        "onEmblemChanged",
        "QUrl",
        "url",
        "Product",
        "product",
        "onUrlChanged",
        "windowId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestProduce'
        QtMocHelpers::SignalData<void(const FileInfoPointer &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestClear'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onEmblemChanged'
        QtMocHelpers::SlotData<void(const QUrl &, const Product &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onUrlChanged'
        QtMocHelpers::SlotData<bool(quint64, const QUrl &)>(11, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::ULongLong, 12 }, { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EmblemHelper, qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_emblem::EmblemHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>.metaTypes,
    nullptr
} };

void dfmplugin_emblem::EmblemHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EmblemHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestProduce((*reinterpret_cast<std::add_pointer_t<FileInfoPointer>>(_a[1]))); break;
        case 1: _t->requestClear(); break;
        case 2: _t->onEmblemChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Product>>(_a[2]))); break;
        case 3: { bool _r = _t->onUrlChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileInfoPointer >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EmblemHelper::*)(const FileInfoPointer & )>(_a, &EmblemHelper::requestProduce, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EmblemHelper::*)()>(_a, &EmblemHelper::requestClear, 1))
            return;
    }
}

const QMetaObject *dfmplugin_emblem::EmblemHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_emblem::EmblemHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_emblem12EmblemHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_emblem::EmblemHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_emblem::EmblemHelper::requestProduce(const FileInfoPointer & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_emblem::EmblemHelper::requestClear()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
