/****************************************************************************
** Meta object code from reading C++ file 'vaultdaemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/daemon/vault/vaultdaemon.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultdaemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto daemonplugin_vaultdaemon::VaultManagerDBusWorker::qt_create_metaobjectdata<qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "daemonplugin_vaultdaemon::VaultManagerDBusWorker",
        "launchService",
        "",
        "sendChangedVaultStateSig",
        "QVariantMap",
        "map"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'launchService'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendChangedVaultStateSig'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VaultManagerDBusWorker, qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject daemonplugin_vaultdaemon::VaultManagerDBusWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>.metaTypes,
    nullptr
} };

void daemonplugin_vaultdaemon::VaultManagerDBusWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultManagerDBusWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->launchService(); break;
        case 1: _t->sendChangedVaultStateSig((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *daemonplugin_vaultdaemon::VaultManagerDBusWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *daemonplugin_vaultdaemon::VaultManagerDBusWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon22VaultManagerDBusWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int daemonplugin_vaultdaemon::VaultManagerDBusWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t {};
} // unnamed namespace

template <> constexpr inline auto daemonplugin_vaultdaemon::VaultDaemon::qt_create_metaobjectdata<qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "daemonplugin_vaultdaemon::VaultDaemon",
        "requesLaunch",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requesLaunch'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VaultDaemon, qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject daemonplugin_vaultdaemon::VaultDaemon::staticMetaObject = { {
    QMetaObject::SuperData::link<dpf::Plugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>.metaTypes,
    nullptr
} };

void daemonplugin_vaultdaemon::VaultDaemon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultDaemon *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requesLaunch(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VaultDaemon::*)()>(_a, &VaultDaemon::requesLaunch, 0))
            return;
    }
}

const QMetaObject *daemonplugin_vaultdaemon::VaultDaemon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *daemonplugin_vaultdaemon::VaultDaemon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24daemonplugin_vaultdaemon11VaultDaemonE_t>.strings))
        return static_cast<void*>(this);
    return dpf::Plugin::qt_metacast(_clname);
}

int daemonplugin_vaultdaemon::VaultDaemon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dpf::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void daemonplugin_vaultdaemon::VaultDaemon::requesLaunch()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
using namespace daemonplugin_vaultdaemon;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_VaultDaemon[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x18,  'o',  'r',  'g',  '.',  'd', 
    'e',  'e',  'p',  'i',  'n',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  '.',  'd',  'a',  'e', 
    'm',  'o',  'n', 
    // "className"
    0x03,  0x6b,  'V',  'a',  'u',  'l',  't',  'D', 
    'a',  'e',  'm',  'o',  'n', 
    // "MetaData"
    0x04,  0xa4,  0x67,  'D',  'e',  'p',  'e',  'n', 
    'd',  's',  0x80,  0x6b,  'D',  'e',  's',  'c', 
    'r',  'i',  'p',  't',  'i',  'o',  'n',  0x78, 
    0x38,  'T',  'h',  'e',  ' ',  'v',  'a',  'u', 
    'l',  't',  ' ',  'h',  'e',  'l',  'p',  'e', 
    'r',  ' ',  'p',  'l',  'u',  'g',  'i',  'n', 
    ' ',  'f',  'o',  'r',  ' ',  't',  'h',  'e', 
    ' ',  'd',  'd',  'e',  '-',  'f',  'i',  'l', 
    'e',  '-',  'm',  'a',  'n',  'a',  'g',  'e', 
    'r',  '-',  'd',  'a',  'e',  'm',  'o',  'n', 
    '.',  0x64,  'N',  'a',  'm',  'e',  0x76,  'd', 
    'f',  'm',  'd',  'a',  'e',  'm',  'o',  'n', 
    '-',  'v',  'a',  'u',  'l',  't',  '-',  'p', 
    'l',  'u',  'g',  'i',  'n',  0x67,  'V',  'e', 
    'r',  's',  'i',  'o',  'n',  0x65,  '1',  '.', 
    '0',  '.',  '0', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(daemonplugin_vaultdaemon::VaultDaemon, VaultDaemon, qt_pluginMetaDataV2_VaultDaemon)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_VaultDaemon[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x18,  'o',  'r',  'g',  '.',  'd', 
    'e',  'e',  'p',  'i',  'n',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  '.',  'd',  'a',  'e', 
    'm',  'o',  'n', 
    // "className"
    0x03,  0x6b,  'V',  'a',  'u',  'l',  't',  'D', 
    'a',  'e',  'm',  'o',  'n', 
    // "MetaData"
    0x04,  0xa4,  0x67,  'D',  'e',  'p',  'e',  'n', 
    'd',  's',  0x80,  0x6b,  'D',  'e',  's',  'c', 
    'r',  'i',  'p',  't',  'i',  'o',  'n',  0x78, 
    0x38,  'T',  'h',  'e',  ' ',  'v',  'a',  'u', 
    'l',  't',  ' ',  'h',  'e',  'l',  'p',  'e', 
    'r',  ' ',  'p',  'l',  'u',  'g',  'i',  'n', 
    ' ',  'f',  'o',  'r',  ' ',  't',  'h',  'e', 
    ' ',  'd',  'd',  'e',  '-',  'f',  'i',  'l', 
    'e',  '-',  'm',  'a',  'n',  'a',  'g',  'e', 
    'r',  '-',  'd',  'a',  'e',  'm',  'o',  'n', 
    '.',  0x64,  'N',  'a',  'm',  'e',  0x76,  'd', 
    'f',  'm',  'd',  'a',  'e',  'm',  'o',  'n', 
    '-',  'v',  'a',  'u',  'l',  't',  '-',  'p', 
    'l',  'u',  'g',  'i',  'n',  0x67,  'V',  'e', 
    'r',  's',  'i',  'o',  'n',  0x65,  '1',  '.', 
    '0',  '.',  '0', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(daemonplugin_vaultdaemon::VaultDaemon, VaultDaemon)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
