/****************************************************************************
** Meta object code from reading C++ file 'cusmediaplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../dde-file-manager/src/apps/dde-file-manager-preview/pluginpreviews/music-preview/cusmediaplayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cusmediaplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto plugin_filepreview::CusMediaPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "plugin_filepreview::CusMediaPlayer",
        "sigStateChanged",
        "",
        "QMediaPlayer::PlaybackState",
        "newState",
        "sigStatusChanged",
        "QMediaPlayer::MediaStatus",
        "status",
        "sigDurationChanged",
        "duration",
        "sigPositionChanged",
        "pos",
        "sigCreateMediaPlayer",
        "sigSetMedia",
        "QUrl",
        "url",
        "sigSetPosition",
        "sigPlay",
        "sigPause",
        "sigStop"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigStateChanged'
        QtMocHelpers::SignalData<void(QMediaPlayer::PlaybackState)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sigStatusChanged'
        QtMocHelpers::SignalData<void(QMediaPlayer::MediaStatus)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigDurationChanged'
        QtMocHelpers::SignalData<void(qint64)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Signal 'sigPositionChanged'
        QtMocHelpers::SignalData<void(qint64)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Signal 'sigCreateMediaPlayer'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSetMedia'
        QtMocHelpers::SignalData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'sigSetPosition'
        QtMocHelpers::SignalData<void(qint64)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Signal 'sigPlay'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigPause'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigStop'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CusMediaPlayer, qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject plugin_filepreview::CusMediaPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>.metaTypes,
    nullptr
} };

void plugin_filepreview::CusMediaPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CusMediaPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigStateChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 1: _t->sigStatusChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::MediaStatus>>(_a[1]))); break;
        case 2: _t->sigDurationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->sigPositionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 4: _t->sigCreateMediaPlayer(); break;
        case 5: _t->sigSetMedia((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->sigSetPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 7: _t->sigPlay(); break;
        case 8: _t->sigPause(); break;
        case 9: _t->sigStop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(QMediaPlayer::PlaybackState )>(_a, &CusMediaPlayer::sigStateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(QMediaPlayer::MediaStatus )>(_a, &CusMediaPlayer::sigStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(qint64 )>(_a, &CusMediaPlayer::sigDurationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(qint64 )>(_a, &CusMediaPlayer::sigPositionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)()>(_a, &CusMediaPlayer::sigCreateMediaPlayer, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(const QUrl & )>(_a, &CusMediaPlayer::sigSetMedia, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)(qint64 )>(_a, &CusMediaPlayer::sigSetPosition, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)()>(_a, &CusMediaPlayer::sigPlay, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)()>(_a, &CusMediaPlayer::sigPause, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CusMediaPlayer::*)()>(_a, &CusMediaPlayer::sigStop, 9))
            return;
    }
}

const QMetaObject *plugin_filepreview::CusMediaPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *plugin_filepreview::CusMediaPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview14CusMediaPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int plugin_filepreview::CusMediaPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void plugin_filepreview::CusMediaPlayer::sigStateChanged(QMediaPlayer::PlaybackState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void plugin_filepreview::CusMediaPlayer::sigStatusChanged(QMediaPlayer::MediaStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void plugin_filepreview::CusMediaPlayer::sigDurationChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void plugin_filepreview::CusMediaPlayer::sigPositionChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void plugin_filepreview::CusMediaPlayer::sigCreateMediaPlayer()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void plugin_filepreview::CusMediaPlayer::sigSetMedia(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void plugin_filepreview::CusMediaPlayer::sigSetPosition(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void plugin_filepreview::CusMediaPlayer::sigPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void plugin_filepreview::CusMediaPlayer::sigPause()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void plugin_filepreview::CusMediaPlayer::sigStop()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
