/****************************************************************************
** Meta object code from reading C++ file 'vaultentryfileentity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-vault/utils/vaultentryfileentity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultentryfileentity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_vault::VaultEntryFileEntity::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_vault::VaultEntryFileEntity",
        "slotFileDirSizeChange",
        "",
        "size",
        "filesCount",
        "directoryCount",
        "slotFinishedThread",
        "displayName",
        "icon",
        "QIcon",
        "exists",
        "showProgress",
        "showTotalSize",
        "showUsageSize",
        "order",
        "dfmbase::AbstractEntryFileEntity::EntryOrder",
        "refresh",
        "sizeTotal",
        "targetUrl",
        "QUrl",
        "VaultEntryFileEntity",
        "parent"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotFileDirSizeChange'
        QtMocHelpers::SlotData<void(qint64, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Slot 'slotFinishedThread'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'displayName'
        QtMocHelpers::MethodData<QString() const>(7, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'icon'
        QtMocHelpers::MethodData<QIcon() const>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Method 'exists'
        QtMocHelpers::MethodData<bool() const>(10, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showProgress'
        QtMocHelpers::MethodData<bool() const>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showTotalSize'
        QtMocHelpers::MethodData<bool() const>(12, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'showUsageSize'
        QtMocHelpers::MethodData<bool() const>(13, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'order'
        QtMocHelpers::MethodData<dfmbase::AbstractEntryFileEntity::EntryOrder() const>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Method 'refresh'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'sizeTotal'
        QtMocHelpers::MethodData<quint64() const>(17, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Method 'targetUrl'
        QtMocHelpers::MethodData<QUrl() const>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    using Constructor = QtMocHelpers::NoType;
    QtMocHelpers::UintData qt_constructors {
        QtMocHelpers::ConstructorData<Constructor(QObject *)>(2, QMC::AccessPublic, {{
            { QMetaType::QObjectStar, 21 },
        }}),
        QtMocHelpers::ConstructorData<Constructor()>(2, QMC::AccessPublic | QMC::MethodCloned),
    };
    return QtMocHelpers::metaObjectData<VaultEntryFileEntity, qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors);
}
Q_CONSTINIT const QMetaObject dfmplugin_vault::VaultEntryFileEntity::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>.metaTypes,
    nullptr
} };

void dfmplugin_vault::VaultEntryFileEntity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultEntryFileEntity *>(_o);
    if (_c == QMetaObject::CreateInstance) {
        switch (_id) {
        case 0: { VaultEntryFileEntity *_r = new VaultEntryFileEntity((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        case 1: { VaultEntryFileEntity *_r = new VaultEntryFileEntity();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = _r; } break;
        default: break;
        }
    }
    if (_c == QMetaObject::ConstructInPlace) {
        switch (_id) {
        case 0: { new (_a[0]) VaultEntryFileEntity((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); } break;
        case 1: { new (_a[0]) VaultEntryFileEntity(); } break;
        default: break;
        }
    }
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotFileDirSizeChange((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->slotFinishedThread(); break;
        case 2: { QString _r = _t->displayName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 3: { QIcon _r = _t->icon();
            if (_a[0]) *reinterpret_cast<QIcon*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->exists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->showProgress();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->showTotalSize();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->showUsageSize();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { dfmbase::AbstractEntryFileEntity::EntryOrder _r = _t->order();
            if (_a[0]) *reinterpret_cast<dfmbase::AbstractEntryFileEntity::EntryOrder*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->refresh(); break;
        case 10: { quint64 _r = _t->sizeTotal();
            if (_a[0]) *reinterpret_cast<quint64*>(_a[0]) = std::move(_r); }  break;
        case 11: { QUrl _r = _t->targetUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_vault::VaultEntryFileEntity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::VaultEntryFileEntity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault20VaultEntryFileEntityE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_vault::VaultEntryFileEntity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
