/****************************************************************************
** Meta object code from reading C++ file 'fileinfomodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/model/fileinfomodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileinfomodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::FileInfoModel::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::FileInfoModel",
        "dataReplaced",
        "",
        "QUrl",
        "oldUrl",
        "newUrl",
        "rootUrl",
        "rootIndex",
        "QModelIndex",
        "index",
        "url",
        "column",
        "fileInfo",
        "FileInfoPointer",
        "fileUrl",
        "files",
        "QList<QUrl>",
        "refresh",
        "parent",
        "modelState",
        "update",
        "updateFile",
        "refreshAllFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataReplaced'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Method 'rootUrl'
        QtMocHelpers::MethodData<QUrl() const>(6, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'rootIndex'
        QtMocHelpers::MethodData<QModelIndex() const>(7, 2, QMC::AccessPublic, 0x80000000 | 8),
        // Method 'index'
        QtMocHelpers::MethodData<QModelIndex(const QUrl &, int) const>(9, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 3, 10 }, { QMetaType::Int, 11 },
        }}),
        // Method 'index'
        QtMocHelpers::MethodData<QModelIndex(const QUrl &) const>(9, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 8, {{
            { 0x80000000 | 3, 10 },
        }}),
        // Method 'fileInfo'
        QtMocHelpers::MethodData<FileInfoPointer(const QModelIndex &) const>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'fileUrl'
        QtMocHelpers::MethodData<QUrl(const QModelIndex &) const>(14, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'files'
        QtMocHelpers::MethodData<QList<QUrl>() const>(15, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Method 'refresh'
        QtMocHelpers::MethodData<void(const QModelIndex &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 18 },
        }}),
        // Method 'modelState'
        QtMocHelpers::MethodData<int() const>(19, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'update'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'updateFile'
        QtMocHelpers::MethodData<void(const QUrl &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 10 },
        }}),
        // Method 'refreshAllFile'
        QtMocHelpers::MethodData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileInfoModel, qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::FileInfoModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::FileInfoModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileInfoModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataReplaced((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: { QUrl _r = _t->rootUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 2: { QModelIndex _r = _t->rootIndex();
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 3: { QModelIndex _r = _t->index((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 4: { QModelIndex _r = _t->index((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 5: { FileInfoPointer _r = _t->fileInfo((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<FileInfoPointer*>(_a[0]) = std::move(_r); }  break;
        case 6: { QUrl _r = _t->fileUrl((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<QUrl> _r = _t->files();
            if (_a[0]) *reinterpret_cast<QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: { int _r = _t->modelState();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->update(); break;
        case 11: _t->updateFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->refreshAllFile(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileInfoModel::*)(const QUrl & , const QUrl & )>(_a, &FileInfoModel::dataReplaced, 0))
            return;
    }
}

const QMetaObject *ddplugin_canvas::FileInfoModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::FileInfoModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas13FileInfoModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int ddplugin_canvas::FileInfoModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_canvas::FileInfoModel::dataReplaced(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
