/****************************************************************************
** Meta object code from reading C++ file 'smbbrowsereventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-smbbrowser/events/smbbrowsereventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'smbbrowsereventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_smbbrowser::SmbBrowserEventReceiver",
        "detailViewIcon",
        "",
        "QUrl",
        "url",
        "QString*",
        "iconName",
        "cancelDelete",
        "QList<QUrl>",
        "urls",
        "rootUrl",
        "cancelMoveToTrash",
        "hookSetTabName",
        "tabName",
        "hookTitleBarAddrHandle",
        "QUrl*",
        "hookAllowRepeatUrl",
        "cur",
        "pre"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'detailViewIcon'
        QtMocHelpers::SlotData<bool(const QUrl &, QString *)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'cancelDelete'
        QtMocHelpers::SlotData<bool(quint64, const QList<QUrl> &, const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 2 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 3, 10 },
        }}),
        // Slot 'cancelMoveToTrash'
        QtMocHelpers::SlotData<bool(quint64, const QList<QUrl> &, const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 2 }, { 0x80000000 | 8, 2 }, { 0x80000000 | 3, 10 },
        }}),
        // Slot 'hookSetTabName'
        QtMocHelpers::SlotData<bool(const QUrl &, QString *)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 13 },
        }}),
        // Slot 'hookTitleBarAddrHandle'
        QtMocHelpers::SlotData<bool(QUrl *)>(14, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Slot 'hookAllowRepeatUrl'
        QtMocHelpers::SlotData<bool(const QUrl &, const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 17 }, { 0x80000000 | 3, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SmbBrowserEventReceiver, qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_smbbrowser::SmbBrowserEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SmbBrowserEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->detailViewIcon((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->cancelDelete((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->cancelMoveToTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->hookSetTabName((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->hookTitleBarAddrHandle((*reinterpret_cast<std::add_pointer_t<QUrl*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->hookAllowRepeatUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_smbbrowser::SmbBrowserEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20dfmplugin_smbbrowser23SmbBrowserEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_smbbrowser::SmbBrowserEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
