/****************************************************************************
** Meta object code from reading C++ file 'filedialogmanagerdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filedialog/core/dbus/filedialogmanagerdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialogmanagerdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21FileDialogManagerDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto FileDialogManagerDBus::qt_create_metaobjectdata<qt_meta_tag_ZN21FileDialogManagerDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileDialogManagerDBus",
        "D-Bus Interface",
        "com.deepin.filemanager.filedialog",
        "createDialog",
        "QDBusObjectPath",
        "",
        "key",
        "destroyDialog",
        "path",
        "dialogs",
        "QList<QDBusObjectPath>",
        "errorString",
        "isUseFileChooserDialog",
        "canUseFileChooserDialog",
        "group",
        "executableFileName",
        "globPatternsForMime",
        "mimeType",
        "monitorFiles",
        "showBluetoothTransDialog",
        "id",
        "URIs"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createDialog'
        QtMocHelpers::SlotData<QDBusObjectPath(QString)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'destroyDialog'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 8 },
        }}),
        // Slot 'dialogs'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>() const>(9, 5, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'errorString'
        QtMocHelpers::SlotData<QString() const>(11, 5, QMC::AccessPublic, QMetaType::QString),
        // Slot 'isUseFileChooserDialog'
        QtMocHelpers::SlotData<bool() const>(12, 5, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'canUseFileChooserDialog'
        QtMocHelpers::SlotData<bool(const QString &, const QString &) const>(13, 5, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'globPatternsForMime'
        QtMocHelpers::SlotData<QStringList(const QString &) const>(16, 5, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'monitorFiles'
        QtMocHelpers::SlotData<QStringList() const>(18, 5, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'showBluetoothTransDialog'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(19, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QStringList, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FileDialogManagerDBus, qt_meta_tag_ZN21FileDialogManagerDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FileDialogManagerDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileDialogManagerDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileDialogManagerDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21FileDialogManagerDBusE_t>.metaTypes,
    nullptr
} };

void FileDialogManagerDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileDialogManagerDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusObjectPath _r = _t->createDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->destroyDialog((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: { QList<QDBusObjectPath> _r = _t->dialogs();
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->errorString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->isUseFileChooserDialog();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->canUseFileChooserDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->globPatternsForMime((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->monitorFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->showBluetoothTransDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
}

const QMetaObject *FileDialogManagerDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileDialogManagerDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileDialogManagerDBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FileDialogManagerDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
