/****************************************************************************
** Meta object code from reading C++ file 'thumbnailfactory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/utils/thumbnail/thumbnailfactory.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'thumbnailfactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::ThumbnailFactory::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::ThumbnailFactory",
        "produceFinished",
        "",
        "QUrl",
        "src",
        "thumb",
        "produceFailed",
        "addTask",
        "ThumbnailWorker::ThumbnailTaskMap",
        "taskMap",
        "thumbnailJob",
        "url",
        "dfmbase::Global::ThumbnailSize",
        "size",
        "onAboutToQuit",
        "pushTask",
        "doJoinThumbnailJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'produceFinished'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'produceFailed'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'addTask'
        QtMocHelpers::SignalData<void(const ThumbnailWorker::ThumbnailTaskMap &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'thumbnailJob'
        QtMocHelpers::SignalData<void(const QUrl &, dfmbase::Global::ThumbnailSize)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onAboutToQuit'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pushTask'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doJoinThumbnailJob'
        QtMocHelpers::SlotData<void(const QUrl &, dfmbase::Global::ThumbnailSize)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ThumbnailFactory, qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::ThumbnailFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>.metaTypes,
    nullptr
} };

void dfmbase::ThumbnailFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThumbnailFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->produceFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->produceFailed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->addTask((*reinterpret_cast<std::add_pointer_t<ThumbnailWorker::ThumbnailTaskMap>>(_a[1]))); break;
        case 3: _t->thumbnailJob((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ThumbnailSize>>(_a[2]))); break;
        case 4: _t->onAboutToQuit(); break;
        case 5: _t->pushTask(); break;
        case 6: _t->doJoinThumbnailJob((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ThumbnailSize>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ThumbnailSize >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ThumbnailSize >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ThumbnailFactory::*)(const QUrl & , const QString & )>(_a, &ThumbnailFactory::produceFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailFactory::*)(const QUrl & )>(_a, &ThumbnailFactory::produceFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailFactory::*)(const ThumbnailWorker::ThumbnailTaskMap & )>(_a, &ThumbnailFactory::addTask, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailFactory::*)(const QUrl & , dfmbase::Global::ThumbnailSize )>(_a, &ThumbnailFactory::thumbnailJob, 3))
            return;
    }
}

const QMetaObject *dfmbase::ThumbnailFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::ThumbnailFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase16ThumbnailFactoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::ThumbnailFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::ThumbnailFactory::produceFinished(const QUrl & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmbase::ThumbnailFactory::produceFailed(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmbase::ThumbnailFactory::addTask(const ThumbnailWorker::ThumbnailTaskMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmbase::ThumbnailFactory::thumbnailJob(const QUrl & _t1, dfmbase::Global::ThumbnailSize _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
