/****************************************************************************
** Meta object code from reading C++ file 'addressbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-titlebar/views/addressbar.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'addressbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_titlebar::AddressBar::qt_create_metaobjectdata<qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_titlebar::AddressBar",
        "lostFocus",
        "",
        "escKeyPressed",
        "clearButtonPressed",
        "pauseButtonClicked",
        "urlChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lostFocus'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'escKeyPressed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearButtonPressed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pauseButtonClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddressBar, qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_titlebar::AddressBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>.metaTypes,
    nullptr
} };

void dfmplugin_titlebar::AddressBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddressBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lostFocus(); break;
        case 1: _t->escKeyPressed(); break;
        case 2: _t->clearButtonPressed(); break;
        case 3: _t->pauseButtonClicked(); break;
        case 4: _t->urlChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AddressBar::*)()>(_a, &AddressBar::lostFocus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddressBar::*)()>(_a, &AddressBar::escKeyPressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddressBar::*)()>(_a, &AddressBar::clearButtonPressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddressBar::*)()>(_a, &AddressBar::pauseButtonClicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AddressBar::*)()>(_a, &AddressBar::urlChanged, 4))
            return;
    }
}

const QMetaObject *dfmplugin_titlebar::AddressBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_titlebar::AddressBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar10AddressBarE_t>.strings))
        return static_cast<void*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int dfmplugin_titlebar::AddressBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_titlebar::AddressBar::lostFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmplugin_titlebar::AddressBar::escKeyPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_titlebar::AddressBar::clearButtonPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dfmplugin_titlebar::AddressBar::pauseButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dfmplugin_titlebar::AddressBar::urlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
