/****************************************************************************
** Meta object code from reading C++ file 'vaultmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "vaultmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19VaultManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto VaultManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19VaultManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VaultManagerAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.VaultManager",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.Daemon.VaultManager\">\n"
        "    <signal name=\"LockEventTriggered\">\n      <arg direction=\"o"
        "ut\" type=\"s\" name=\"user\"/>\n    </signal>\n    <signal name=\""
        "ChangedVaultState\">\n      <arg direction=\"out\" type=\"a{sv}\" "
        "name=\"map\"/>\n      <annotation value=\"QVariantMap\" name=\"org"
        ".qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <method "
        "name=\"SysUserChanged\">\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"curUser\"/>\n    </method>\n    <method name=\"SetRefreshTim"
        "e\">\n      <arg direction=\"in\" type=\"t\" name=\"time\"/>\n    "
        "</method>\n    <method name=\"GetLastestTime\">\n      <arg direct"
        "ion=\"out\" type=\"t\"/>\n    </method>\n    <method name=\"GetSel"
        "fTime\">\n      <arg direction=\"out\" type=\"t\"/>\n    </method>"
        "\n    <method name=\"IsLockEventTriggered\">\n      <arg direction"
        "=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"TriggerLo"
        "ckEvent\"/>\n    <method name=\"ClearLockEvent\"/>\n    <method na"
        "me=\"ComputerSleep\">\n      <arg direction=\"in\" type=\"b\" name"
        "=\"bSleep\"/>\n    </method>\n    <method name=\"GetLeftoverErrorI"
        "nputTimes\">\n      <arg direction=\"out\" type=\"i\"/>\n      <ar"
        "g direction=\"in\" type=\"i\" name=\"userID\"/>\n    </method>\n  "
        "  <method name=\"LeftoverErrorInputTimesMinusOne\">\n      <arg di"
        "rection=\"in\" type=\"i\" name=\"userID\"/>\n    </method>\n    <m"
        "ethod name=\"RestoreLeftoverErrorInputTimes\">\n      <arg directi"
        "on=\"in\" type=\"i\" name=\"userID\"/>\n    </method>\n    <method"
        " name=\"StartTimerOfRestorePasswordInput\">\n      <arg direction="
        "\"in\" type=\"i\" name=\"userID\"/>\n    </method>\n    <method na"
        "me=\"GetNeedWaitMinutes\">\n      <arg direction=\"out\" type=\"i\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"userID\"/>\n    "
        "</method>\n    <method name=\"RestoreNeedWaitMinutes\">\n      <ar"
        "g direction=\"in\" type=\"i\" name=\"userID\"/>\n    </method>\n  "
        "</interface>\n",
        "ChangedVaultState",
        "",
        "QVariantMap",
        "map",
        "LockEventTriggered",
        "user",
        "ClearLockEvent",
        "ComputerSleep",
        "bSleep",
        "GetLastestTime",
        "GetLeftoverErrorInputTimes",
        "userID",
        "GetNeedWaitMinutes",
        "GetSelfTime",
        "IsLockEventTriggered",
        "LeftoverErrorInputTimesMinusOne",
        "RestoreLeftoverErrorInputTimes",
        "RestoreNeedWaitMinutes",
        "SetRefreshTime",
        "time",
        "StartTimerOfRestorePasswordInput",
        "SysUserChanged",
        "curUser",
        "TriggerLockEvent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ChangedVaultState'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'LockEventTriggered'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'ClearLockEvent'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ComputerSleep'
        QtMocHelpers::SlotData<void(bool)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'GetLastestTime'
        QtMocHelpers::SlotData<qulonglong()>(14, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'GetLeftoverErrorInputTimes'
        QtMocHelpers::SlotData<int(int)>(15, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'GetNeedWaitMinutes'
        QtMocHelpers::SlotData<int(int)>(17, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'GetSelfTime'
        QtMocHelpers::SlotData<qulonglong()>(18, 6, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'IsLockEventTriggered'
        QtMocHelpers::SlotData<bool()>(19, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'LeftoverErrorInputTimesMinusOne'
        QtMocHelpers::SlotData<void(int)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'RestoreLeftoverErrorInputTimes'
        QtMocHelpers::SlotData<void(int)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'RestoreNeedWaitMinutes'
        QtMocHelpers::SlotData<void(int)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'SetRefreshTime'
        QtMocHelpers::SlotData<void(qulonglong)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 },
        }}),
        // Slot 'StartTimerOfRestorePasswordInput'
        QtMocHelpers::SlotData<void(int)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'SysUserChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'TriggerLockEvent'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<VaultManagerAdaptor, qt_meta_tag_ZN19VaultManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VaultManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VaultManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VaultManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19VaultManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void VaultManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ChangedVaultState((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->LockEventTriggered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->ClearLockEvent(); break;
        case 3: _t->ComputerSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: { qulonglong _r = _t->GetLastestTime();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->GetLeftoverErrorInputTimes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->GetNeedWaitMinutes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { qulonglong _r = _t->GetSelfTime();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->IsLockEventTriggered();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->LeftoverErrorInputTimesMinusOne((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->RestoreLeftoverErrorInputTimes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->RestoreNeedWaitMinutes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->SetRefreshTime((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 13: _t->StartTimerOfRestorePasswordInput((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->SysUserChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->TriggerLockEvent(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VaultManagerAdaptor::*)(const QVariantMap & )>(_a, &VaultManagerAdaptor::ChangedVaultState, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VaultManagerAdaptor::*)(const QString & )>(_a, &VaultManagerAdaptor::LockEventTriggered, 1))
            return;
    }
}

const QMetaObject *VaultManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VaultManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VaultManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int VaultManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void VaultManagerAdaptor::ChangedVaultState(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VaultManagerAdaptor::LockEventTriggered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
