/****************************************************************************
** Meta object code from reading C++ file 'recenteventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-recent/events/recenteventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recenteventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_recent::RecentEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_recent::RecentEventReceiver",
        "handleWindowUrlChanged",
        "",
        "winId",
        "QUrl",
        "url",
        "handleRemoveFilesResult",
        "QList<QUrl>",
        "urls",
        "ok",
        "errMsg",
        "handleFileRenameResult",
        "QMap<QUrl,QUrl>",
        "renamedUrls",
        "handleFileCutResult",
        "srcUrls",
        "destUrls",
        "customColumnRole",
        "rootUrl",
        "QList<dfmbase::Global::ItemRoles>*",
        "roleList",
        "customRoleDisplayName",
        "dfmbase::Global::ItemRoles",
        "role",
        "QString*",
        "displayName",
        "detailViewIcon",
        "iconName",
        "sepateTitlebarCrumb",
        "QList<QVariantMap>*",
        "mapGroup",
        "isTransparent",
        "dfmbase::Global::TransparentStatus*",
        "status",
        "checkDragDropAction",
        "urlTo",
        "Qt::DropAction*",
        "action",
        "handleDropFiles",
        "fromUrls",
        "toUrl",
        "handlePropertydialogDisable"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleWindowUrlChanged'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleRemoveFilesResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, bool, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'handleFileRenameResult'
        QtMocHelpers::SlotData<void(quint64, const QMap<QUrl,QUrl> &, bool, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'handleFileCutResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QList<QUrl> &, bool, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 15 }, { 0x80000000 | 7, 16 }, { QMetaType::Bool, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'customColumnRole'
        QtMocHelpers::SlotData<bool(const QUrl &, QList<dfmbase::Global::ItemRoles> *)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Slot 'customRoleDisplayName'
        QtMocHelpers::SlotData<bool(const QUrl &, const dfmbase::Global::ItemRoles, QString *)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'detailViewIcon'
        QtMocHelpers::SlotData<bool(const QUrl &, QString *)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 24, 27 },
        }}),
        // Slot 'sepateTitlebarCrumb'
        QtMocHelpers::SlotData<bool(const QUrl &, QList<QVariantMap> *)>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'isTransparent'
        QtMocHelpers::SlotData<bool(const QUrl &, dfmbase::Global::TransparentStatus *)>(31, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'checkDragDropAction'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &, Qt::DropAction *)>(34, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 4, 35 }, { 0x80000000 | 36, 37 },
        }}),
        // Slot 'handleDropFiles'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 39 }, { 0x80000000 | 4, 40 },
        }}),
        // Slot 'handlePropertydialogDisable'
        QtMocHelpers::SlotData<bool(const QUrl &)>(41, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecentEventReceiver, qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_recent::RecentEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_recent::RecentEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecentEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleWindowUrlChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: _t->handleRemoveFilesResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->handleFileRenameResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QUrl,QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->handleFileCutResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 4: { bool _r = _t->customColumnRole((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<dfmbase::Global::ItemRoles>*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->customRoleDisplayName((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ItemRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->detailViewIcon((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->sepateTitlebarCrumb((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->isTransparent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::TransparentStatus*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->checkDragDropAction((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::DropAction*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->handleDropFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->handlePropertydialogDisable((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<dfmbase::Global::ItemRoles>* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ItemRoles >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::TransparentStatus* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dfmplugin_recent::RecentEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_recent::RecentEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_recent19RecentEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_recent::RecentEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
