/****************************************************************************
** Meta object code from reading C++ file 'fileviewmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/models/fileviewmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileviewmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::FileViewModel::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::FileViewModel",
        "stateChanged",
        "",
        "renameFileProcessStarted",
        "selectAndEditFile",
        "QUrl",
        "url",
        "traverPrehandle",
        "QModelIndex",
        "index",
        "FileView*",
        "view",
        "hiddenFileChanged",
        "filtersChanged",
        "nameFilters",
        "QDir::Filters",
        "filters",
        "requestGetSourceData",
        "requestChangeHiddenFilter",
        "requestChangeFilters",
        "requestChangeNameFilters",
        "requestUpdateFile",
        "requestRefreshAllChildren",
        "requestClearThumbnail",
        "requestSortChildren",
        "Qt::SortOrder",
        "order",
        "dfmbase::Global::ItemRoles",
        "role",
        "isMixAndFile",
        "requestSetFilterData",
        "QVariant",
        "data",
        "requestSetFilterCallback",
        "FileViewFilterCallback",
        "callback",
        "requestShowHiddenChanged",
        "value",
        "requestCollapseItem",
        "key",
        "parent",
        "requestTreeView",
        "isTree",
        "onFileThumbUpdated",
        "thumb",
        "onFileUpdated",
        "show",
        "onInsert",
        "firstIndex",
        "count",
        "onInsertFinish",
        "onRemove",
        "onRemoveFinish",
        "onUpdateView",
        "onGenericAttributeChanged",
        "dfmbase::Application::GenericAttribute",
        "ga",
        "onDConfigChanged",
        "config",
        "onSetCursorWait",
        "onHiddenSettingChanged",
        "onWorkFinish",
        "visiableCount",
        "totalCount",
        "onDataChanged",
        "first",
        "last"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renameFileProcessStarted'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectAndEditFile'
        QtMocHelpers::SignalData<void(const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'traverPrehandle'
        QtMocHelpers::SignalData<void(const QUrl &, const QModelIndex &, FileView *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'hiddenFileChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filtersChanged'
        QtMocHelpers::SignalData<void(QStringList, QDir::Filters)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'requestGetSourceData'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestChangeHiddenFilter'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestChangeFilters'
        QtMocHelpers::SignalData<void(QDir::Filters)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'requestChangeNameFilters'
        QtMocHelpers::SignalData<void(const QStringList &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'requestUpdateFile'
        QtMocHelpers::SignalData<void(const QUrl &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'requestRefreshAllChildren'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestClearThumbnail'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSortChildren'
        QtMocHelpers::SignalData<void(Qt::SortOrder, dfmbase::Global::ItemRoles, const bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { 0x80000000 | 27, 28 }, { QMetaType::Bool, 29 },
        }}),
        // Signal 'requestSetFilterData'
        QtMocHelpers::SignalData<void(const QVariant &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Signal 'requestSetFilterCallback'
        QtMocHelpers::SignalData<void(FileViewFilterCallback)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Signal 'requestShowHiddenChanged'
        QtMocHelpers::SignalData<void(bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Signal 'requestCollapseItem'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 }, { 0x80000000 | 5, 40 },
        }}),
        // Signal 'requestTreeView'
        QtMocHelpers::SignalData<void(const bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'onFileThumbUpdated'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QString, 44 },
        }}),
        // Slot 'onFileUpdated'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'onInsert'
        QtMocHelpers::SlotData<void(int, int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 }, { QMetaType::Int, 49 },
        }}),
        // Slot 'onInsertFinish'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onRemove'
        QtMocHelpers::SlotData<void(int, int)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 }, { QMetaType::Int, 49 },
        }}),
        // Slot 'onRemoveFinish'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUpdateView'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onGenericAttributeChanged'
        QtMocHelpers::SlotData<void(dfmbase::Application::GenericAttribute, const QVariant &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 }, { 0x80000000 | 31, 37 },
        }}),
        // Slot 'onDConfigChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 58 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'onSetCursorWait'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onHiddenSettingChanged'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'onWorkFinish'
        QtMocHelpers::SlotData<void(int, int)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 }, { QMetaType::Int, 63 },
        }}),
        // Slot 'onDataChanged'
        QtMocHelpers::SlotData<void(int, int)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 65 }, { QMetaType::Int, 66 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileViewModel, qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::FileViewModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::FileViewModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileViewModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged(); break;
        case 1: _t->renameFileProcessStarted(); break;
        case 2: _t->selectAndEditFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->traverPrehandle((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FileView*>>(_a[3]))); break;
        case 4: _t->hiddenFileChanged(); break;
        case 5: _t->filtersChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDir::Filters>>(_a[2]))); break;
        case 6: _t->requestGetSourceData(); break;
        case 7: _t->requestChangeHiddenFilter(); break;
        case 8: _t->requestChangeFilters((*reinterpret_cast<std::add_pointer_t<QDir::Filters>>(_a[1]))); break;
        case 9: _t->requestChangeNameFilters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 10: _t->requestUpdateFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->requestRefreshAllChildren(); break;
        case 12: _t->requestClearThumbnail(); break;
        case 13: _t->requestSortChildren((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ItemRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->requestSetFilterData((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 15: _t->requestSetFilterCallback((*reinterpret_cast<std::add_pointer_t<FileViewFilterCallback>>(_a[1]))); break;
        case 16: _t->requestShowHiddenChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->requestCollapseItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 18: _t->requestTreeView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->onFileThumbUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: _t->onFileUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->onInsert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 22: _t->onInsertFinish(); break;
        case 23: _t->onRemove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 24: _t->onRemoveFinish(); break;
        case 25: _t->onUpdateView(); break;
        case 26: _t->onGenericAttributeChanged((*reinterpret_cast<std::add_pointer_t<dfmbase::Application::GenericAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 27: _t->onDConfigChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 28: _t->onSetCursorWait(); break;
        case 29: _t->onHiddenSettingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->onWorkFinish((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 31: _t->onDataChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDir::Filters >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDir::Filters >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ItemRoles >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::renameFileProcessStarted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QUrl & )>(_a, &FileViewModel::selectAndEditFile, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QUrl & , const QModelIndex & , FileView * )>(_a, &FileViewModel::traverPrehandle, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::hiddenFileChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(QStringList , QDir::Filters )>(_a, &FileViewModel::filtersChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::requestGetSourceData, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::requestChangeHiddenFilter, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(QDir::Filters )>(_a, &FileViewModel::requestChangeFilters, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QStringList & )>(_a, &FileViewModel::requestChangeNameFilters, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QUrl & )>(_a, &FileViewModel::requestUpdateFile, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::requestRefreshAllChildren, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)()>(_a, &FileViewModel::requestClearThumbnail, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(Qt::SortOrder , dfmbase::Global::ItemRoles , const bool )>(_a, &FileViewModel::requestSortChildren, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QVariant & )>(_a, &FileViewModel::requestSetFilterData, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(FileViewFilterCallback )>(_a, &FileViewModel::requestSetFilterCallback, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(bool )>(_a, &FileViewModel::requestShowHiddenChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const QString & , const QUrl & )>(_a, &FileViewModel::requestCollapseItem, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileViewModel::*)(const bool )>(_a, &FileViewModel::requestTreeView, 18))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::FileViewModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::FileViewModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace13FileViewModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int dfmplugin_workspace::FileViewModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::FileViewModel::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmplugin_workspace::FileViewModel::renameFileProcessStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_workspace::FileViewModel::selectAndEditFile(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmplugin_workspace::FileViewModel::traverPrehandle(const QUrl & _t1, const QModelIndex & _t2, FileView * _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void dfmplugin_workspace::FileViewModel::hiddenFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dfmplugin_workspace::FileViewModel::filtersChanged(QStringList _t1, QDir::Filters _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dfmplugin_workspace::FileViewModel::requestGetSourceData()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dfmplugin_workspace::FileViewModel::requestChangeHiddenFilter()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dfmplugin_workspace::FileViewModel::requestChangeFilters(QDir::Filters _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dfmplugin_workspace::FileViewModel::requestChangeNameFilters(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dfmplugin_workspace::FileViewModel::requestUpdateFile(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dfmplugin_workspace::FileViewModel::requestRefreshAllChildren()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dfmplugin_workspace::FileViewModel::requestClearThumbnail()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void dfmplugin_workspace::FileViewModel::requestSortChildren(Qt::SortOrder _t1, dfmbase::Global::ItemRoles _t2, const bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void dfmplugin_workspace::FileViewModel::requestSetFilterData(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dfmplugin_workspace::FileViewModel::requestSetFilterCallback(FileViewFilterCallback _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dfmplugin_workspace::FileViewModel::requestShowHiddenChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void dfmplugin_workspace::FileViewModel::requestCollapseItem(const QString & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void dfmplugin_workspace::FileViewModel::requestTreeView(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}
QT_WARNING_POP
