/****************************************************************************
** Meta object code from reading C++ file 'dfmplugin_propertydialog_global.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-propertydialog/dfmplugin_propertydialog_global.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dfmplugin_propertydialog_global.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_propertydialogE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_propertydialog::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_propertydialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_propertydialog",
        "PropertyFilterType",
        "kNotFilter",
        "kIconTitle",
        "kBasisInfo",
        "kPermission",
        "kFileSizeFiled",
        "kFileCountFiled",
        "kFileTypeFiled",
        "kFilePositionFiled",
        "kFileCreateTimeFiled",
        "kFileAccessedTimeFiled",
        "kFileModifiedTimeFiled",
        "kFileMediaResolutionFiled",
        "kFileMediaDurationFiled",
        "BasicFieldExpandEnum",
        "kNotAll",
        "kFileSize",
        "kFileCount",
        "kFileType",
        "kFilePosition",
        "kFileCreateTime",
        "kFileAccessedTime",
        "kFileModifiedTime",
        "kFileMediaResolution",
        "kFileMediaDuration",
        "BasicExpandType",
        "kFieldInsert",
        "kFieldReplace"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PropertyFilterType'
        QtMocHelpers::EnumData<PropertyFilterType>(1, 1, QMC::EnumFlags{}).add({
            {    2, PropertyFilterType::kNotFilter },
            {    3, PropertyFilterType::kIconTitle },
            {    4, PropertyFilterType::kBasisInfo },
            {    5, PropertyFilterType::kPermission },
            {    6, PropertyFilterType::kFileSizeFiled },
            {    7, PropertyFilterType::kFileCountFiled },
            {    8, PropertyFilterType::kFileTypeFiled },
            {    9, PropertyFilterType::kFilePositionFiled },
            {   10, PropertyFilterType::kFileCreateTimeFiled },
            {   11, PropertyFilterType::kFileAccessedTimeFiled },
            {   12, PropertyFilterType::kFileModifiedTimeFiled },
            {   13, PropertyFilterType::kFileMediaResolutionFiled },
            {   14, PropertyFilterType::kFileMediaDurationFiled },
        }),
        // enum 'BasicFieldExpandEnum'
        QtMocHelpers::EnumData<BasicFieldExpandEnum>(15, 15, QMC::EnumFlags{}).add({
            {   16, BasicFieldExpandEnum::kNotAll },
            {   17, BasicFieldExpandEnum::kFileSize },
            {   18, BasicFieldExpandEnum::kFileCount },
            {   19, BasicFieldExpandEnum::kFileType },
            {   20, BasicFieldExpandEnum::kFilePosition },
            {   21, BasicFieldExpandEnum::kFileCreateTime },
            {   22, BasicFieldExpandEnum::kFileAccessedTime },
            {   23, BasicFieldExpandEnum::kFileModifiedTime },
            {   24, BasicFieldExpandEnum::kFileMediaResolution },
            {   25, BasicFieldExpandEnum::kFileMediaDuration },
        }),
        // enum 'BasicExpandType'
        QtMocHelpers::EnumData<BasicExpandType>(26, 26, QMC::EnumFlags{}).add({
            {   27, BasicExpandType::kFieldInsert },
            {   28, BasicExpandType::kFieldReplace },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN24dfmplugin_propertydialogE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN24dfmplugin_propertydialogE =
    dfmplugin_propertydialog::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_propertydialogE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN24dfmplugin_propertydialogE =
    qt_staticMetaObjectContent_ZN24dfmplugin_propertydialogE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN24dfmplugin_propertydialogE =
    qt_staticMetaObjectContent_ZN24dfmplugin_propertydialogE.relocatingData;

Q_CONSTINIT const QMetaObject dfmplugin_propertydialog::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN24dfmplugin_propertydialogE.stringdata,
    qt_staticMetaObjectStaticContent_ZN24dfmplugin_propertydialogE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN24dfmplugin_propertydialogE.metaTypes,
    nullptr
} };

QT_WARNING_POP
