/****************************************************************************
** Meta object code from reading C++ file 'fileprovider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/model/fileprovider.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::FileProvider::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::FileProvider",
        "refreshEnd",
        "",
        "QList<QUrl>",
        "urls",
        "fileRemoved",
        "QUrl",
        "url",
        "fileInserted",
        "fileRenamed",
        "oldurl",
        "newurl",
        "fileUpdated",
        "fileInfoUpdated",
        "isLinkOrg",
        "fileThumbUpdated",
        "thumb",
        "traversalFinished",
        "reset",
        "children",
        "insert",
        "remove",
        "rename",
        "oldUrl",
        "newUrl",
        "update",
        "preupdateData",
        "onFileInfoUpdated",
        "infoPtr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshEnd'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileRemoved'
        QtMocHelpers::SignalData<void(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'fileInserted'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'fileRenamed'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 },
        }}),
        // Signal 'fileUpdated'
        QtMocHelpers::SignalData<void(const QUrl &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'fileInfoUpdated'
        QtMocHelpers::SignalData<void(const QUrl &, const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'fileThumbUpdated'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'traversalFinished'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void(QList<QUrl>)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 19 },
        }}),
        // Slot 'insert'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(const QUrl &)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'rename'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 23 }, { 0x80000000 | 6, 24 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void(const QUrl &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'preupdateData'
        QtMocHelpers::SlotData<void(const QUrl &)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'onFileInfoUpdated'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const bool)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileProvider, qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::FileProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::FileProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshEnd((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 1: _t->fileRemoved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->fileInserted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->fileRenamed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 4: _t->fileUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->fileInfoUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->fileThumbUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->traversalFinished(); break;
        case 8: _t->reset((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 9: _t->insert((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->remove((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->rename((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 12: _t->update((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->preupdateData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->onFileInfoUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QList<QUrl> & )>(_a, &FileProvider::refreshEnd, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & )>(_a, &FileProvider::fileRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & )>(_a, &FileProvider::fileInserted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & , const QUrl & )>(_a, &FileProvider::fileRenamed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & )>(_a, &FileProvider::fileUpdated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & , const bool )>(_a, &FileProvider::fileInfoUpdated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileProvider::*)(const QUrl & , const QString & )>(_a, &FileProvider::fileThumbUpdated, 6))
            return;
    }
}

const QMetaObject *ddplugin_canvas::FileProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::FileProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas12FileProviderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_canvas::FileProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_canvas::FileProvider::refreshEnd(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ddplugin_canvas::FileProvider::fileRemoved(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ddplugin_canvas::FileProvider::fileInserted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ddplugin_canvas::FileProvider::fileRenamed(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ddplugin_canvas::FileProvider::fileUpdated(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ddplugin_canvas::FileProvider::fileInfoUpdated(const QUrl & _t1, const bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void ddplugin_canvas::FileProvider::fileThumbUpdated(const QUrl & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
