/****************************************************************************
** Meta object code from reading C++ file 'diskencryptadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "diskencryptadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'diskencryptadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18DiskEncryptAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DiskEncryptAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN18DiskEncryptAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiskEncryptAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.DiskEncrypt",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.DiskEncrypt\">\n    <si"
        "gnal name=\"PrepareEncryptDiskResult\">\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"device\"/>\n      <arg direction=\"out\" typ"
        "e=\"s\" name=\"devName\"/>\n      <arg direction=\"out\" type=\"s\""
        " name=\"jobID\"/>\n      <arg direction=\"out\" type=\"i\" name=\""
        "errCode\"/>\n    </signal>\n    <signal name=\"EncryptDiskResult\""
        ">\n      <arg direction=\"out\" type=\"s\" name=\"device\"/>\n    "
        "  <arg direction=\"out\" type=\"s\" name=\"devName\"/>\n      <arg"
        " direction=\"out\" type=\"i\" name=\"errCode\"/>\n      <arg direc"
        "tion=\"out\" type=\"s\" name=\"msg\"/>\n    </signal>\n    <signal"
        " name=\"DecryptDiskResult\">\n      <arg direction=\"out\" type=\""
        "s\" name=\"device\"/>\n      <arg direction=\"out\" type=\"s\" nam"
        "e=\"devName\"/>\n      <arg direction=\"out\" type=\"s\" name=\"jo"
        "bID\"/>\n      <arg direction=\"out\" type=\"i\" name=\"errCode\"/"
        ">\n    </signal>\n    <signal name=\"ChangePassphressResult\">\n  "
        "    <arg direction=\"out\" type=\"s\" name=\"device\"/>\n      <ar"
        "g direction=\"out\" type=\"s\" name=\"devName\"/>\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"jobID\"/>\n      <arg direction=\""
        "out\" type=\"i\" name=\"errCode\"/>\n    </signal>\n    <signal na"
        "me=\"EncryptProgress\">\n      <arg direction=\"out\" type=\"s\" n"
        "ame=\"device\"/>\n      <arg direction=\"out\" type=\"s\" name=\"d"
        "evName\"/>\n      <arg direction=\"out\" type=\"d\" name=\"progres"
        "s\"/>\n    </signal>\n    <signal name=\"DecryptProgress\">\n     "
        " <arg direction=\"out\" type=\"s\" name=\"device\"/>\n      <arg d"
        "irection=\"out\" type=\"s\" name=\"devName\"/>\n      <arg directi"
        "on=\"out\" type=\"d\" name=\"progress\"/>\n    </signal>\n    <sig"
        "nal name=\"RequestEncryptParams\">\n      <arg direction=\"out\" t"
        "ype=\"a{sv}\" name=\"encConfig\"/>\n      <annotation value=\"QVar"
        "iantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </s"
        "ignal>\n    <method name=\"PrepareEncryptDisk\">\n      <arg direc"
        "tion=\"out\" type=\"s\"/>\n      <arg direction=\"in\" type=\"a{sv"
        "}\" name=\"params\"/>\n      <annotation value=\"QVariantMap\" nam"
        "e=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <m"
        "ethod name=\"DecryptDisk\">\n      <arg direction=\"out\" type=\"s"
        "\"/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\"params\"/>"
        "\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtD"
        "Bus.QtTypeName.In0\"/>\n    </method>\n    <method name=\"ChangeEn"
        "cryptPassphress\">\n      <arg direction=\"out\" type=\"s\"/>\n   "
        "   <arg direction=\"in\" type=\"a{sv}\" name=\"params\"/>\n      <"
        "annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTyp"
        "eName.In0\"/>\n    </method>\n    <method name=\"IgnoreParamReques"
        "t\"/>\n    <method name=\"ResumeEncryption\">\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"device\"/>\n    </method>\n    <method "
        "name=\"SetEncryptParams\">\n      <arg direction=\"in\" type=\"a{s"
        "v}\" name=\"params\"/>\n      <annotation value=\"QVariantMap\" na"
        "me=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n    <"
        "method name=\"QueryTPMToken\">\n      <arg direction=\"out\" type="
        "\"s\"/>\n      <arg direction=\"in\" type=\"s\" name=\"device\"/>\n"
        "    </method>\n    <method name=\"EncryptStatus\">\n      <arg dir"
        "ection=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"device\"/>\n    </method>\n    <method name=\"HasPendingTa"
        "sk\">\n      <arg direction=\"out\" type=\"b\"/>\n    </method>\n "
        "   <method name=\"IsWorkerRunning\">\n      <arg direction=\"out\""
        " type=\"b\"/>\n    </method>\n    <method name=\"UnfinishedDecrypt"
        "Job\">\n      <arg direction=\"out\" type=\"s\"/>\n    </method>\n"
        "  </interface>\n",
        "ChangePassphressResult",
        "",
        "device",
        "devName",
        "jobID",
        "errCode",
        "DecryptDiskResult",
        "DecryptProgress",
        "progress",
        "EncryptDiskResult",
        "msg",
        "EncryptProgress",
        "PrepareEncryptDiskResult",
        "RequestEncryptParams",
        "QVariantMap",
        "encConfig",
        "ChangeEncryptPassphress",
        "params",
        "DecryptDisk",
        "EncryptStatus",
        "HasPendingTask",
        "IgnoreParamRequest",
        "IsWorkerRunning",
        "PrepareEncryptDisk",
        "QueryTPMToken",
        "ResumeEncryption",
        "SetEncryptParams",
        "UnfinishedDecryptJob"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ChangePassphressResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'DecryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'DecryptProgress'
        QtMocHelpers::SignalData<void(const QString &, const QString &, double)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::Double, 13 },
        }}),
        // Signal 'EncryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, int, const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::Int, 10 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'EncryptProgress'
        QtMocHelpers::SignalData<void(const QString &, const QString &, double)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::Double, 13 },
        }}),
        // Signal 'PrepareEncryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::Int, 10 },
        }}),
        // Signal 'RequestEncryptParams'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'ChangeEncryptPassphress'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(21, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 19, 22 },
        }}),
        // Slot 'DecryptDisk'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(23, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 19, 22 },
        }}),
        // Slot 'EncryptStatus'
        QtMocHelpers::SlotData<int(const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'HasPendingTask'
        QtMocHelpers::SlotData<bool()>(25, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'IgnoreParamRequest'
        QtMocHelpers::SlotData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'IsWorkerRunning'
        QtMocHelpers::SlotData<bool()>(27, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'PrepareEncryptDisk'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(28, 6, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 19, 22 },
        }}),
        // Slot 'QueryTPMToken'
        QtMocHelpers::SlotData<QString(const QString &)>(29, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'ResumeEncryption'
        QtMocHelpers::SlotData<void(const QString &)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'SetEncryptParams'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 22 },
        }}),
        // Slot 'UnfinishedDecryptJob'
        QtMocHelpers::SlotData<QString()>(32, 6, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DiskEncryptAdaptor, qt_meta_tag_ZN18DiskEncryptAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DiskEncryptAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DiskEncryptAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DiskEncryptAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18DiskEncryptAdaptorE_t>.metaTypes,
    nullptr
} };

void DiskEncryptAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiskEncryptAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ChangePassphressResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 1: _t->DecryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 2: _t->DecryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 3: _t->EncryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 4: _t->EncryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 5: _t->PrepareEncryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 6: _t->RequestEncryptParams((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: { QString _r = _t->ChangeEncryptPassphress((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->DecryptDisk((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->EncryptStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->HasPendingTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->IgnoreParamRequest(); break;
        case 12: { bool _r = _t->IsWorkerRunning();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { QString _r = _t->PrepareEncryptDisk((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->QueryTPMToken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->ResumeEncryption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->SetEncryptParams((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 17: { QString _r = _t->UnfinishedDecryptJob();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptAdaptor::ChangePassphressResult, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptAdaptor::DecryptDiskResult, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , double )>(_a, &DiskEncryptAdaptor::DecryptProgress, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , int , const QString & )>(_a, &DiskEncryptAdaptor::EncryptDiskResult, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , double )>(_a, &DiskEncryptAdaptor::EncryptProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptAdaptor::PrepareEncryptDiskResult, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptAdaptor::*)(const QVariantMap & )>(_a, &DiskEncryptAdaptor::RequestEncryptParams, 6))
            return;
    }
}

const QMetaObject *DiskEncryptAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiskEncryptAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18DiskEncryptAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DiskEncryptAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void DiskEncryptAdaptor::ChangePassphressResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void DiskEncryptAdaptor::DecryptDiskResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void DiskEncryptAdaptor::DecryptProgress(const QString & _t1, const QString & _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void DiskEncryptAdaptor::EncryptDiskResult(const QString & _t1, const QString & _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void DiskEncryptAdaptor::EncryptProgress(const QString & _t1, const QString & _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void DiskEncryptAdaptor::PrepareEncryptDiskResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 6
void DiskEncryptAdaptor::RequestEncryptParams(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
