/****************************************************************************
** Meta object code from reading C++ file 'mountcontroladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mountcontroladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mountcontroladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19MountControlAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto MountControlAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19MountControlAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MountControlAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.MountControl",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.MountControl\">\n    <m"
        "ethod name=\"Mount\">\n      <arg direction=\"out\" type=\"a{sv}\""
        "/>\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.Q"
        "tDBus.QtTypeName.Out0\"/>\n      <arg direction=\"in\" type=\"s\" "
        "name=\"path\"/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\""
        "opts\"/>\n      <annotation value=\"QVariantMap\" name=\"org.qtpro"
        "ject.QtDBus.QtTypeName.In1\"/>\n    </method>\n    <method name=\""
        "Unmount\">\n      <arg direction=\"out\" type=\"a{sv}\"/>\n      <"
        "annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTyp"
        "eName.Out0\"/>\n      <arg direction=\"in\" type=\"s\" name=\"path"
        "\"/>\n      <arg direction=\"in\" type=\"a{sv}\" name=\"opts\"/>\n"
        "      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBu"
        "s.QtTypeName.In1\"/>\n    </method>\n    <method name=\"SupportedF"
        "ileSystems\">\n      <arg direction=\"out\" type=\"as\"/>\n    </m"
        "ethod>\n  </interface>\n",
        "Mount",
        "QVariantMap",
        "",
        "path",
        "opts",
        "SupportedFileSystems",
        "Unmount"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Mount'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QVariantMap &)>(5, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 6, 9 },
        }}),
        // Slot 'SupportedFileSystems'
        QtMocHelpers::SlotData<QStringList()>(10, 7, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'Unmount'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QVariantMap &)>(11, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 6, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<MountControlAdaptor, qt_meta_tag_ZN19MountControlAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MountControlAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MountControlAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MountControlAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19MountControlAdaptorE_t>.metaTypes,
    nullptr
} };

void MountControlAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MountControlAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QVariantMap _r = _t->Mount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 1: { QStringList _r = _t->SupportedFileSystems();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVariantMap _r = _t->Unmount((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *MountControlAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MountControlAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MountControlAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int MountControlAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
