/****************************************************************************
** Meta object code from reading C++ file 'docopyfileworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-fileoperations/fileoperations/fileoperationutils/docopyfileworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'docopyfileworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_fileoperations::DoCopyFileWorker::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_fileoperations::DoCopyFileWorker",
        "ErrorFinished",
        "",
        "CompleteSize",
        "size",
        "currentTask",
        "QUrl",
        "source",
        "target",
        "errorNotify",
        "from",
        "to",
        "AbstractJobHandler::JobErrorType",
        "error",
        "isTo",
        "id",
        "errorMsg",
        "allUsErrorMsg",
        "retryErrSuccess",
        "skipCopyLocalBigFile",
        "fromUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ErrorFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'CompleteSize'
        QtMocHelpers::SignalData<void(const int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'currentTask'
        QtMocHelpers::SignalData<void(const QUrl, const QUrl)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 },
        }}),
        // Signal 'errorNotify'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &, const AbstractJobHandler::JobErrorType &, const bool, const quint64, const QString &, const bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 10 }, { 0x80000000 | 6, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::Bool, 14 },
            { QMetaType::ULongLong, 15 }, { QMetaType::QString, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'retryErrSuccess'
        QtMocHelpers::SignalData<void(const quint64)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 15 },
        }}),
        // Signal 'skipCopyLocalBigFile'
        QtMocHelpers::SignalData<void(const QUrl)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DoCopyFileWorker, qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_fileoperations::DoCopyFileWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_fileoperations::DoCopyFileWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DoCopyFileWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ErrorFinished(); break;
        case 1: _t->CompleteSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->currentTask((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 3: _t->errorNotify((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<AbstractJobHandler::JobErrorType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7]))); break;
        case 4: _t->retryErrSuccess((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 5: _t->skipCopyLocalBigFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)()>(_a, &DoCopyFileWorker::ErrorFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)(const int )>(_a, &DoCopyFileWorker::CompleteSize, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)(const QUrl , const QUrl )>(_a, &DoCopyFileWorker::currentTask, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)(const QUrl & , const QUrl & , const AbstractJobHandler::JobErrorType & , const bool , const quint64 , const QString & , const bool )>(_a, &DoCopyFileWorker::errorNotify, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)(const quint64 )>(_a, &DoCopyFileWorker::retryErrSuccess, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DoCopyFileWorker::*)(const QUrl )>(_a, &DoCopyFileWorker::skipCopyLocalBigFile, 5))
            return;
    }
}

const QMetaObject *dfmplugin_fileoperations::DoCopyFileWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_fileoperations::DoCopyFileWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations16DoCopyFileWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_fileoperations::DoCopyFileWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_fileoperations::DoCopyFileWorker::ErrorFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmplugin_fileoperations::DoCopyFileWorker::CompleteSize(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_fileoperations::DoCopyFileWorker::currentTask(const QUrl _t1, const QUrl _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmplugin_fileoperations::DoCopyFileWorker::errorNotify(const QUrl & _t1, const QUrl & _t2, const AbstractJobHandler::JobErrorType & _t3, const bool _t4, const quint64 _t5, const QString & _t6, const bool _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 4
void dfmplugin_fileoperations::DoCopyFileWorker::retryErrSuccess(const quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmplugin_fileoperations::DoCopyFileWorker::skipCopyLocalBigFile(const QUrl _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
