/****************************************************************************
** Meta object code from reading C++ file 'dfmplugin_detailspace_global.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-detailspace/dfmplugin_detailspace_global.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dfmplugin_detailspace_global.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21dfmplugin_detailspaceE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_detailspace::qt_create_metaobjectdata<qt_meta_tag_ZN21dfmplugin_detailspaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_detailspace",
        "DetailFilterType",
        "kNotFilter",
        "kBasicView",
        "kIconView",
        "kFileNameField",
        "kFileSizeField",
        "kFileViewSizeField",
        "kFileDurationField",
        "kFileTypeField",
        "kFileInterviewTimeField",
        "kFileChangeTimeField",
        "BasicFieldExpandEnum",
        "kNotAll",
        "kFileName",
        "kFileSize",
        "kFileViewSize",
        "kFileDuration",
        "kFileType",
        "kFileInterviewTime",
        "kFileChangeTIme",
        "BasicExpandType",
        "kFieldInsert",
        "kFieldReplace"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DetailFilterType'
        QtMocHelpers::EnumData<DetailFilterType>(1, 1, QMC::EnumFlags{}).add({
            {    2, DetailFilterType::kNotFilter },
            {    3, DetailFilterType::kBasicView },
            {    4, DetailFilterType::kIconView },
            {    5, DetailFilterType::kFileNameField },
            {    6, DetailFilterType::kFileSizeField },
            {    7, DetailFilterType::kFileViewSizeField },
            {    8, DetailFilterType::kFileDurationField },
            {    9, DetailFilterType::kFileTypeField },
            {   10, DetailFilterType::kFileInterviewTimeField },
            {   11, DetailFilterType::kFileChangeTimeField },
        }),
        // enum 'BasicFieldExpandEnum'
        QtMocHelpers::EnumData<BasicFieldExpandEnum>(12, 12, QMC::EnumFlags{}).add({
            {   13, BasicFieldExpandEnum::kNotAll },
            {   14, BasicFieldExpandEnum::kFileName },
            {   15, BasicFieldExpandEnum::kFileSize },
            {   16, BasicFieldExpandEnum::kFileViewSize },
            {   17, BasicFieldExpandEnum::kFileDuration },
            {   18, BasicFieldExpandEnum::kFileType },
            {   19, BasicFieldExpandEnum::kFileInterviewTime },
            {   20, BasicFieldExpandEnum::kFileChangeTIme },
        }),
        // enum 'BasicExpandType'
        QtMocHelpers::EnumData<BasicExpandType>(21, 21, QMC::EnumFlags{}).add({
            {   22, BasicExpandType::kFieldInsert },
            {   23, BasicExpandType::kFieldReplace },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN21dfmplugin_detailspaceE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN21dfmplugin_detailspaceE =
    dfmplugin_detailspace::qt_create_metaobjectdata<qt_meta_tag_ZN21dfmplugin_detailspaceE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN21dfmplugin_detailspaceE =
    qt_staticMetaObjectContent_ZN21dfmplugin_detailspaceE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN21dfmplugin_detailspaceE =
    qt_staticMetaObjectContent_ZN21dfmplugin_detailspaceE.relocatingData;

Q_CONSTINIT const QMetaObject dfmplugin_detailspace::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN21dfmplugin_detailspaceE.stringdata,
    qt_staticMetaObjectStaticContent_ZN21dfmplugin_detailspaceE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN21dfmplugin_detailspaceE.metaTypes,
    nullptr
} };

QT_WARNING_POP
