/****************************************************************************
** Meta object code from reading C++ file 'recentiterateworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/daemon/recent/recentiterateworker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recentiterateworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto serverplugin_recentmanager::RecentIterateWorker::qt_create_metaobjectdata<qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "serverplugin_recentmanager::RecentIterateWorker",
        "reloadFinished",
        "",
        "timestamp",
        "purgeFinished",
        "itemAdded",
        "path",
        "RecentItem",
        "item",
        "itemsRemoved",
        "paths",
        "itemChanged",
        "onRequestReload",
        "xbelPath",
        "onRequestAddRecentItem",
        "QVariantMap",
        "onRequestRemoveItems",
        "hrefs",
        "onRequestPurgeItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'reloadFinished'
        QtMocHelpers::SignalData<void(qint64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Signal 'purgeFinished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const QString &, const RecentItem &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'itemsRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void(const QString &, const RecentItem &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onRequestReload'
        QtMocHelpers::SlotData<void(const QString &, qint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::LongLong, 3 },
        }}),
        // Slot 'onRequestAddRecentItem'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 8 },
        }}),
        // Slot 'onRequestRemoveItems'
        QtMocHelpers::SlotData<void(const QStringList &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Slot 'onRequestPurgeItems'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecentIterateWorker, qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject serverplugin_recentmanager::RecentIterateWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>.metaTypes,
    nullptr
} };

void serverplugin_recentmanager::RecentIterateWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecentIterateWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadFinished((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: _t->purgeFinished(); break;
        case 2: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RecentItem>>(_a[2]))); break;
        case 3: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RecentItem>>(_a[2]))); break;
        case 5: _t->onRequestReload((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 6: _t->onRequestAddRecentItem((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: _t->onRequestRemoveItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->onRequestPurgeItems((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecentIterateWorker::*)(qint64 )>(_a, &RecentIterateWorker::reloadFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentIterateWorker::*)()>(_a, &RecentIterateWorker::purgeFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentIterateWorker::*)(const QString & , const RecentItem & )>(_a, &RecentIterateWorker::itemAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentIterateWorker::*)(const QStringList & )>(_a, &RecentIterateWorker::itemsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentIterateWorker::*)(const QString & , const RecentItem & )>(_a, &RecentIterateWorker::itemChanged, 4))
            return;
    }
}

const QMetaObject *serverplugin_recentmanager::RecentIterateWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *serverplugin_recentmanager::RecentIterateWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager19RecentIterateWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int serverplugin_recentmanager::RecentIterateWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void serverplugin_recentmanager::RecentIterateWorker::reloadFinished(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void serverplugin_recentmanager::RecentIterateWorker::purgeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void serverplugin_recentmanager::RecentIterateWorker::itemAdded(const QString & _t1, const RecentItem & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void serverplugin_recentmanager::RecentIterateWorker::itemsRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void serverplugin_recentmanager::RecentIterateWorker::itemChanged(const QString & _t1, const RecentItem & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
