/****************************************************************************
** Meta object code from reading C++ file 'textindex_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "textindex_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textindex_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgDeepinFilemanagerTextIndexInterface::qt_create_metaobjectdata<qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgDeepinFilemanagerTextIndexInterface",
        "TaskFinished",
        "",
        "type",
        "path",
        "success",
        "TaskProgressChanged",
        "count",
        "CreateIndexTask",
        "QDBusPendingReply<bool>",
        "GetLastUpdateTime",
        "QDBusPendingReply<QString>",
        "HasRunningTask",
        "IndexDatabaseExists",
        "RemoveIndexTask",
        "paths",
        "StopCurrentTask",
        "UpdateIndexTask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TaskFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'TaskProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::LongLong, 7 },
        }}),
        // Slot 'CreateIndexTask'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'GetLastUpdateTime'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'HasRunningTask'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(12, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'IndexDatabaseExists'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(13, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'RemoveIndexTask'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QStringList &)>(14, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Slot 'StopCurrentTask'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(16, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'UpdateIndexTask'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgDeepinFilemanagerTextIndexInterface, qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgDeepinFilemanagerTextIndexInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgDeepinFilemanagerTextIndexInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgDeepinFilemanagerTextIndexInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TaskFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->TaskProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 2: { QDBusPendingReply<bool> _r = _t->CreateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->GetLastUpdateTime();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->HasRunningTask();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->IndexDatabaseExists();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<bool> _r = _t->RemoveIndexTask((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<bool> _r = _t->StopCurrentTask();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->UpdateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerTextIndexInterface::*)(const QString & , const QString & , bool )>(_a, &OrgDeepinFilemanagerTextIndexInterface::TaskFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerTextIndexInterface::*)(const QString & , const QString & , qlonglong )>(_a, &OrgDeepinFilemanagerTextIndexInterface::TaskProgressChanged, 1))
            return;
    }
}

const QMetaObject *OrgDeepinFilemanagerTextIndexInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgDeepinFilemanagerTextIndexInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38OrgDeepinFilemanagerTextIndexInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgDeepinFilemanagerTextIndexInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void OrgDeepinFilemanagerTextIndexInterface::TaskFinished(const QString & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void OrgDeepinFilemanagerTextIndexInterface::TaskProgressChanged(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
