/****************************************************************************
** Meta object code from reading C++ file 'recentmanager_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "recentmanager_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recentmanager_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgDeepinFilemanagerDaemonRecentManagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgDeepinFilemanagerDaemonRecentManagerInterface",
        "ItemAdded",
        "",
        "path",
        "href",
        "modified",
        "ItemChanged",
        "ItemsRemoved",
        "paths",
        "PurgeFinished",
        "ReloadFinished",
        "timestamp",
        "AddItem",
        "QDBusPendingReply<>",
        "QVariantMap",
        "item",
        "GetItemInfo",
        "QDBusPendingReply<QVariantMap>",
        "GetItemsInfo",
        "QDBusPendingReply<QVariantList>",
        "GetItemsPath",
        "QDBusPendingReply<QStringList>",
        "PurgeItems",
        "Reload",
        "QDBusPendingReply<qlonglong>",
        "RemoveItems",
        "hrefs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ItemAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'ItemChanged'
        QtMocHelpers::SignalData<void(const QString &, qlonglong)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::LongLong, 5 },
        }}),
        // Signal 'ItemsRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 },
        }}),
        // Signal 'PurgeFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ReloadFinished'
        QtMocHelpers::SignalData<void(qlonglong)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 11 },
        }}),
        // Slot 'AddItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QVariantMap &)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'GetItemInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetItemsInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantList>()>(18, 2, QMC::AccessPublic, 0x80000000 | 19),
        // Slot 'GetItemsPath'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(20, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'PurgeItems'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'Reload'
        QtMocHelpers::SlotData<QDBusPendingReply<qlonglong>()>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'RemoveItems'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(25, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QStringList, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgDeepinFilemanagerDaemonRecentManagerInterface, qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgDeepinFilemanagerDaemonRecentManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgDeepinFilemanagerDaemonRecentManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgDeepinFilemanagerDaemonRecentManagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ItemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 1: _t->ItemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 2: _t->ItemsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->PurgeFinished(); break;
        case 4: _t->ReloadFinished((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 5: { QDBusPendingReply<> _r = _t->AddItem((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QVariantMap> _r = _t->GetItemInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<QVariantList> _r = _t->GetItemsInfo();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantList>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<QStringList> _r = _t->GetItemsPath();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->PurgeItems();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<qlonglong> _r = _t->Reload();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qlonglong>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->RemoveItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonRecentManagerInterface::*)(const QString & , const QString & , qlonglong )>(_a, &OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonRecentManagerInterface::*)(const QString & , qlonglong )>(_a, &OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonRecentManagerInterface::*)(const QStringList & )>(_a, &OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemsRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonRecentManagerInterface::*)()>(_a, &OrgDeepinFilemanagerDaemonRecentManagerInterface::PurgeFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonRecentManagerInterface::*)(qlonglong )>(_a, &OrgDeepinFilemanagerDaemonRecentManagerInterface::ReloadFinished, 4))
            return;
    }
}

const QMetaObject *OrgDeepinFilemanagerDaemonRecentManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgDeepinFilemanagerDaemonRecentManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN48OrgDeepinFilemanagerDaemonRecentManagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgDeepinFilemanagerDaemonRecentManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemAdded(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemChanged(const QString & _t1, qlonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OrgDeepinFilemanagerDaemonRecentManagerInterface::ItemsRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgDeepinFilemanagerDaemonRecentManagerInterface::PurgeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void OrgDeepinFilemanagerDaemonRecentManagerInterface::ReloadFinished(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
