/****************************************************************************
** Meta object code from reading C++ file 'canvasviewshell.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/interface/canvasviewshell.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasviewshell.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::CanvasViewShell::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::CanvasViewShell",
        "filterDropData",
        "",
        "viewIndex",
        "const QMimeData*",
        "mimeData",
        "QPoint",
        "viewPos",
        "extData",
        "filterShortcutkeyPress",
        "key",
        "modifiers",
        "filterKeyPress",
        "filterWheel",
        "angleDelta",
        "ctrl",
        "filterContextMenu",
        "QUrl",
        "dir",
        "QList<QUrl>",
        "files",
        "eventDropData",
        "viewPoint",
        "eventKeyPress",
        "eventShortcutkeyPress",
        "eventWheel",
        "eventContextMenu"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterDropData'
        QtMocHelpers::SignalData<bool(int, const QMimeData *, const QPoint &, void *)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::VoidStar, 8 },
        }}),
        // Signal 'filterShortcutkeyPress'
        QtMocHelpers::SignalData<bool(int, int, int)>(9, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'filterKeyPress'
        QtMocHelpers::SignalData<bool(int, int, int)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'filterWheel'
        QtMocHelpers::SignalData<bool(int, const QPoint &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 6, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Signal 'filterContextMenu'
        QtMocHelpers::SignalData<bool(int, const QUrl &, const QList<QUrl> &, const QPoint &)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'eventDropData'
        QtMocHelpers::SlotData<bool(int, const QMimeData *, const QPoint &, void *)>(21, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 22 }, { QMetaType::VoidStar, 8 },
        }}),
        // Slot 'eventKeyPress'
        QtMocHelpers::SlotData<bool(int, int, int, void *)>(23, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::VoidStar, 8 },
        }}),
        // Slot 'eventKeyPress'
        QtMocHelpers::SlotData<bool(int, int, int)>(23, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'eventShortcutkeyPress'
        QtMocHelpers::SlotData<bool(int, int, int, void *)>(24, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::VoidStar, 8 },
        }}),
        // Slot 'eventShortcutkeyPress'
        QtMocHelpers::SlotData<bool(int, int, int)>(24, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'eventWheel'
        QtMocHelpers::SlotData<bool(int, const QPoint &, void *)>(25, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 6, 14 }, { QMetaType::VoidStar, 8 },
        }}),
        // Slot 'eventContextMenu'
        QtMocHelpers::SlotData<bool(int, const QUrl &, const QList<QUrl> &, const QPoint &, void *)>(26, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 6, 7 },
            { QMetaType::VoidStar, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasViewShell, qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::CanvasViewShell::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::CanvasViewShell::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasViewShell *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->filterDropData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->filterShortcutkeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->filterKeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->filterWheel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->filterContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->eventDropData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->eventKeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->eventKeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->eventShortcutkeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->eventShortcutkeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->eventWheel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->eventContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<bool (CanvasViewShell::*)(int , const QMimeData * , const QPoint & , void * )>(_a, &CanvasViewShell::filterDropData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<bool (CanvasViewShell::*)(int , int , int )>(_a, &CanvasViewShell::filterShortcutkeyPress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<bool (CanvasViewShell::*)(int , int , int )>(_a, &CanvasViewShell::filterKeyPress, 2))
            return;
        if (QtMocHelpers::indexOfMethod<bool (CanvasViewShell::*)(int , const QPoint & , bool )>(_a, &CanvasViewShell::filterWheel, 3))
            return;
        if (QtMocHelpers::indexOfMethod<bool (CanvasViewShell::*)(int , const QUrl & , const QList<QUrl> & , const QPoint & )>(_a, &CanvasViewShell::filterContextMenu, 4))
            return;
    }
}

const QMetaObject *ddplugin_organizer::CanvasViewShell::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::CanvasViewShell::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasViewShellE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_organizer::CanvasViewShell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
bool ddplugin_organizer::CanvasViewShell::filterDropData(int _t1, const QMimeData * _t2, const QPoint & _t3, void * _t4)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 0, std::addressof(_t0), _t1, _t2, _t3, _t4);
    return _t0;
}

// SIGNAL 1
bool ddplugin_organizer::CanvasViewShell::filterShortcutkeyPress(int _t1, int _t2, int _t3)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 1, std::addressof(_t0), _t1, _t2, _t3);
    return _t0;
}

// SIGNAL 2
bool ddplugin_organizer::CanvasViewShell::filterKeyPress(int _t1, int _t2, int _t3)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 2, std::addressof(_t0), _t1, _t2, _t3);
    return _t0;
}

// SIGNAL 3
bool ddplugin_organizer::CanvasViewShell::filterWheel(int _t1, const QPoint & _t2, bool _t3)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 3, std::addressof(_t0), _t1, _t2, _t3);
    return _t0;
}

// SIGNAL 4
bool ddplugin_organizer::CanvasViewShell::filterContextMenu(int _t1, const QUrl & _t2, const QList<QUrl> & _t3, const QPoint & _t4)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 4, std::addressof(_t0), _t1, _t2, _t3, _t4);
    return _t0;
}
QT_WARNING_POP
