/****************************************************************************
** Meta object code from reading C++ file 'reportlogmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/reportlog/reportlogmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'reportlogmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_utils::ReportLogManager::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_utils::ReportLogManager",
        "requestCommitLog",
        "",
        "type",
        "QVariantMap",
        "args",
        "requestReportMenuData",
        "name",
        "QList<QUrl>",
        "urlList",
        "requestReportNetworkMountData",
        "ret",
        "dfmmount::DeviceError",
        "err",
        "msg",
        "requestReportBlockMountData",
        "id",
        "result",
        "requestReportDesktopStartUp",
        "key",
        "QVariant",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestCommitLog'
        QtMocHelpers::SignalData<void(const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'requestReportMenuData'
        QtMocHelpers::SignalData<void(const QString &, const QList<QUrl> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'requestReportNetworkMountData'
        QtMocHelpers::SignalData<void(bool, dfmmount::DeviceError, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'requestReportBlockMountData'
        QtMocHelpers::SignalData<void(const QString &, bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'requestReportDesktopStartUp'
        QtMocHelpers::SignalData<void(const QString &, const QVariant &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReportLogManager, qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_utils::ReportLogManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_utils::ReportLogManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReportLogManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestCommitLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 1: _t->requestReportMenuData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 2: _t->requestReportNetworkMountData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmmount::DeviceError>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->requestReportBlockMountData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->requestReportDesktopStartUp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReportLogManager::*)(const QString & , const QVariantMap & )>(_a, &ReportLogManager::requestCommitLog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportLogManager::*)(const QString & , const QList<QUrl> & )>(_a, &ReportLogManager::requestReportMenuData, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportLogManager::*)(bool , dfmmount::DeviceError , const QString & )>(_a, &ReportLogManager::requestReportNetworkMountData, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportLogManager::*)(const QString & , bool )>(_a, &ReportLogManager::requestReportBlockMountData, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReportLogManager::*)(const QString & , const QVariant & )>(_a, &ReportLogManager::requestReportDesktopStartUp, 4))
            return;
    }
}

const QMetaObject *dfmplugin_utils::ReportLogManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::ReportLogManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16ReportLogManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::ReportLogManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::ReportLogManager::requestCommitLog(const QString & _t1, const QVariantMap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmplugin_utils::ReportLogManager::requestReportMenuData(const QString & _t1, const QList<QUrl> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void dfmplugin_utils::ReportLogManager::requestReportNetworkMountData(bool _t1, dfmmount::DeviceError _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void dfmplugin_utils::ReportLogManager::requestReportBlockMountData(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dfmplugin_utils::ReportLogManager::requestReportDesktopStartUp(const QString & _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
