/****************************************************************************
** Meta object code from reading C++ file 'tagmanager_interface_qt6.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "tagmanager_interface_qt6.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tagmanager_interface_qt6.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgDeepinFilemanagerDaemonTagManagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgDeepinFilemanagerDaemonTagManagerInterface",
        "FilesTagged",
        "",
        "QVariantMap",
        "fileAndTags",
        "FilesUntagged",
        "NewTagsAdded",
        "tags",
        "TagsColorChanged",
        "oldAndNew",
        "TagsDeleted",
        "TagsNameChanged",
        "TagsServiceReady",
        "Delete",
        "QDBusPendingReply<bool>",
        "opt",
        "value",
        "Insert",
        "Query",
        "QDBusPendingReply<QDBusVariant>",
        "Update"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'FilesTagged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'FilesUntagged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'NewTagsAdded'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Signal 'TagsColorChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Signal 'TagsDeleted'
        QtMocHelpers::SignalData<void(const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'TagsNameChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Signal 'TagsServiceReady'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QVariantMap &)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 3, 16 },
        }}),
        // Slot 'Insert'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QVariantMap &)>(17, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 3, 16 },
        }}),
        // Slot 'Query'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(int)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'Query'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(int, const QStringList &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::Int, 15 }, { QMetaType::QStringList, 16 },
        }}),
        // Slot 'Update'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QVariantMap &)>(20, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 3, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgDeepinFilemanagerDaemonTagManagerInterface, qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgDeepinFilemanagerDaemonTagManagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgDeepinFilemanagerDaemonTagManagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgDeepinFilemanagerDaemonTagManagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->FilesTagged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->FilesUntagged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->NewTagsAdded((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->TagsColorChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->TagsDeleted((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->TagsNameChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 6: _t->TagsServiceReady(); break;
        case 7: { QDBusPendingReply<bool> _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->Insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QDBusVariant> _r = _t->Query((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<QDBusVariant> _r = _t->Query((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<bool> _r = _t->Update((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QVariantMap & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::FilesTagged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QVariantMap & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::FilesUntagged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QVariantMap & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::NewTagsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QVariantMap & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::TagsColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QStringList & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::TagsDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)(const QVariantMap & )>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::TagsNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgDeepinFilemanagerDaemonTagManagerInterface::*)()>(_a, &OrgDeepinFilemanagerDaemonTagManagerInterface::TagsServiceReady, 6))
            return;
    }
}

const QMetaObject *OrgDeepinFilemanagerDaemonTagManagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgDeepinFilemanagerDaemonTagManagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgDeepinFilemanagerDaemonTagManagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgDeepinFilemanagerDaemonTagManagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OrgDeepinFilemanagerDaemonTagManagerInterface::FilesTagged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgDeepinFilemanagerDaemonTagManagerInterface::FilesUntagged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgDeepinFilemanagerDaemonTagManagerInterface::NewTagsAdded(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgDeepinFilemanagerDaemonTagManagerInterface::TagsColorChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgDeepinFilemanagerDaemonTagManagerInterface::TagsDeleted(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgDeepinFilemanagerDaemonTagManagerInterface::TagsNameChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgDeepinFilemanagerDaemonTagManagerInterface::TagsServiceReady()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
