/****************************************************************************
** Meta object code from reading C++ file 'vaultmanagerdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/daemon/vault/dbus/vaultmanagerdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaultmanagerdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16VaultManagerDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto VaultManagerDBus::qt_create_metaobjectdata<qt_meta_tag_ZN16VaultManagerDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VaultManagerDBus",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.VaultManager",
        "LockEventTriggered",
        "",
        "user",
        "ChangedVaultState",
        "QVariantMap",
        "map",
        "SysUserChanged",
        "curUser",
        "SetRefreshTime",
        "time",
        "GetLastestTime",
        "GetSelfTime",
        "IsLockEventTriggered",
        "TriggerLockEvent",
        "ClearLockEvent",
        "ComputerSleep",
        "bSleep",
        "GetLeftoverErrorInputTimes",
        "userID",
        "LeftoverErrorInputTimesMinusOne",
        "RestoreLeftoverErrorInputTimes",
        "StartTimerOfRestorePasswordInput",
        "GetNeedWaitMinutes",
        "RestoreNeedWaitMinutes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'LockEventTriggered'
        QtMocHelpers::SignalData<void(QString)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'ChangedVaultState'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'SysUserChanged'
        QtMocHelpers::SlotData<void(const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'SetRefreshTime'
        QtMocHelpers::SlotData<void(quint64)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 12 },
        }}),
        // Slot 'GetLastestTime'
        QtMocHelpers::SlotData<quint64() const>(13, 4, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'GetSelfTime'
        QtMocHelpers::SlotData<quint64() const>(14, 4, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'IsLockEventTriggered'
        QtMocHelpers::SlotData<bool() const>(15, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'TriggerLockEvent'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ClearLockEvent'
        QtMocHelpers::SlotData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ComputerSleep'
        QtMocHelpers::SlotData<void(bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'GetLeftoverErrorInputTimes'
        QtMocHelpers::SlotData<int(int)>(20, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'LeftoverErrorInputTimesMinusOne'
        QtMocHelpers::SlotData<void(int)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'RestoreLeftoverErrorInputTimes'
        QtMocHelpers::SlotData<void(int)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'StartTimerOfRestorePasswordInput'
        QtMocHelpers::SlotData<void(int)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'GetNeedWaitMinutes'
        QtMocHelpers::SlotData<int(int)>(25, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'RestoreNeedWaitMinutes'
        QtMocHelpers::SlotData<void(int)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<VaultManagerDBus, qt_meta_tag_ZN16VaultManagerDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject VaultManagerDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VaultManagerDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VaultManagerDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16VaultManagerDBusE_t>.metaTypes,
    nullptr
} };

void VaultManagerDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultManagerDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->LockEventTriggered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ChangedVaultState((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->SysUserChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->SetRefreshTime((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 4: { quint64 _r = _t->GetLastestTime();
            if (_a[0]) *reinterpret_cast<quint64*>(_a[0]) = std::move(_r); }  break;
        case 5: { quint64 _r = _t->GetSelfTime();
            if (_a[0]) *reinterpret_cast<quint64*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->IsLockEventTriggered();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->TriggerLockEvent(); break;
        case 8: _t->ClearLockEvent(); break;
        case 9: _t->ComputerSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: { int _r = _t->GetLeftoverErrorInputTimes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->LeftoverErrorInputTimesMinusOne((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->RestoreLeftoverErrorInputTimes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->StartTimerOfRestorePasswordInput((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: { int _r = _t->GetNeedWaitMinutes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->RestoreNeedWaitMinutes((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VaultManagerDBus::*)(QString )>(_a, &VaultManagerDBus::LockEventTriggered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VaultManagerDBus::*)(const QVariantMap & )>(_a, &VaultManagerDBus::ChangedVaultState, 1))
            return;
    }
}

const QMetaObject *VaultManagerDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VaultManagerDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16VaultManagerDBusE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int VaultManagerDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void VaultManagerDBus::LockEventTriggered(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VaultManagerDBus::ChangedVaultState(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
