/****************************************************************************
** Meta object code from reading C++ file 'accesscontroladaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "accesscontroladaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accesscontroladaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27AccessControlManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto AccessControlManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AccessControlManagerAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.AccessControlManager",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.AccessControlManager\">"
        "\n    <signal name=\"DiskPasswordChecked\">\n      <arg direction="
        "\"out\" type=\"i\" name=\"code\"/>\n    </signal>\n    <signal nam"
        "e=\"DiskPasswordChanged\">\n      <arg direction=\"out\" type=\"i\""
        " name=\"code\"/>\n    </signal>\n    <method name=\"ChangeDiskPass"
        "word\">\n      <arg direction=\"in\" type=\"s\" name=\"oldPwd\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"newPwd\"/>\n    </me"
        "thod>\n    <method name=\"Chmod\">\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"path\"/"
        ">\n      <arg direction=\"in\" type=\"u\" name=\"mode\"/>\n    </m"
        "ethod>\n  </interface>\n",
        "DiskPasswordChanged",
        "",
        "code",
        "DiskPasswordChecked",
        "ChangeDiskPassword",
        "oldPwd",
        "newPwd",
        "Chmod",
        "path",
        "mode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DiskPasswordChanged'
        QtMocHelpers::SignalData<void(int)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'DiskPasswordChecked'
        QtMocHelpers::SignalData<void(int)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'ChangeDiskPassword'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'Chmod'
        QtMocHelpers::SlotData<bool(const QString &, uint)>(12, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 13 }, { QMetaType::UInt, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<AccessControlManagerAdaptor, qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject AccessControlManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void AccessControlManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccessControlManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DiskPasswordChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->DiskPasswordChecked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->ChangeDiskPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: { bool _r = _t->Chmod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccessControlManagerAdaptor::*)(int )>(_a, &AccessControlManagerAdaptor::DiskPasswordChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccessControlManagerAdaptor::*)(int )>(_a, &AccessControlManagerAdaptor::DiskPasswordChecked, 1))
            return;
    }
}

const QMetaObject *AccessControlManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccessControlManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27AccessControlManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AccessControlManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void AccessControlManagerAdaptor::DiskPasswordChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AccessControlManagerAdaptor::DiskPasswordChecked(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
