/****************************************************************************
** Meta object code from reading C++ file 'abstractjobhandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/include/dfm-base/interfaces/abstractjobhandler.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractjobhandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::AbstractJobHandler::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::AbstractJobHandler",
        "proccessChangedNotify",
        "",
        "JobInfoPointer",
        "jobInfo",
        "stateChangedNotify",
        "currentTaskNotify",
        "finishedNotify",
        "errorNotify",
        "speedUpdatedNotify",
        "requestShowTipsDialog",
        "dfmbase::AbstractJobHandler::ShowDialogType",
        "type",
        "QList<QUrl>",
        "list",
        "workerFinish",
        "requestRemoveTaskWidget",
        "requestSaveRedoOperation",
        "token",
        "deleteFirstFileSize",
        "requestTaskDailog",
        "userAction",
        "SupportActions",
        "actions",
        "operateTaskJob",
        "onProccessChanged",
        "onStateChanged",
        "onCurrentTask",
        "onError",
        "onFinished",
        "onSpeedUpdated",
        "JobFlag",
        "kNoHint",
        "kCopyFollowSymlink",
        "kCopyAttributes",
        "kCopyAttributesOnly",
        "kCopyToSelf",
        "kCopyRemoveDestination",
        "kCopyResizeDestinationFile",
        "kCopyIntegrityChecking",
        "kDeleteForceDeleteFile",
        "kDontFormatFileName",
        "kRevocation",
        "kCopyRemote",
        "kRedo",
        "kCountProgressCustomize",
        "JobState",
        "kStartState",
        "kRunningState",
        "kPauseState",
        "kStopState",
        "kUnknowState",
        "StatisticState",
        "kNoState",
        "JobErrorType",
        "kNoError",
        "kNoSourceError",
        "kCancelError",
        "kPermissionError",
        "kSpecialFileError",
        "kFileExistsError",
        "kDirectoryExistsError",
        "kOpenError",
        "kReadError",
        "kWriteError",
        "kSymlinkError",
        "kMkdirError",
        "kResizeError",
        "kRemoveError",
        "kRenameError",
        "kSymlinkToGvfsError",
        "kUnknowUrlError",
        "kNonexistenceError",
        "kIntegrityCheckingError",
        "kFileSizeTooBigError",
        "kNotEnoughSpaceError",
        "kTargetReadOnlyError",
        "kTargetIsSelfError",
        "kNotSupportedError",
        "kPermissionDeniedError",
        "kSeekError",
        "kProrogramError",
        "kDfmIoError",
        "kDeleteFileError",
        "kMakeStandardTrashError",
        "kGetRestorePathError",
        "kDeleteTrashFileError",
        "kIsNotTrashFileError",
        "kCreateParentDirError",
        "kFailedParseUrlOfTrash",
        "kFailedObtainTrashOriginalFile",
        "kFileMoveToTrashError",
        "kRetryReadOrWriteFailed",
        "kCanNotAccessFile",
        "kUnknowError",
        "JobType",
        "kCopyType",
        "kCutType",
        "kDeleteType",
        "kMoveToTrashType",
        "kRestoreType",
        "kCleanTrashType",
        "kUnknow",
        "SupportAction",
        "kNoAction",
        "kRetryAction",
        "kReplaceAction",
        "kMergeAction",
        "kSkipAction",
        "kCoexistAction",
        "kCancelAction",
        "kEnforceAction",
        "kRememberAction",
        "kPauseAction",
        "kStopAction",
        "kStartAction",
        "kResumAction",
        "NotifyInfoKey",
        "kJobtypeKey",
        "kCurrentProgressKey",
        "kTotalSizeKey",
        "kStatisticStateKey",
        "kJobStateKey",
        "kJobStateHideKey",
        "kSourceUrlKey",
        "kTargetUrlKey",
        "kErrorTypeKey",
        "kSourceMsgKey",
        "kTargetMsgKey",
        "kErrorMsgKey",
        "kActionsKey",
        "kSpeedKey",
        "kRemindTimeKey",
        "kCompleteFilesKey",
        "kCompleteTargetFilesKey",
        "kCompleteCustomInfosKey",
        "kJobHandlePointer",
        "kWorkerPointer",
        "NotifyType",
        "kNotifyProccessChangedKey",
        "kNotifyStateChangedKey",
        "kNotifyCurrentTaskKey",
        "kNotifyFinishedKey",
        "kNotifySpeedUpdatedTaskKey",
        "kNotifyErrorTaskKey",
        "FileNameAddFlag",
        "kPrefix",
        "kSuffix",
        "DeleteDialogNoticeType",
        "kEmptyTrash",
        "kDeleteTashFiles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'proccessChangedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'stateChangedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'currentTaskNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finishedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'errorNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'speedUpdatedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestShowTipsDialog'
        QtMocHelpers::SignalData<void(dfmbase::AbstractJobHandler::ShowDialogType, const QList<QUrl>)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'workerFinish'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestRemoveTaskWidget'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSaveRedoOperation'
        QtMocHelpers::SignalData<void(const QString &, const qint64)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::LongLong, 19 },
        }}),
        // Signal 'requestTaskDailog'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userAction'
        QtMocHelpers::SignalData<void(SupportActions)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'operateTaskJob'
        QtMocHelpers::SlotData<void(SupportActions)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'onProccessChanged'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onStateChanged'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onCurrentTask'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onSpeedUpdated'
        QtMocHelpers::SlotData<void(const JobInfoPointer)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'JobFlag'
        QtMocHelpers::EnumData<enum JobFlag>(31, 31, QMC::EnumIsScoped).add({
            {   32, JobFlag::kNoHint },
            {   33, JobFlag::kCopyFollowSymlink },
            {   34, JobFlag::kCopyAttributes },
            {   35, JobFlag::kCopyAttributesOnly },
            {   36, JobFlag::kCopyToSelf },
            {   37, JobFlag::kCopyRemoveDestination },
            {   38, JobFlag::kCopyResizeDestinationFile },
            {   39, JobFlag::kCopyIntegrityChecking },
            {   40, JobFlag::kDeleteForceDeleteFile },
            {   41, JobFlag::kDontFormatFileName },
            {   42, JobFlag::kRevocation },
            {   43, JobFlag::kCopyRemote },
            {   44, JobFlag::kRedo },
            {   45, JobFlag::kCountProgressCustomize },
        }),
        // enum 'JobState'
        QtMocHelpers::EnumData<enum JobState>(46, 46, QMC::EnumIsScoped).add({
            {   47, JobState::kStartState },
            {   48, JobState::kRunningState },
            {   49, JobState::kPauseState },
            {   50, JobState::kStopState },
            {   51, JobState::kUnknowState },
        }),
        // enum 'StatisticState'
        QtMocHelpers::EnumData<enum StatisticState>(52, 52, QMC::EnumIsScoped).add({
            {   53, StatisticState::kNoState },
            {   48, StatisticState::kRunningState },
            {   50, StatisticState::kStopState },
        }),
        // enum 'JobErrorType'
        QtMocHelpers::EnumData<enum JobErrorType>(54, 54, QMC::EnumIsScoped).add({
            {   55, JobErrorType::kNoError },
            {   56, JobErrorType::kNoSourceError },
            {   57, JobErrorType::kCancelError },
            {   58, JobErrorType::kPermissionError },
            {   59, JobErrorType::kSpecialFileError },
            {   60, JobErrorType::kFileExistsError },
            {   61, JobErrorType::kDirectoryExistsError },
            {   62, JobErrorType::kOpenError },
            {   63, JobErrorType::kReadError },
            {   64, JobErrorType::kWriteError },
            {   65, JobErrorType::kSymlinkError },
            {   66, JobErrorType::kMkdirError },
            {   67, JobErrorType::kResizeError },
            {   68, JobErrorType::kRemoveError },
            {   69, JobErrorType::kRenameError },
            {   70, JobErrorType::kSymlinkToGvfsError },
            {   71, JobErrorType::kUnknowUrlError },
            {   72, JobErrorType::kNonexistenceError },
            {   73, JobErrorType::kIntegrityCheckingError },
            {   74, JobErrorType::kFileSizeTooBigError },
            {   75, JobErrorType::kNotEnoughSpaceError },
            {   76, JobErrorType::kTargetReadOnlyError },
            {   77, JobErrorType::kTargetIsSelfError },
            {   78, JobErrorType::kNotSupportedError },
            {   79, JobErrorType::kPermissionDeniedError },
            {   80, JobErrorType::kSeekError },
            {   81, JobErrorType::kProrogramError },
            {   82, JobErrorType::kDfmIoError },
            {   83, JobErrorType::kDeleteFileError },
            {   84, JobErrorType::kMakeStandardTrashError },
            {   85, JobErrorType::kGetRestorePathError },
            {   86, JobErrorType::kDeleteTrashFileError },
            {   87, JobErrorType::kIsNotTrashFileError },
            {   88, JobErrorType::kCreateParentDirError },
            {   89, JobErrorType::kFailedParseUrlOfTrash },
            {   90, JobErrorType::kFailedObtainTrashOriginalFile },
            {   91, JobErrorType::kFileMoveToTrashError },
            {   92, JobErrorType::kRetryReadOrWriteFailed },
            {   93, JobErrorType::kCanNotAccessFile },
            {   94, JobErrorType::kUnknowError },
        }),
        // enum 'JobType'
        QtMocHelpers::EnumData<enum JobType>(95, 95, QMC::EnumIsScoped).add({
            {   96, JobType::kCopyType },
            {   97, JobType::kCutType },
            {   98, JobType::kDeleteType },
            {   99, JobType::kMoveToTrashType },
            {  100, JobType::kRestoreType },
            {  101, JobType::kCleanTrashType },
            {  102, JobType::kUnknow },
        }),
        // enum 'SupportAction'
        QtMocHelpers::EnumData<enum SupportAction>(103, 103, QMC::EnumIsScoped).add({
            {  104, SupportAction::kNoAction },
            {  105, SupportAction::kRetryAction },
            {  106, SupportAction::kReplaceAction },
            {  107, SupportAction::kMergeAction },
            {  108, SupportAction::kSkipAction },
            {  109, SupportAction::kCoexistAction },
            {  110, SupportAction::kCancelAction },
            {  111, SupportAction::kEnforceAction },
            {  112, SupportAction::kRememberAction },
            {  113, SupportAction::kPauseAction },
            {  114, SupportAction::kStopAction },
            {  115, SupportAction::kStartAction },
            {  116, SupportAction::kResumAction },
        }),
        // enum 'NotifyInfoKey'
        QtMocHelpers::EnumData<enum NotifyInfoKey>(117, 117, QMC::EnumFlags{}).add({
            {  118, NotifyInfoKey::kJobtypeKey },
            {  119, NotifyInfoKey::kCurrentProgressKey },
            {  120, NotifyInfoKey::kTotalSizeKey },
            {  121, NotifyInfoKey::kStatisticStateKey },
            {  122, NotifyInfoKey::kJobStateKey },
            {  123, NotifyInfoKey::kJobStateHideKey },
            {  124, NotifyInfoKey::kSourceUrlKey },
            {  125, NotifyInfoKey::kTargetUrlKey },
            {  126, NotifyInfoKey::kErrorTypeKey },
            {  127, NotifyInfoKey::kSourceMsgKey },
            {  128, NotifyInfoKey::kTargetMsgKey },
            {  129, NotifyInfoKey::kErrorMsgKey },
            {  130, NotifyInfoKey::kActionsKey },
            {  131, NotifyInfoKey::kSpeedKey },
            {  132, NotifyInfoKey::kRemindTimeKey },
            {  133, NotifyInfoKey::kCompleteFilesKey },
            {  134, NotifyInfoKey::kCompleteTargetFilesKey },
            {  135, NotifyInfoKey::kCompleteCustomInfosKey },
            {  136, NotifyInfoKey::kJobHandlePointer },
            {  137, NotifyInfoKey::kWorkerPointer },
        }),
        // enum 'NotifyType'
        QtMocHelpers::EnumData<enum NotifyType>(138, 138, QMC::EnumIsScoped).add({
            {  139, NotifyType::kNotifyProccessChangedKey },
            {  140, NotifyType::kNotifyStateChangedKey },
            {  141, NotifyType::kNotifyCurrentTaskKey },
            {  142, NotifyType::kNotifyFinishedKey },
            {  143, NotifyType::kNotifySpeedUpdatedTaskKey },
            {  144, NotifyType::kNotifyErrorTaskKey },
        }),
        // enum 'FileNameAddFlag'
        QtMocHelpers::EnumData<enum FileNameAddFlag>(145, 145, QMC::EnumFlags{}).add({
            {  146, FileNameAddFlag::kPrefix },
            {  147, FileNameAddFlag::kSuffix },
        }),
        // enum 'DeleteDialogNoticeType'
        QtMocHelpers::EnumData<enum DeleteDialogNoticeType>(148, 148, QMC::EnumIsScoped).add({
            {  149, DeleteDialogNoticeType::kEmptyTrash },
            {  150, DeleteDialogNoticeType::kDeleteTashFiles },
        }),
    };
    return QtMocHelpers::metaObjectData<AbstractJobHandler, qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::AbstractJobHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>.metaTypes,
    nullptr
} };

void dfmbase::AbstractJobHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractJobHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->proccessChangedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 1: _t->stateChangedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 2: _t->currentTaskNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 3: _t->finishedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 4: _t->errorNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 5: _t->speedUpdatedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 6: _t->requestShowTipsDialog((*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::ShowDialogType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 7: _t->workerFinish(); break;
        case 8: _t->requestRemoveTaskWidget(); break;
        case 9: _t->requestSaveRedoOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 10: _t->requestTaskDailog(); break;
        case 11: _t->userAction((*reinterpret_cast<std::add_pointer_t<SupportActions>>(_a[1]))); break;
        case 12: _t->operateTaskJob((*reinterpret_cast<std::add_pointer_t<SupportActions>>(_a[1]))); break;
        case 13: _t->onProccessChanged((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 14: _t->onStateChanged((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 15: _t->onCurrentTask((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 16: _t->onError((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 17: _t->onFinished((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 18: _t->onSpeedUpdated((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::ShowDialogType >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::proccessChangedNotify, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::stateChangedNotify, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::currentTaskNotify, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::finishedNotify, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::errorNotify, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const JobInfoPointer )>(_a, &AbstractJobHandler::speedUpdatedNotify, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(dfmbase::AbstractJobHandler::ShowDialogType , const QList<QUrl> )>(_a, &AbstractJobHandler::requestShowTipsDialog, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)()>(_a, &AbstractJobHandler::workerFinish, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)()>(_a, &AbstractJobHandler::requestRemoveTaskWidget, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(const QString & , const qint64 )>(_a, &AbstractJobHandler::requestSaveRedoOperation, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)()>(_a, &AbstractJobHandler::requestTaskDailog, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractJobHandler::*)(SupportActions )>(_a, &AbstractJobHandler::userAction, 11))
            return;
    }
}

const QMetaObject *dfmbase::AbstractJobHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::AbstractJobHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18AbstractJobHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::AbstractJobHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::AbstractJobHandler::proccessChangedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmbase::AbstractJobHandler::stateChangedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmbase::AbstractJobHandler::currentTaskNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmbase::AbstractJobHandler::finishedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmbase::AbstractJobHandler::errorNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmbase::AbstractJobHandler::speedUpdatedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmbase::AbstractJobHandler::requestShowTipsDialog(dfmbase::AbstractJobHandler::ShowDialogType _t1, const QList<QUrl> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dfmbase::AbstractJobHandler::workerFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dfmbase::AbstractJobHandler::requestRemoveTaskWidget()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dfmbase::AbstractJobHandler::requestSaveRedoOperation(const QString & _t1, const qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void dfmbase::AbstractJobHandler::requestTaskDailog()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dfmbase::AbstractJobHandler::userAction(SupportActions _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
