/****************************************************************************
** Meta object code from reading C++ file 'traversaldirthreadmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/utils/traversaldirthreadmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traversaldirthreadmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::TraversalDirThreadManager::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::TraversalDirThreadManager",
        "updateChildrenManager",
        "",
        "QList<FileInfoPointer>",
        "children",
        "traversalToken",
        "updateLocalChildren",
        "QList<SortInfoPointer>",
        "dfmio::DEnumerator::SortRoleCompareFlag",
        "sortRole",
        "Qt::SortOrder",
        "sortOrder",
        "isMixDirAndFile",
        "traversalFinished",
        "traversalRequestSort",
        "iteratorInitFinished",
        "onAsyncIteratorOver"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateChildrenManager'
        QtMocHelpers::SignalData<void(const QList<FileInfoPointer>, QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'updateLocalChildren'
        QtMocHelpers::SignalData<void(const QList<SortInfoPointer>, dfmio::DEnumerator::SortRoleCompareFlag, Qt::SortOrder, bool, QString)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::Bool, 12 },
            { QMetaType::QString, 5 },
        }}),
        // Signal 'traversalFinished'
        QtMocHelpers::SignalData<void(QString)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'traversalRequestSort'
        QtMocHelpers::SignalData<void(QString)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'iteratorInitFinished'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAsyncIteratorOver'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TraversalDirThreadManager, qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::TraversalDirThreadManager::staticMetaObject = { {
    QMetaObject::SuperData::link<TraversalDirThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::TraversalDirThreadManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TraversalDirThreadManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateChildrenManager((*reinterpret_cast<std::add_pointer_t<QList<FileInfoPointer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->updateLocalChildren((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 2: _t->traversalFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->traversalRequestSort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->iteratorInitFinished(); break;
        case 5: _t->onAsyncIteratorOver(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<FileInfoPointer> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TraversalDirThreadManager::*)(const QList<FileInfoPointer> , QString )>(_a, &TraversalDirThreadManager::updateChildrenManager, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraversalDirThreadManager::*)(const QList<SortInfoPointer> , dfmio::DEnumerator::SortRoleCompareFlag , Qt::SortOrder , bool , QString )>(_a, &TraversalDirThreadManager::updateLocalChildren, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraversalDirThreadManager::*)(QString )>(_a, &TraversalDirThreadManager::traversalFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraversalDirThreadManager::*)(QString )>(_a, &TraversalDirThreadManager::traversalRequestSort, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraversalDirThreadManager::*)()>(_a, &TraversalDirThreadManager::iteratorInitFinished, 4))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::TraversalDirThreadManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::TraversalDirThreadManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace25TraversalDirThreadManagerE_t>.strings))
        return static_cast<void*>(this);
    return TraversalDirThread::qt_metacast(_clname);
}

int dfmplugin_workspace::TraversalDirThreadManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TraversalDirThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::TraversalDirThreadManager::updateChildrenManager(const QList<FileInfoPointer> _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmplugin_workspace::TraversalDirThreadManager::updateLocalChildren(const QList<SortInfoPointer> _t1, dfmio::DEnumerator::SortRoleCompareFlag _t2, Qt::SortOrder _t3, bool _t4, QString _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 2
void dfmplugin_workspace::TraversalDirThreadManager::traversalFinished(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmplugin_workspace::TraversalDirThreadManager::traversalRequestSort(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmplugin_workspace::TraversalDirThreadManager::iteratorInitFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
