/****************************************************************************
** Meta object code from reading C++ file 'filedialogadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filedialogadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialogadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17FiledialogAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FiledialogAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17FiledialogAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FiledialogAdaptor",
        "D-Bus Interface",
        "com.deepin.filemanager.filedialog",
        "D-Bus Introspection",
        "  <interface name=\"com.deepin.filemanager.filedialog\">\n    <pro"
        "perty access=\"readwrite\" type=\"s\" name=\"directory\"/>\n    <p"
        "roperty access=\"readwrite\" type=\"s\" name=\"directoryUrl\"/>\n "
        "   <property access=\"readwrite\" type=\"as\" name=\"nameFilters\""
        ">\n      <annotation value=\"QStringList\" name=\"org.qtproject.Qt"
        "DBus.QtTypeName\"/>\n    </property>\n    <property access=\"readw"
        "rite\" type=\"i\" name=\"filter\"/>\n    <property access=\"readwr"
        "ite\" type=\"i\" name=\"viewMode\"/>\n    <property access=\"readw"
        "rite\" type=\"i\" name=\"acceptMode\"/>\n    <property access=\"re"
        "ad\" type=\"b\" name=\"windowActive\"/>\n    <property access=\"re"
        "adwrite\" type=\"i\" name=\"heartbeatInterval\"/>\n    <property a"
        "ccess=\"readwrite\" type=\"u\" name=\"windowFlags\"/>\n    <proper"
        "ty access=\"readwrite\" type=\"b\" name=\"hideOnAccept\"/>\n    <m"
        "ethod name=\"selectFile\">\n      <arg direction=\"in\" type=\"s\""
        " name=\"filename\"/>\n    </method>\n    <method name=\"selectedFi"
        "les\">\n      <annotation value=\"QStringList\" name=\"org.qtproje"
        "ct.QtDBus.QtTypeName.Out0\"/>\n      <arg direction=\"out\" type=\""
        "as\" name=\"filelist\"/>\n    </method>\n    <method name=\"select"
        "Url\">\n      <arg direction=\"in\" type=\"s\" name=\"url\"/>\n   "
        " </method>\n    <method name=\"selectedUrls\">\n      <annotation "
        "value=\"QStringList\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\""
        "/>\n      <arg direction=\"out\" type=\"as\" name=\"urllist\"/>\n "
        "   </method>\n    <method name=\"selectNameFilter\">\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"filter\"/>\n    </method>\n    <"
        "method name=\"selectedNameFilter\">\n      <arg direction=\"out\" "
        "type=\"s\" name=\"filter\"/>\n    </method>\n    <method name=\"se"
        "lectNameFilterByIndex\">\n      <arg direction=\"in\" type=\"i\" n"
        "ame=\"index\"/>\n    </method>\n    <method name=\"selectedNameFil"
        "terIndex\">\n      <arg direction=\"out\" type=\"i\" name=\"index\""
        "/>\n    </method>\n    <method name=\"setFileMode\">\n      <arg d"
        "irection=\"in\" type=\"i\" name=\"fileMode\"/>\n    </method>\n   "
        " <method name=\"setLabelText\">\n      <arg direction=\"in\" type="
        "\"i\" name=\"label\"/>\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"text\"/>\n    </method>\n    <method name=\"labelText\">\n    "
        "  <arg direction=\"in\" type=\"i\" name=\"label\"/>\n      <arg di"
        "rection=\"out\" type=\"s\" name=\"text\"/>\n    </method>\n    <me"
        "thod name=\"setOptions\">\n      <arg direction=\"in\" type=\"i\" "
        "name=\"options\"/>\n    </method>\n    <method name=\"setOption\">"
        "\n      <arg direction=\"in\" type=\"i\" name=\"option\"/>\n      "
        "<arg direction=\"in\" type=\"b\" name=\"on\"/>\n    </method>\n   "
        " <method name=\"options\">\n      <arg direction=\"out\" type=\"i\""
        " name=\"options\"/>\n    </method>\n    <method name=\"testOption\""
        ">\n      <arg direction=\"in\" type=\"i\" name=\"option\"/>\n     "
        " <arg direction=\"out\" type=\"b\" name=\"on\"/>\n    </method>\n "
        "   <method name=\"setCurrentInputName\">\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"name\"/>\n    </method>\n    <method name=\""
        "show\"/>\n    <method name=\"open\"/>\n    <method name=\"hide\"/>"
        "\n    <method name=\"accept\"/>\n    <method name=\"reject\"/>\n  "
        "  <method name=\"winId\">\n      <arg direction=\"out\" type=\"t\""
        " name=\"windowId\"/>\n    </method>\n    <method name=\"setWindowT"
        "itle\">\n      <arg direction=\"in\" type=\"s\" name=\"title\"/>\n"
        "    </method>\n    <method name=\"deleteLater\"/>\n    <method nam"
        "e=\"activateWindow\"/>\n    <method name=\"makeHeartbeat\"/>\n    "
        "<method name=\"addCustomWidget\">\n      <arg direction=\"in\" typ"
        "e=\"i\" name=\"type\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"data\"/>\n    </method>\n    <method name=\"getCustomWidgetVa"
        "lue\">\n      <arg direction=\"in\" type=\"i\" name=\"type\"/>\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"text\"/>\n      <arg d"
        "irection=\"out\" type=\"v\" name=\"value\"/>\n    </method>\n    <"
        "method name=\"allCustomWidgetsValue\">\n      <arg direction=\"in\""
        " type=\"i\" name=\"type\"/>\n      <arg direction=\"out\" type=\"a"
        "{sv}\" name=\"values\"/>\n      <annotation value=\"QMap&lt;QStrin"
        "g,QVariant&gt;\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
        "    </method>\n    <method name=\"beginAddCustomWidget\"/>\n    <m"
        "ethod name=\"endAddCustomWidget\"/>\n    <method name=\"addDisable"
        "UrlScheme\">\n      <arg direction=\"in\" type=\"s\" name=\"type\""
        "/>\n    </method>\n    <method name=\"setAllowMixedSelection\">\n "
        "     <arg direction=\"in\" type=\"b\" name=\"on\"/>\n    </method>"
        "\n    <signal name=\"finished\">\n      <arg direction=\"out\" typ"
        "e=\"i\" name=\"result\"/>\n    </signal>\n    <signal name=\"accep"
        "ted\"/>\n    <signal name=\"rejected\"/>\n    <signal name=\"windo"
        "wActiveChanged\"/>\n    <signal name=\"destroyed\"/>\n    <signal "
        "name=\"selectionFilesChanged\"/>\n    <signal name=\"currentUrlCha"
        "nged\"/>\n    <signal name=\"directoryChanged\"/>\n    <signal nam"
        "e=\"directoryUrlChanged\"/>\n    <signal name=\"selectedNameFilter"
        "Changed\"/>\n  </interface>\n",
        "accepted",
        "",
        "currentUrlChanged",
        "destroyed",
        "directoryChanged",
        "directoryUrlChanged",
        "finished",
        "result",
        "rejected",
        "selectedNameFilterChanged",
        "selectionFilesChanged",
        "windowActiveChanged",
        "accept",
        "activateWindow",
        "addCustomWidget",
        "type",
        "data",
        "addDisableUrlScheme",
        "allCustomWidgetsValue",
        "QMap<QString,QVariant>",
        "beginAddCustomWidget",
        "deleteLater",
        "endAddCustomWidget",
        "getCustomWidgetValue",
        "QDBusVariant",
        "text",
        "hide",
        "labelText",
        "label",
        "makeHeartbeat",
        "open",
        "options",
        "reject",
        "selectFile",
        "filename",
        "selectNameFilter",
        "filter",
        "selectNameFilterByIndex",
        "index",
        "selectUrl",
        "url",
        "selectedFiles",
        "selectedNameFilter",
        "selectedNameFilterIndex",
        "selectedUrls",
        "setAllowMixedSelection",
        "on",
        "setCurrentInputName",
        "name",
        "setFileMode",
        "fileMode",
        "setLabelText",
        "setOption",
        "option",
        "setOptions",
        "setWindowTitle",
        "title",
        "show",
        "testOption",
        "winId",
        "acceptMode",
        "directory",
        "directoryUrl",
        "heartbeatInterval",
        "hideOnAccept",
        "nameFilters",
        "viewMode",
        "windowActive",
        "windowFlags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accepted'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentUrlChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'destroyed'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryUrlChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'rejected'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedNameFilterChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionFilesChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowActiveChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateWindow'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addCustomWidget'
        QtMocHelpers::SlotData<void(int, const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'addDisableUrlScheme'
        QtMocHelpers::SlotData<void(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'allCustomWidgetsValue'
        QtMocHelpers::SlotData<QMap<QString,QVariant>(int)>(23, 6, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'beginAddCustomWidget'
        QtMocHelpers::SlotData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteLater'
        QtMocHelpers::SlotData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'endAddCustomWidget'
        QtMocHelpers::SlotData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getCustomWidgetValue'
        QtMocHelpers::SlotData<QDBusVariant(int, const QString &)>(28, 6, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 20 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'hide'
        QtMocHelpers::SlotData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'labelText'
        QtMocHelpers::SlotData<QString(int)>(32, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'makeHeartbeat'
        QtMocHelpers::SlotData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'open'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'options'
        QtMocHelpers::SlotData<int()>(36, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectFile'
        QtMocHelpers::SlotData<void(const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'selectNameFilter'
        QtMocHelpers::SlotData<void(const QString &)>(40, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'selectNameFilterByIndex'
        QtMocHelpers::SlotData<void(int)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'selectUrl'
        QtMocHelpers::SlotData<void(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
        // Slot 'selectedFiles'
        QtMocHelpers::SlotData<QStringList()>(46, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'selectedNameFilter'
        QtMocHelpers::SlotData<QString()>(47, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectedNameFilterIndex'
        QtMocHelpers::SlotData<int()>(48, 6, QMC::AccessPublic, QMetaType::Int),
        // Slot 'selectedUrls'
        QtMocHelpers::SlotData<QStringList()>(49, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'setAllowMixedSelection'
        QtMocHelpers::SlotData<void(bool)>(50, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setCurrentInputName'
        QtMocHelpers::SlotData<void(const QString &)>(52, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'setFileMode'
        QtMocHelpers::SlotData<void(int)>(54, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'setLabelText'
        QtMocHelpers::SlotData<void(int, const QString &)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(int, bool)>(57, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 58 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'setOptions'
        QtMocHelpers::SlotData<void(int)>(59, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'setWindowTitle'
        QtMocHelpers::SlotData<void(const QString &)>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'show'
        QtMocHelpers::SlotData<void()>(62, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'testOption'
        QtMocHelpers::SlotData<bool(int)>(63, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 58 },
        }}),
        // Slot 'winId'
        QtMocHelpers::SlotData<qulonglong()>(64, 6, QMC::AccessPublic, QMetaType::ULongLong),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'acceptMode'
        QtMocHelpers::PropertyData<int>(65, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'directory'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'directoryUrl'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'filter'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'heartbeatInterval'
        QtMocHelpers::PropertyData<int>(68, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hideOnAccept'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'nameFilters'
        QtMocHelpers::PropertyData<QStringList>(70, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'viewMode'
        QtMocHelpers::PropertyData<int>(71, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'windowActive'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'windowFlags'
        QtMocHelpers::PropertyData<uint>(73, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FiledialogAdaptor, qt_meta_tag_ZN17FiledialogAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FiledialogAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FiledialogAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FiledialogAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17FiledialogAdaptorE_t>.metaTypes,
    nullptr
} };

void FiledialogAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FiledialogAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accepted(); break;
        case 1: _t->currentUrlChanged(); break;
        case 2: _t->destroyed(); break;
        case 3: _t->directoryChanged(); break;
        case 4: _t->directoryUrlChanged(); break;
        case 5: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->rejected(); break;
        case 7: _t->selectedNameFilterChanged(); break;
        case 8: _t->selectionFilesChanged(); break;
        case 9: _t->windowActiveChanged(); break;
        case 10: _t->accept(); break;
        case 11: _t->activateWindow(); break;
        case 12: _t->addCustomWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->addDisableUrlScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: { QMap<QString,QVariant> _r = _t->allCustomWidgetsValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QMap<QString,QVariant>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->beginAddCustomWidget(); break;
        case 16: _t->deleteLater(); break;
        case 17: _t->endAddCustomWidget(); break;
        case 18: { QDBusVariant _r = _t->getCustomWidgetValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->hide(); break;
        case 20: { QString _r = _t->labelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->makeHeartbeat(); break;
        case 22: _t->open(); break;
        case 23: { int _r = _t->options();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->reject(); break;
        case 25: _t->selectFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->selectNameFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->selectNameFilterByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->selectUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: { QStringList _r = _t->selectedFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->selectedNameFilter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { int _r = _t->selectedNameFilterIndex();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 32: { QStringList _r = _t->selectedUrls();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->setAllowMixedSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->setCurrentInputName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->setFileMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->setLabelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: _t->setOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 38: _t->setOptions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->setWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->show(); break;
        case 41: { bool _r = _t->testOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: { qulonglong _r = _t->winId();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::accepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::currentUrlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::destroyed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::directoryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::directoryUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)(int )>(_a, &FiledialogAdaptor::finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::rejected, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::selectedNameFilterChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::selectionFilesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FiledialogAdaptor::*)()>(_a, &FiledialogAdaptor::windowActiveChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->acceptMode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->directory(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->directoryUrl(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->filter(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->heartbeatInterval(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hideOnAccept(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->nameFilters(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->viewMode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->windowActive(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->windowFlags(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAcceptMode(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDirectoryUrl(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setFilter(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setHeartbeatInterval(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setHideOnAccept(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setNameFilters(*reinterpret_cast<QStringList*>(_v)); break;
        case 7: _t->setViewMode(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setWindowFlags(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FiledialogAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FiledialogAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17FiledialogAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FiledialogAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 43;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void FiledialogAdaptor::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FiledialogAdaptor::currentUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FiledialogAdaptor::destroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FiledialogAdaptor::directoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FiledialogAdaptor::directoryUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FiledialogAdaptor::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void FiledialogAdaptor::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FiledialogAdaptor::selectedNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FiledialogAdaptor::selectionFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FiledialogAdaptor::windowActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
