/****************************************************************************
** Meta object code from reading C++ file 'fileoperationseventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-fileoperations/fileoperationsevent/fileoperationseventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileoperationseventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_fileoperations::FileOperationsEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_fileoperations::FileOperationsEventReceiver",
        "handleOperationCopy",
        "",
        "windowId",
        "QList<QUrl>",
        "sources",
        "QUrl",
        "target",
        "dfmbase::AbstractJobHandler::JobFlag",
        "flags",
        "dfmbase::AbstractJobHandler::OperatorHandleCallback",
        "handle",
        "QVariant",
        "custom",
        "dfmbase::AbstractJobHandler::OperatorCallback",
        "callback",
        "handleOperationCut",
        "handleOperationDeletes",
        "handleOperationOpenFiles",
        "urls",
        "bool*",
        "ok",
        "handleOperationOpenFilesByApp",
        "apps",
        "handleOperationRenameFile",
        "oldUrl",
        "newUrl",
        "handleOperationRenameFiles",
        "std::pair<QString,QString>",
        "pair",
        "replace",
        "std::pair<QString,dfmbase::AbstractJobHandler::FileNameAddFlag>",
        "handleOperationMkdir",
        "url",
        "handleOperationTouchFile",
        "dfmbase::Global::CreateFileType",
        "fileType",
        "suffix",
        "tempUrl",
        "callbackImmediately",
        "handleOperationLinkFile",
        "link",
        "force",
        "silence",
        "handleOperationSetPermission",
        "QFileDevice::Permissions",
        "permissions",
        "callBack",
        "handleOperationWriteToClipboard",
        "dfmbase::ClipBoard::ClipboardAction",
        "action",
        "handleOperationWriteDataToClipboard",
        "QMimeData*",
        "data",
        "handleOperationOpenInTerminal",
        "handleOperationSaveOperations",
        "QVariantMap",
        "values",
        "handleOperationCleanSaveOperationsStack",
        "handleOperationRevocation",
        "handleOperationHideFiles",
        "handleShortCut",
        "rootUrl",
        "handleShortCutPaste",
        "handleOperationSaveRedoOperations",
        "handleOperationCleanByUrls",
        "handleRecoveryOperationRedoRecovery",
        "handleSaveRedoOpt",
        "token",
        "fileSize",
        "handleOperationUndoDeletes",
        "handleCallback",
        "op",
        "handleOperationUndoCut",
        "handleOperationFilesPreview",
        "selectUrls",
        "dirUrls",
        "handleIsSubFile",
        "parent",
        "sub"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleOperationCopy'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleOperationCopy'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationCut'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleOperationCut'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationDeletes'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleOperationDeletes'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 },
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationOpenFiles'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 },
        }}),
        // Slot 'handleOperationOpenFiles'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>, bool *)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'handleOperationOpenFiles'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationOpenFilesByApp'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>, const QList<QString>)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { QMetaType::QStringList, 23 },
        }}),
        // Slot 'handleOperationOpenFilesByApp'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QList<QString>, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { QMetaType::QStringList, 23 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationRenameFile'
        QtMocHelpers::SlotData<bool(const quint64, const QUrl, const QUrl, const dfmbase::AbstractJobHandler::JobFlag)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 25 }, { 0x80000000 | 6, 26 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleOperationRenameFile'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 25 }, { 0x80000000 | 6, 26 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationRenameFiles'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>, const QPair<QString,QString>, const bool)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'handleOperationRenameFiles'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QPair<QString,QString>, const bool, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 28, 29 }, { QMetaType::Bool, 30 },
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationRenameFiles'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>, const QPair<QString,dfmbase::AbstractJobHandler::FileNameAddFlag>)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 31, 29 },
        }}),
        // Slot 'handleOperationRenameFiles'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QPair<QString,dfmbase::AbstractJobHandler::FileNameAddFlag>, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 31, 29 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationMkdir'
        QtMocHelpers::SlotData<bool(const quint64, const QUrl)>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 },
        }}),
        // Slot 'handleOperationMkdir'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationTouchFile'
        QtMocHelpers::SlotData<QString(const quint64, const QUrl, const dfmbase::Global::CreateFileType, const QString)>(34, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 35, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'handleOperationTouchFile'
        QtMocHelpers::SlotData<QString(const quint64, const QUrl, const QUrl, const QString)>(34, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 6, 38 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'handleOperationTouchFile'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const dfmbase::Global::CreateFileType, const QString, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 35, 36 }, { QMetaType::QString, 37 },
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 39 },
        }}),
        // Slot 'handleOperationTouchFile'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const QUrl, const QString, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 6, 38 }, { QMetaType::QString, 37 },
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 39 },
        }}),
        // Slot 'handleOperationLinkFile'
        QtMocHelpers::SlotData<bool(const quint64, const QUrl, const QUrl, const bool, const bool)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 6, 41 }, { QMetaType::Bool, 42 },
            { QMetaType::Bool, 43 },
        }}),
        // Slot 'handleOperationLinkFile'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const QUrl, const bool, const bool, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 6, 41 }, { QMetaType::Bool, 42 },
            { QMetaType::Bool, 43 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleOperationSetPermission'
        QtMocHelpers::SlotData<bool(const quint64, const QUrl, const QFileDevice::Permissions)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 45, 46 },
        }}),
        // Slot 'handleOperationSetPermission'
        QtMocHelpers::SlotData<void(const quint64, const QUrl, const QFileDevice::Permissions, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 33 }, { 0x80000000 | 45, 46 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 47 },
        }}),
        // Slot 'handleOperationWriteToClipboard'
        QtMocHelpers::SlotData<bool(const quint64, const dfmbase::ClipBoard::ClipboardAction, const QList<QUrl>)>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 49, 50 }, { 0x80000000 | 4, 19 },
        }}),
        // Slot 'handleOperationWriteDataToClipboard'
        QtMocHelpers::SlotData<bool(const quint64, QMimeData *)>(51, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'handleOperationOpenInTerminal'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>)>(54, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 },
        }}),
        // Slot 'handleOperationSaveOperations'
        QtMocHelpers::SlotData<void(const QVariantMap)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'handleOperationCleanSaveOperationsStack'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleOperationRevocation'
        QtMocHelpers::SlotData<void(const quint64, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleOperationHideFiles'
        QtMocHelpers::SlotData<bool(const quint64, const QList<QUrl>)>(60, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 },
        }}),
        // Slot 'handleOperationHideFiles'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleShortCut'
        QtMocHelpers::SlotData<bool(quint64, const QList<QUrl> &, const QUrl &)>(61, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 2 }, { 0x80000000 | 4, 19 }, { 0x80000000 | 6, 62 },
        }}),
        // Slot 'handleShortCutPaste'
        QtMocHelpers::SlotData<bool(quint64, const QList<QUrl> &, const QUrl &)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 2 }, { 0x80000000 | 4, 2 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleOperationSaveRedoOperations'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'handleOperationCleanByUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 19 },
        }}),
        // Slot 'handleRecoveryOperationRedoRecovery'
        QtMocHelpers::SlotData<void(const quint64, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'handleSaveRedoOpt'
        QtMocHelpers::SlotData<void(const QString &, const qint64)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 }, { QMetaType::LongLong, 69 },
        }}),
        // Slot 'handleOperationUndoDeletes'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariantMap &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 71 },
            { 0x80000000 | 56, 72 },
        }}),
        // Slot 'handleOperationUndoCut'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariantMap &)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 10, 71 }, { 0x80000000 | 56, 72 },
        }}),
        // Slot 'handleOperationFilesPreview'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const QList<QUrl> &)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 75 }, { 0x80000000 | 4, 76 },
        }}),
        // Slot 'handleIsSubFile'
        QtMocHelpers::SlotData<bool(const QUrl &, const QUrl &)>(77, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 6, 78 }, { 0x80000000 | 6, 79 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileOperationsEventReceiver, qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_fileoperations::FileOperationsEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_fileoperations::FileOperationsEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileOperationsEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleOperationCopy((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5]))); break;
        case 1: _t->handleOperationCopy((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[7]))); break;
        case 2: _t->handleOperationCut((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5]))); break;
        case 3: _t->handleOperationCut((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[7]))); break;
        case 4: _t->handleOperationDeletes((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4]))); break;
        case 5: _t->handleOperationDeletes((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 6: { bool _r = _t->handleOperationOpenFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->handleOperationOpenFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->handleOperationOpenFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[4]))); break;
        case 9: { bool _r = _t->handleOperationOpenFilesByApp((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->handleOperationOpenFilesByApp((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[5]))); break;
        case 11: { bool _r = _t->handleOperationRenameFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->handleOperationRenameFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 13: { bool _r = _t->handleOperationRenameFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->handleOperationRenameFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,QString>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 15: { bool _r = _t->handleOperationRenameFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,dfmbase::AbstractJobHandler::FileNameAddFlag>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->handleOperationRenameFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<QString,dfmbase::AbstractJobHandler::FileNameAddFlag>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[5]))); break;
        case 17: { bool _r = _t->handleOperationMkdir((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->handleOperationMkdir((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[4]))); break;
        case 19: { QString _r = _t->handleOperationTouchFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::CreateFileType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->handleOperationTouchFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->handleOperationTouchFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::CreateFileType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 22: _t->handleOperationTouchFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 23: { bool _r = _t->handleOperationLinkFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->handleOperationLinkFile((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[7]))); break;
        case 25: { bool _r = _t->handleOperationSetPermission((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileDevice::Permissions>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->handleOperationSetPermission((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QFileDevice::Permissions>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[5]))); break;
        case 27: { bool _r = _t->handleOperationWriteToClipboard((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::ClipBoard::ClipboardAction>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->handleOperationWriteDataToClipboard((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeData*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->handleOperationOpenInTerminal((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->handleOperationSaveOperations((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 31: _t->handleOperationCleanSaveOperationsStack(); break;
        case 32: _t->handleOperationRevocation((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[2]))); break;
        case 33: { bool _r = _t->handleOperationHideFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->handleOperationHideFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[4]))); break;
        case 35: { bool _r = _t->handleShortCut((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->handleShortCutPaste((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->handleOperationSaveRedoOperations((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 38: _t->handleOperationCleanByUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 39: _t->handleRecoveryOperationRedoRecovery((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[2]))); break;
        case 40: _t->handleSaveRedoOpt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 41: _t->handleOperationUndoDeletes((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5]))); break;
        case 42: _t->handleOperationUndoCut((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[6]))); break;
        case 43: _t->handleOperationFilesPreview((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3]))); break;
        case 44: { bool _r = _t->handleIsSubFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::CreateFileType >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::CreateFileType >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileDevice::Permissions >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QFileDevice::Permissions >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::ClipBoard::ClipboardAction >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dfmplugin_fileoperations::FileOperationsEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_fileoperations::FileOperationsEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations27FileOperationsEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_fileoperations::FileOperationsEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
