// SPDX-FileCopyrightText: 2021 - 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "dfmextactionprivate.h"

USING_DFMEXT_NAMESPACE

DFMExtActionPrivate::DFMExtActionPrivate()
{
}

DFMExtActionPrivate::~DFMExtActionPrivate()
{
}
