/****************************************************************************
** Meta object code from reading C++ file 'application.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/base/application/application.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'application.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase11ApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::Application::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase11ApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::Application",
        "appAttributeChanged",
        "",
        "ApplicationAttribute",
        "aa",
        "QVariant",
        "value",
        "genericAttributeChanged",
        "GenericAttribute",
        "ga",
        "appAttributeEdited",
        "genericAttributeEdited",
        "iconSizeLevelChanged",
        "level",
        "gridDensityLevelChanged",
        "listHeightLevelChanged",
        "viewModeChanged",
        "mode",
        "previewCompressFileChanged",
        "enable",
        "showedFileSuffixChanged",
        "previewAttributeChanged",
        "showedHiddenFilesChanged",
        "csdClickableAreaAttributeChanged",
        "enabled",
        "indexFullTextSearchChanged",
        "genericSettingCreated",
        "Settings*",
        "settings",
        "appSettingCreated",
        "clearSearchHistory",
        "winId",
        "kAllwayOpenOnNewWindow",
        "kIconSizeLevel",
        "kViewMode",
        "kViewSizeAdjustable",
        "kViewComppactMode",
        "kViewAutoCompace",
        "kOpenFileMode",
        "kUrlOfNewWindow",
        "kUrlOfNewTab",
        "kThemeName",
        "kFileAndDirMixedSort",
        "kListItemExpandable",
        "kGridDensityLevel",
        "kListHeightLevel",
        "kPreviewCompressFile",
        "kPreviewTextFile",
        "kPreviewDocumentFile",
        "kPreviewImage",
        "kPreviewVideo",
        "kPreviewAudio",
        "kAutoMount",
        "kAutoMountAndOpen",
        "kAlwaysShowOfflineRemoteConnections",
        "kMergeTheEntriesOfSambaSharedFolders",
        "kOverrideFileChooserDialog",
        "kShowedHiddenOnSearch",
        "kShowedHiddenFiles",
        "kShowedFileSuffix",
        "kDisableNonRemovableDeviceUnmount",
        "kHiddenSystemPartition",
        "kShowCsdCrumbBarClickableArea",
        "kShowFileSystemTagOnDiskIcon",
        "kShowDeleteConfirmDialog",
        "kHideLoopPartitions",
        "kShowThunmbnailInRemote",
        "TriggerAttribute",
        "kRestoreViewMode",
        "kClearSearchHistory"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'appAttributeChanged'
        QtMocHelpers::SignalData<void(enum ApplicationAttribute, const QVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'genericAttributeChanged'
        QtMocHelpers::SignalData<void(enum GenericAttribute, const QVariant &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'appAttributeEdited'
        QtMocHelpers::SignalData<void(enum ApplicationAttribute, const QVariant &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'genericAttributeEdited'
        QtMocHelpers::SignalData<void(enum GenericAttribute, const QVariant &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'iconSizeLevelChanged'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'gridDensityLevelChanged'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'listHeightLevelChanged'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'previewCompressFileChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'showedFileSuffixChanged'
        QtMocHelpers::SignalData<void(bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'previewAttributeChanged'
        QtMocHelpers::SignalData<void(enum GenericAttribute, bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 19 },
        }}),
        // Signal 'showedHiddenFilesChanged'
        QtMocHelpers::SignalData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'csdClickableAreaAttributeChanged'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'indexFullTextSearchChanged'
        QtMocHelpers::SignalData<void(bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'genericSettingCreated'
        QtMocHelpers::SignalData<void(Settings *)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'appSettingCreated'
        QtMocHelpers::SignalData<void(Settings *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Signal 'clearSearchHistory'
        QtMocHelpers::SignalData<void(quint64)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ApplicationAttribute'
        QtMocHelpers::EnumData<enum ApplicationAttribute>(3, 3, QMC::EnumFlags{}).add({
            {   32, ApplicationAttribute::kAllwayOpenOnNewWindow },
            {   33, ApplicationAttribute::kIconSizeLevel },
            {   34, ApplicationAttribute::kViewMode },
            {   35, ApplicationAttribute::kViewSizeAdjustable },
            {   36, ApplicationAttribute::kViewComppactMode },
            {   37, ApplicationAttribute::kViewAutoCompace },
            {   38, ApplicationAttribute::kOpenFileMode },
            {   39, ApplicationAttribute::kUrlOfNewWindow },
            {   40, ApplicationAttribute::kUrlOfNewTab },
            {   41, ApplicationAttribute::kThemeName },
            {   42, ApplicationAttribute::kFileAndDirMixedSort },
            {   43, ApplicationAttribute::kListItemExpandable },
            {   44, ApplicationAttribute::kGridDensityLevel },
            {   45, ApplicationAttribute::kListHeightLevel },
        }),
        // enum 'GenericAttribute'
        QtMocHelpers::EnumData<enum GenericAttribute>(8, 8, QMC::EnumFlags{}).add({
            {   46, GenericAttribute::kPreviewCompressFile },
            {   47, GenericAttribute::kPreviewTextFile },
            {   48, GenericAttribute::kPreviewDocumentFile },
            {   49, GenericAttribute::kPreviewImage },
            {   50, GenericAttribute::kPreviewVideo },
            {   51, GenericAttribute::kPreviewAudio },
            {   52, GenericAttribute::kAutoMount },
            {   53, GenericAttribute::kAutoMountAndOpen },
            {   54, GenericAttribute::kAlwaysShowOfflineRemoteConnections },
            {   55, GenericAttribute::kMergeTheEntriesOfSambaSharedFolders },
            {   56, GenericAttribute::kOverrideFileChooserDialog },
            {   57, GenericAttribute::kShowedHiddenOnSearch },
            {   58, GenericAttribute::kShowedHiddenFiles },
            {   59, GenericAttribute::kShowedFileSuffix },
            {   60, GenericAttribute::kDisableNonRemovableDeviceUnmount },
            {   61, GenericAttribute::kHiddenSystemPartition },
            {   62, GenericAttribute::kShowCsdCrumbBarClickableArea },
            {   63, GenericAttribute::kShowFileSystemTagOnDiskIcon },
            {   64, GenericAttribute::kShowDeleteConfirmDialog },
            {   65, GenericAttribute::kHideLoopPartitions },
            {   66, GenericAttribute::kShowThunmbnailInRemote },
        }),
        // enum 'TriggerAttribute'
        QtMocHelpers::EnumData<enum TriggerAttribute>(67, 67, QMC::EnumFlags{}).add({
            {   68, TriggerAttribute::kRestoreViewMode },
            {   69, TriggerAttribute::kClearSearchHistory },
        }),
    };
    return QtMocHelpers::metaObjectData<Application, qt_meta_tag_ZN7dfmbase11ApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::Application::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase11ApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase11ApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase11ApplicationE_t>.metaTypes,
    nullptr
} };

void dfmbase::Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Application *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->appAttributeChanged((*reinterpret_cast<std::add_pointer_t<enum ApplicationAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 1: _t->genericAttributeChanged((*reinterpret_cast<std::add_pointer_t<enum GenericAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 2: _t->appAttributeEdited((*reinterpret_cast<std::add_pointer_t<enum ApplicationAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 3: _t->genericAttributeEdited((*reinterpret_cast<std::add_pointer_t<enum GenericAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 4: _t->iconSizeLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->gridDensityLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->listHeightLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->viewModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->previewCompressFileChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->showedFileSuffixChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->previewAttributeChanged((*reinterpret_cast<std::add_pointer_t<enum GenericAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->showedHiddenFilesChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->csdClickableAreaAttributeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->indexFullTextSearchChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->genericSettingCreated((*reinterpret_cast<std::add_pointer_t<Settings*>>(_a[1]))); break;
        case 15: _t->appSettingCreated((*reinterpret_cast<std::add_pointer_t<Settings*>>(_a[1]))); break;
        case 16: _t->clearSearchHistory((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Application::*)(ApplicationAttribute , const QVariant & )>(_a, &Application::appAttributeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(GenericAttribute , const QVariant & )>(_a, &Application::genericAttributeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(ApplicationAttribute , const QVariant & )>(_a, &Application::appAttributeEdited, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(GenericAttribute , const QVariant & )>(_a, &Application::genericAttributeEdited, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(int )>(_a, &Application::iconSizeLevelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(int )>(_a, &Application::gridDensityLevelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(int )>(_a, &Application::listHeightLevelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(int )>(_a, &Application::viewModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(bool )>(_a, &Application::previewCompressFileChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(bool )>(_a, &Application::showedFileSuffixChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(GenericAttribute , bool )>(_a, &Application::previewAttributeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(bool )>(_a, &Application::showedHiddenFilesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(bool )>(_a, &Application::csdClickableAreaAttributeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(bool )>(_a, &Application::indexFullTextSearchChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(Settings * )>(_a, &Application::genericSettingCreated, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(Settings * )>(_a, &Application::appSettingCreated, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Application::*)(quint64 )>(_a, &Application::clearSearchHistory, 16))
            return;
    }
}

const QMetaObject *dfmbase::Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase11ApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::Application::appAttributeChanged(ApplicationAttribute _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmbase::Application::genericAttributeChanged(GenericAttribute _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void dfmbase::Application::appAttributeEdited(ApplicationAttribute _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmbase::Application::genericAttributeEdited(GenericAttribute _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dfmbase::Application::iconSizeLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmbase::Application::gridDensityLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmbase::Application::listHeightLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dfmbase::Application::viewModeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dfmbase::Application::previewCompressFileChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dfmbase::Application::showedFileSuffixChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dfmbase::Application::previewAttributeChanged(GenericAttribute _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void dfmbase::Application::showedHiddenFilesChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dfmbase::Application::csdClickableAreaAttributeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dfmbase::Application::indexFullTextSearchChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void dfmbase::Application::genericSettingCreated(Settings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void dfmbase::Application::appSettingCreated(Settings * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void dfmbase::Application::clearSearchHistory(quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}
QT_WARNING_POP
