/****************************************************************************
** Meta object code from reading C++ file 'docsheet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../dde-file-manager/src/apps/dde-file-manager-preview/pluginpreviews/pdf-preview/docsheet.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'docsheet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t {};
} // unnamed namespace

template <> constexpr inline auto plugin_filepreview::DocSheet::qt_create_metaobjectdata<qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "plugin_filepreview::DocSheet",
        "sigPageModified",
        "",
        "index",
        "sigFileOpened",
        "DocSheet*",
        "sheet",
        "Document::Error",
        "error",
        "onOpened",
        "onBrowserPageChanged",
        "page",
        "onExtractPassword",
        "password"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigPageModified'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'sigFileOpened'
        QtMocHelpers::SignalData<void(DocSheet *, Document::Error)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onOpened'
        QtMocHelpers::SlotData<void(Document::Error)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onBrowserPageChanged'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'onExtractPassword'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocSheet, qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject plugin_filepreview::DocSheet::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Widget::DSplitter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>.metaTypes,
    nullptr
} };

void plugin_filepreview::DocSheet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocSheet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigPageModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->sigFileOpened((*reinterpret_cast<std::add_pointer_t<DocSheet*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Document::Error>>(_a[2]))); break;
        case 2: _t->onOpened((*reinterpret_cast<std::add_pointer_t<Document::Error>>(_a[1]))); break;
        case 3: _t->onBrowserPageChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->onExtractPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DocSheet* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocSheet::*)(int )>(_a, &DocSheet::sigPageModified, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocSheet::*)(DocSheet * , Document::Error )>(_a, &DocSheet::sigFileOpened, 1))
            return;
    }
}

const QMetaObject *plugin_filepreview::DocSheet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *plugin_filepreview::DocSheet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview8DocSheetE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Widget::DSplitter::qt_metacast(_clname);
}

int plugin_filepreview::DocSheet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Widget::DSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void plugin_filepreview::DocSheet::sigPageModified(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void plugin_filepreview::DocSheet::sigFileOpened(DocSheet * _t1, Document::Error _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
