/****************************************************************************
** Meta object code from reading C++ file 'filedialogmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filedialogmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialogmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FiledialogmanagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FiledialogmanagerAdaptor",
        "D-Bus Interface",
        "com.deepin.filemanager.filedialogmanager",
        "D-Bus Introspection",
        "  <interface name=\"com.deepin.filemanager.filedialogmanager\">\n "
        "   <method name=\"createDialog\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"key\"/>\n      <arg direction=\"out\" type=\"o\" na"
        "me=\"path\"/>\n    </method>\n    <method name=\"destroyDialog\">\n"
        "      <arg direction=\"in\" type=\"o\" name=\"path\"/>\n    </meth"
        "od>\n    <method name=\"dialogs\">\n      <arg direction=\"out\" t"
        "ype=\"ao\" name=\"dialogObjectList\"/>\n    </method>\n    <method"
        " name=\"errorString\">\n      <arg direction=\"out\" type=\"s\" na"
        "me=\"error\"/>\n    </method>\n    <method name=\"isUseFileChooser"
        "Dialog\">\n      <arg direction=\"out\" type=\"b\" name=\"ok\"/>\n"
        "    </method>\n    <method name=\"canUseFileChooserDialog\">\n    "
        "  <arg direction=\"out\" type=\"b\" name=\"ok\"/>\n      <arg dire"
        "ction=\"in\" type=\"s\" name=\"group\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"executableFileName\"/>\n    </method>\n    <"
        "method name=\"globPatternsForMime\">\n      <arg direction=\"in\" "
        "type=\"s\" name=\"mime\"/>\n      <arg direction=\"out\" type=\"as"
        "\" name=\"patterns\"/>\n    </method>\n    <method name=\"monitorF"
        "iles\">\n      <arg direction=\"out\" type=\"as\" name=\"files\"/>"
        "\n    </method>\n    <method name=\"showBluetoothTransDialog\">\n "
        "     <arg direction=\"in\" type=\"s\" name=\"id\"/>\n      <arg di"
        "rection=\"in\" type=\"as\" name=\"URIs\"/>\n    </method>\n  </int"
        "erface>\n",
        "canUseFileChooserDialog",
        "",
        "group",
        "executableFileName",
        "createDialog",
        "QDBusObjectPath",
        "key",
        "destroyDialog",
        "path",
        "dialogs",
        "QList<QDBusObjectPath>",
        "errorString",
        "globPatternsForMime",
        "mime",
        "isUseFileChooserDialog",
        "monitorFiles",
        "showBluetoothTransDialog",
        "id",
        "URIs"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'canUseFileChooserDialog'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'createDialog'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &)>(9, 6, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 11 },
        }}),
        // Slot 'destroyDialog'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 13 },
        }}),
        // Slot 'dialogs'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>()>(14, 6, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'errorString'
        QtMocHelpers::SlotData<QString()>(16, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'globPatternsForMime'
        QtMocHelpers::SlotData<QStringList(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'isUseFileChooserDialog'
        QtMocHelpers::SlotData<bool()>(19, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'monitorFiles'
        QtMocHelpers::SlotData<QStringList()>(20, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'showBluetoothTransDialog'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QStringList, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FiledialogmanagerAdaptor, qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FiledialogmanagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>.metaTypes,
    nullptr
} };

void FiledialogmanagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FiledialogmanagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->canUseFileChooserDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusObjectPath _r = _t->createDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->destroyDialog((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: { QList<QDBusObjectPath> _r = _t->dialogs();
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->errorString();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->globPatternsForMime((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->isUseFileChooserDialog();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->monitorFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->showBluetoothTransDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *FiledialogmanagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FiledialogmanagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24FiledialogmanagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FiledialogmanagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
