/****************************************************************************
** Meta object code from reading C++ file 'canvasorganizer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/mode/canvasorganizer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasorganizer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::CanvasOrganizer::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::CanvasOrganizer",
        "collectionChanged",
        "",
        "hideAllKeyPressed",
        "filterDataRested",
        "QList<QUrl>*",
        "urls",
        "filterDataInserted",
        "QUrl",
        "url",
        "filterDataRenamed",
        "oldUrl",
        "newUrl",
        "filterDropData",
        "viewIndex",
        "const QMimeData*",
        "mimeData",
        "QPoint",
        "viewPoint",
        "extData",
        "filterShortcutkeyPress",
        "key",
        "modifiers",
        "filterKeyPress",
        "filterWheel",
        "angleDelta",
        "ctrl",
        "filterContextMenu",
        "dir",
        "QList<QUrl>",
        "files",
        "viewPos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collectionChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideAllKeyPressed'
        QtMocHelpers::SignalData<void() const>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'filterDataRested'
        QtMocHelpers::SlotData<bool(QList<QUrl> *)>(4, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'filterDataInserted'
        QtMocHelpers::SlotData<bool(const QUrl &)>(7, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'filterDataRenamed'
        QtMocHelpers::SlotData<bool(const QUrl &, const QUrl &)>(10, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 8, 11 }, { 0x80000000 | 8, 12 },
        }}),
        // Slot 'filterDropData'
        QtMocHelpers::SlotData<bool(int, const QMimeData *, const QPoint &, void *)>(13, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::VoidStar, 19 },
        }}),
        // Slot 'filterShortcutkeyPress'
        QtMocHelpers::SlotData<bool(int, int, int) const>(20, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'filterKeyPress'
        QtMocHelpers::SlotData<bool(int, int, int) const>(23, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'filterWheel'
        QtMocHelpers::SlotData<bool(int, const QPoint &, bool) const>(24, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 17, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'filterContextMenu'
        QtMocHelpers::SlotData<bool(int, const QUrl &, const QList<QUrl> &, const QPoint &) const>(27, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 8, 28 }, { 0x80000000 | 29, 30 }, { 0x80000000 | 17, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasOrganizer, qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::CanvasOrganizer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::CanvasOrganizer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasOrganizer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collectionChanged(); break;
        case 1: _t->hideAllKeyPressed(); break;
        case 2: { bool _r = _t->filterDataRested((*reinterpret_cast<std::add_pointer_t<QList<QUrl>*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->filterDataInserted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->filterDataRenamed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->filterDropData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->filterShortcutkeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->filterKeyPress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->filterWheel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->filterContextMenu((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CanvasOrganizer::*)()>(_a, &CanvasOrganizer::collectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CanvasOrganizer::*)() const>(_a, &CanvasOrganizer::hideAllKeyPressed, 1))
            return;
    }
}

const QMetaObject *ddplugin_organizer::CanvasOrganizer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::CanvasOrganizer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CanvasOrganizerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_organizer::CanvasOrganizer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_organizer::CanvasOrganizer::collectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ddplugin_organizer::CanvasOrganizer::hideAllKeyPressed()const
{
    QMetaObject::activate(const_cast< ddplugin_organizer::CanvasOrganizer *>(this), &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
