/****************************************************************************
** Meta object code from reading C++ file 'bluetoothmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/bluetooth/private/bluetoothmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_utils::BluetoothManager::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_utils::BluetoothManager",
        "transferProgressUpdated",
        "",
        "sessionPath",
        "total",
        "transferred",
        "currFileIndex",
        "transferCancledByRemote",
        "fileTransferFinished",
        "filePath",
        "transferFailed",
        "errMsg",
        "transferEstablishFinish",
        "senderToken",
        "adapterAdded",
        "const BluetoothAdapter*",
        "adapter",
        "adapterRemoved",
        "refresh",
        "showBluetoothSettings",
        "sendFiles",
        "id",
        "cancelTransfer",
        "canSendBluetoothRequest"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transferProgressUpdated'
        QtMocHelpers::SignalData<void(const QString &, qulonglong, qulonglong, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::ULongLong, 4 }, { QMetaType::ULongLong, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'transferCancledByRemote'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'fileTransferFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'transferFailed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'transferEstablishFinish'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'adapterAdded'
        QtMocHelpers::SignalData<void(const BluetoothAdapter *) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'adapterRemoved'
        QtMocHelpers::SignalData<void(const BluetoothAdapter *) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showBluetoothSettings'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendFiles'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QStringList, 9 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'cancelTransfer'
        QtMocHelpers::SlotData<bool(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'canSendBluetoothRequest'
        QtMocHelpers::SlotData<bool()>(23, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BluetoothManager, qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_utils::BluetoothManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_utils::BluetoothManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BluetoothManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transferProgressUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 1: _t->transferCancledByRemote((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->fileTransferFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->transferFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->transferEstablishFinish((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->adapterAdded((*reinterpret_cast<std::add_pointer_t<const BluetoothAdapter*>>(_a[1]))); break;
        case 6: _t->adapterRemoved((*reinterpret_cast<std::add_pointer_t<const BluetoothAdapter*>>(_a[1]))); break;
        case 7: _t->refresh(); break;
        case 8: _t->showBluetoothSettings(); break;
        case 9: _t->sendFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: { bool _r = _t->cancelTransfer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->canSendBluetoothRequest();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const QString & , qulonglong , qulonglong , int )>(_a, &BluetoothManager::transferProgressUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const QString & )>(_a, &BluetoothManager::transferCancledByRemote, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const QString & , const QString & )>(_a, &BluetoothManager::fileTransferFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const QString & , const QString & , const QString & )>(_a, &BluetoothManager::transferFailed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const QString & , const QString & , const QString & )>(_a, &BluetoothManager::transferEstablishFinish, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const BluetoothAdapter * ) const>(_a, &BluetoothManager::adapterAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BluetoothManager::*)(const BluetoothAdapter * ) const>(_a, &BluetoothManager::adapterRemoved, 6))
            return;
    }
}

const QMetaObject *dfmplugin_utils::BluetoothManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::BluetoothManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils16BluetoothManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::BluetoothManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::BluetoothManager::transferProgressUpdated(const QString & _t1, qulonglong _t2, qulonglong _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void dfmplugin_utils::BluetoothManager::transferCancledByRemote(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_utils::BluetoothManager::fileTransferFinished(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmplugin_utils::BluetoothManager::transferFailed(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void dfmplugin_utils::BluetoothManager::transferEstablishFinish(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void dfmplugin_utils::BluetoothManager::adapterAdded(const BluetoothAdapter * _t1)const
{
    QMetaObject::activate<void>(const_cast< dfmplugin_utils::BluetoothManager *>(this), &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmplugin_utils::BluetoothManager::adapterRemoved(const BluetoothAdapter * _t1)const
{
    QMetaObject::activate<void>(const_cast< dfmplugin_utils::BluetoothManager *>(this), &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
