/****************************************************************************
** Meta object code from reading C++ file 'eventshandler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-disk-encrypt-entry/events/eventshandler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventshandler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_diskenc::EventsHandler::qt_create_metaobjectdata<qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_diskenc::EventsHandler",
        "onPreencryptResult",
        "",
        "onEncryptResult",
        "onEncryptProgress",
        "onDecryptResult",
        "onDecryptProgress",
        "onChgPassphraseResult",
        "onRequestEncryptParams",
        "QVariantMap",
        "encConfig",
        "ignoreParamRequest",
        "acquirePassphrase",
        "dev",
        "bool&",
        "cancelled",
        "acquirePassphraseByPIN",
        "acquirePassphraseByTPM",
        "acquirePassphraseByRec",
        "showPreEncryptError",
        "device",
        "devName",
        "code",
        "showDecryptError",
        "showChgPwdError",
        "requestReboot",
        "canUnlock"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onPreencryptResult'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'onEncryptResult'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int, const QString &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'onEncryptProgress'
        QtMocHelpers::SlotData<void(const QString &, const QString &, double)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Double, 2 },
        }}),
        // Slot 'onDecryptResult'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'onDecryptProgress'
        QtMocHelpers::SlotData<void(const QString &, const QString &, double)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Double, 2 },
        }}),
        // Slot 'onChgPassphraseResult'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, int)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'onRequestEncryptParams'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'ignoreParamRequest'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'acquirePassphrase'
        QtMocHelpers::SlotData<QString(const QString &, bool &)>(12, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'acquirePassphraseByPIN'
        QtMocHelpers::SlotData<QString(const QString &, bool &)>(16, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'acquirePassphraseByTPM'
        QtMocHelpers::SlotData<QString(const QString &, bool &)>(17, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'acquirePassphraseByRec'
        QtMocHelpers::SlotData<QString(const QString &, bool &)>(18, 2, QMC::AccessPrivate, QMetaType::QString, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'showPreEncryptError'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'showDecryptError'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'showChgPwdError'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::QString, 21 }, { QMetaType::Int, 22 },
        }}),
        // Slot 'requestReboot'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'canUnlock'
        QtMocHelpers::SlotData<bool(const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EventsHandler, qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_diskenc::EventsHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_diskenc::EventsHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EventsHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onPreencryptResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 1: _t->onEncryptResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->onEncryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 3: _t->onDecryptResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 4: _t->onDecryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 5: _t->onChgPassphraseResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 6: _t->onRequestEncryptParams((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: _t->ignoreParamRequest(); break;
        case 8: { QString _r = _t->acquirePassphrase((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->acquirePassphraseByPIN((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { QString _r = _t->acquirePassphraseByTPM((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->acquirePassphraseByRec((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->showPreEncryptError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->showDecryptError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 14: _t->showChgPwdError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->requestReboot(); break;
        case 16: { bool _r = _t->canUnlock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_diskenc::EventsHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_diskenc::EventsHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17dfmplugin_diskenc13EventsHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_diskenc::EventsHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}
QT_WARNING_POP
