/****************************************************************************
** Meta object code from reading C++ file 'configpresenter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/config/configpresenter.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'configpresenter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::ConfigPresenter::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::ConfigPresenter",
        "changeEnableState",
        "",
        "e",
        "changeEnableVisibilityState",
        "v",
        "changeHideAllKeySequence",
        "QKeySequence",
        "switchToNormalized",
        "releaseCollection",
        "category",
        "switchToCustom",
        "changeDisplaySize",
        "newCollection",
        "QList<QUrl>",
        "showOptionWindow",
        "reorganizeDesktop",
        "optimizeStateChanged",
        "onDConfigChanged",
        "cfg",
        "key"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changeEnableState'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'changeEnableVisibilityState'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'changeHideAllKeySequence'
        QtMocHelpers::SignalData<void(const QKeySequence &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'switchToNormalized'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'releaseCollection'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'switchToCustom'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changeDisplaySize'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'newCollection'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'showOptionWindow'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reorganizeDesktop'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'optimizeStateChanged'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'onDConfigChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConfigPresenter, qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::ConfigPresenter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::ConfigPresenter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConfigPresenter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeEnableState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->changeEnableVisibilityState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->changeHideAllKeySequence((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 3: _t->switchToNormalized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->releaseCollection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->switchToCustom(); break;
        case 6: _t->changeDisplaySize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->newCollection((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 8: _t->showOptionWindow(); break;
        case 9: _t->reorganizeDesktop(); break;
        case 10: _t->optimizeStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onDConfigChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(bool )>(_a, &ConfigPresenter::changeEnableState, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(bool )>(_a, &ConfigPresenter::changeEnableVisibilityState, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(const QKeySequence & )>(_a, &ConfigPresenter::changeHideAllKeySequence, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(int )>(_a, &ConfigPresenter::switchToNormalized, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(int )>(_a, &ConfigPresenter::releaseCollection, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)()>(_a, &ConfigPresenter::switchToCustom, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(int )>(_a, &ConfigPresenter::changeDisplaySize, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(const QList<QUrl> & )>(_a, &ConfigPresenter::newCollection, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)()>(_a, &ConfigPresenter::showOptionWindow, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)()>(_a, &ConfigPresenter::reorganizeDesktop, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConfigPresenter::*)(bool )>(_a, &ConfigPresenter::optimizeStateChanged, 10))
            return;
    }
}

const QMetaObject *ddplugin_organizer::ConfigPresenter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::ConfigPresenter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15ConfigPresenterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_organizer::ConfigPresenter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_organizer::ConfigPresenter::changeEnableState(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ddplugin_organizer::ConfigPresenter::changeEnableVisibilityState(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ddplugin_organizer::ConfigPresenter::changeHideAllKeySequence(const QKeySequence & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ddplugin_organizer::ConfigPresenter::switchToNormalized(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ddplugin_organizer::ConfigPresenter::releaseCollection(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ddplugin_organizer::ConfigPresenter::switchToCustom()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ddplugin_organizer::ConfigPresenter::changeDisplaySize(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ddplugin_organizer::ConfigPresenter::newCollection(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ddplugin_organizer::ConfigPresenter::showOptionWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ddplugin_organizer::ConfigPresenter::reorganizeDesktop()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ddplugin_organizer::ConfigPresenter::optimizeStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
