/****************************************************************************
** Meta object code from reading C++ file 'rootinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/models/rootinfo.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rootinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::RootInfo::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::RootInfo",
        "itemAdded",
        "",
        "iteratorLocalFiles",
        "key",
        "QList<SortInfoPointer>",
        "children",
        "dfmio::DEnumerator::SortRoleCompareFlag",
        "sortRole",
        "Qt::SortOrder",
        "sortOrder",
        "isMixDirAndFile",
        "iteratorAddFile",
        "SortInfoPointer",
        "sortInfo",
        "FileInfoPointer",
        "info",
        "iteratorAddFiles",
        "sortInfos",
        "QList<FileInfoPointer>",
        "infos",
        "watcherAddFiles",
        "watcherRemoveFiles",
        "traversalFinished",
        "sourceDatas",
        "isFinished",
        "watcherUpdateFile",
        "watcherUpdateFiles",
        "watcherUpdateHideFile",
        "QUrl",
        "hidUrl",
        "requestSort",
        "dirUrl",
        "requestCloseTab",
        "url",
        "requestTreeSortDir",
        "parent",
        "renameFileProcessStarted",
        "requestClearRoot",
        "doFileDeleted",
        "dofileMoved",
        "fromUrl",
        "toUrl",
        "dofileCreated",
        "doFileUpdated",
        "doWatcherEvent",
        "doThreadWatcherEvent",
        "handleTraversalResult",
        "child",
        "travseToken",
        "handleTraversalResults",
        "handleTraversalLocalResult",
        "handleTraversalFinish",
        "handleTraversalSort",
        "handleGetSourceData",
        "currentToken",
        "startWatcher"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iteratorLocalFiles'
        QtMocHelpers::SignalData<void(const QString &, const QList<SortInfoPointer>, const dfmio::DEnumerator::SortRoleCompareFlag, const Qt::SortOrder, const bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'iteratorAddFile'
        QtMocHelpers::SignalData<void(const QString &, const SortInfoPointer, const FileInfoPointer)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 13, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'iteratorAddFiles'
        QtMocHelpers::SignalData<void(const QString &, const QList<SortInfoPointer>, const QList<FileInfoPointer>)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 18 }, { 0x80000000 | 19, 20 },
        }}),
        // Signal 'watcherAddFiles'
        QtMocHelpers::SignalData<void(const QList<SortInfoPointer> &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'watcherRemoveFiles'
        QtMocHelpers::SignalData<void(const QList<SortInfoPointer> &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'traversalFinished'
        QtMocHelpers::SignalData<void(const QString &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'sourceDatas'
        QtMocHelpers::SignalData<void(const QString &, const QList<SortInfoPointer>, const dfmio::DEnumerator::SortRoleCompareFlag, const Qt::SortOrder, const bool, const bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
            { QMetaType::Bool, 11 }, { QMetaType::Bool, 25 },
        }}),
        // Signal 'watcherUpdateFile'
        QtMocHelpers::SignalData<void(const SortInfoPointer)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'watcherUpdateFiles'
        QtMocHelpers::SignalData<void(const QList<SortInfoPointer> &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 18 },
        }}),
        // Signal 'watcherUpdateHideFile'
        QtMocHelpers::SignalData<void(const QUrl &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Signal 'requestSort'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 29, 32 },
        }}),
        // Signal 'requestCloseTab'
        QtMocHelpers::SignalData<void(const QUrl &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 },
        }}),
        // Signal 'requestTreeSortDir'
        QtMocHelpers::SignalData<void(const QString &, const QUrl &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 29, 36 },
        }}),
        // Signal 'renameFileProcessStarted'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestClearRoot'
        QtMocHelpers::SignalData<void(const QUrl &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 },
        }}),
        // Slot 'doFileDeleted'
        QtMocHelpers::SlotData<void(const QUrl &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 },
        }}),
        // Slot 'dofileMoved'
        QtMocHelpers::SlotData<void(const QUrl &, const QUrl &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 41 }, { 0x80000000 | 29, 42 },
        }}),
        // Slot 'dofileCreated'
        QtMocHelpers::SlotData<void(const QUrl &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 },
        }}),
        // Slot 'doFileUpdated'
        QtMocHelpers::SlotData<void(const QUrl &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 },
        }}),
        // Slot 'doWatcherEvent'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doThreadWatcherEvent'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleTraversalResult'
        QtMocHelpers::SlotData<void(const FileInfoPointer &, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 48 }, { QMetaType::QString, 49 },
        }}),
        // Slot 'handleTraversalResults'
        QtMocHelpers::SlotData<void(const QList<FileInfoPointer>, const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 6 }, { QMetaType::QString, 49 },
        }}),
        // Slot 'handleTraversalLocalResult'
        QtMocHelpers::SlotData<void(QList<SortInfoPointer>, dfmio::DEnumerator::SortRoleCompareFlag, Qt::SortOrder, bool, const QString &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::Bool, 11 },
            { QMetaType::QString, 49 },
        }}),
        // Slot 'handleTraversalFinish'
        QtMocHelpers::SlotData<void(const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'handleTraversalSort'
        QtMocHelpers::SlotData<void(const QString &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 49 },
        }}),
        // Slot 'handleGetSourceData'
        QtMocHelpers::SlotData<void(const QString &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 55 },
        }}),
        // Slot 'startWatcher'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RootInfo, qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::RootInfo::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::RootInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RootInfo *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemAdded(); break;
        case 1: _t->iteratorLocalFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 2: _t->iteratorAddFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SortInfoPointer>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<FileInfoPointer>>(_a[3]))); break;
        case 3: _t->iteratorAddFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<FileInfoPointer>>>(_a[3]))); break;
        case 4: _t->watcherAddFiles((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 5: _t->watcherRemoveFiles((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 6: _t->traversalFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->sourceDatas((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 8: _t->watcherUpdateFile((*reinterpret_cast<std::add_pointer_t<SortInfoPointer>>(_a[1]))); break;
        case 9: _t->watcherUpdateFiles((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1]))); break;
        case 10: _t->watcherUpdateHideFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->requestSort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 12: _t->requestCloseTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->requestTreeSortDir((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 14: _t->renameFileProcessStarted(); break;
        case 15: _t->requestClearRoot((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: _t->doFileDeleted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->dofileMoved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 18: _t->dofileCreated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 19: _t->doFileUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 20: _t->doWatcherEvent(); break;
        case 21: _t->doThreadWatcherEvent(); break;
        case 22: _t->handleTraversalResult((*reinterpret_cast<std::add_pointer_t<FileInfoPointer>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->handleTraversalResults((*reinterpret_cast<std::add_pointer_t<QList<FileInfoPointer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->handleTraversalLocalResult((*reinterpret_cast<std::add_pointer_t<QList<SortInfoPointer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmio::DEnumerator::SortRoleCompareFlag>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 25: _t->handleTraversalFinish((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->handleTraversalSort((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->handleGetSourceData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->startWatcher(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileInfoPointer >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SortInfoPointer >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<FileInfoPointer> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SortInfoPointer >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FileInfoPointer >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<FileInfoPointer> >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<SortInfoPointer> >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmio::DEnumerator::SortRoleCompareFlag >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)()>(_a, &RootInfo::itemAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const QList<SortInfoPointer> , const dfmio::DEnumerator::SortRoleCompareFlag , const Qt::SortOrder , const bool )>(_a, &RootInfo::iteratorLocalFiles, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const SortInfoPointer , const FileInfoPointer )>(_a, &RootInfo::iteratorAddFile, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const QList<SortInfoPointer> , const QList<FileInfoPointer> )>(_a, &RootInfo::iteratorAddFiles, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QList<SortInfoPointer> & )>(_a, &RootInfo::watcherAddFiles, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QList<SortInfoPointer> & )>(_a, &RootInfo::watcherRemoveFiles, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & )>(_a, &RootInfo::traversalFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const QList<SortInfoPointer> , const dfmio::DEnumerator::SortRoleCompareFlag , const Qt::SortOrder , const bool , const bool )>(_a, &RootInfo::sourceDatas, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const SortInfoPointer )>(_a, &RootInfo::watcherUpdateFile, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QList<SortInfoPointer> & )>(_a, &RootInfo::watcherUpdateFiles, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QUrl & )>(_a, &RootInfo::watcherUpdateHideFile, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const QUrl & )>(_a, &RootInfo::requestSort, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QUrl & )>(_a, &RootInfo::requestCloseTab, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QString & , const QUrl & )>(_a, &RootInfo::requestTreeSortDir, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)()>(_a, &RootInfo::renameFileProcessStarted, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (RootInfo::*)(const QUrl & )>(_a, &RootInfo::requestClearRoot, 15))
            return;
    }
}

const QMetaObject *dfmplugin_workspace::RootInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::RootInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace8RootInfoE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_workspace::RootInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_workspace::RootInfo::itemAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmplugin_workspace::RootInfo::iteratorLocalFiles(const QString & _t1, const QList<SortInfoPointer> _t2, const dfmio::DEnumerator::SortRoleCompareFlag _t3, const Qt::SortOrder _t4, const bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 2
void dfmplugin_workspace::RootInfo::iteratorAddFile(const QString & _t1, const SortInfoPointer _t2, const FileInfoPointer _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void dfmplugin_workspace::RootInfo::iteratorAddFiles(const QString & _t1, const QList<SortInfoPointer> _t2, const QList<FileInfoPointer> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void dfmplugin_workspace::RootInfo::watcherAddFiles(const QList<SortInfoPointer> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmplugin_workspace::RootInfo::watcherRemoveFiles(const QList<SortInfoPointer> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmplugin_workspace::RootInfo::traversalFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dfmplugin_workspace::RootInfo::sourceDatas(const QString & _t1, const QList<SortInfoPointer> _t2, const dfmio::DEnumerator::SortRoleCompareFlag _t3, const Qt::SortOrder _t4, const bool _t5, const bool _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 8
void dfmplugin_workspace::RootInfo::watcherUpdateFile(const SortInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dfmplugin_workspace::RootInfo::watcherUpdateFiles(const QList<SortInfoPointer> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dfmplugin_workspace::RootInfo::watcherUpdateHideFile(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dfmplugin_workspace::RootInfo::requestSort(const QString & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void dfmplugin_workspace::RootInfo::requestCloseTab(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dfmplugin_workspace::RootInfo::requestTreeSortDir(const QString & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void dfmplugin_workspace::RootInfo::renameFileProcessStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void dfmplugin_workspace::RootInfo::requestClearRoot(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
