/****************************************************************************
** Meta object code from reading C++ file 'normalizedmodebroker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/mode/normalized/normalizedmodebroker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'normalizedmodebroker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::NormalizedModeBroker::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::NormalizedModeBroker",
        "refreshModel",
        "",
        "global",
        "ms",
        "file",
        "gridPoint",
        "QUrl",
        "item",
        "QPoint*",
        "point",
        "visualRect",
        "QRect",
        "id",
        "view",
        "QAbstractItemView*",
        "iconRect",
        "vrect",
        "selectAllItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'refreshModel'
        QtMocHelpers::SlotData<void(bool, int, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 }, { QMetaType::Int, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'gridPoint'
        QtMocHelpers::SlotData<QString(const QUrl &, QPoint *)>(6, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'visualRect'
        QtMocHelpers::SlotData<QRect(const QString &, const QUrl &)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'view'
        QtMocHelpers::SlotData<QAbstractItemView *(const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 15, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'iconRect'
        QtMocHelpers::SlotData<QRect(const QString &, QRect)>(16, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 12, 17 },
        }}),
        // Slot 'selectAllItems'
        QtMocHelpers::SlotData<bool()>(18, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NormalizedModeBroker, qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::NormalizedModeBroker::staticMetaObject = { {
    QMetaObject::SuperData::link<OrganizerBroker::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::NormalizedModeBroker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NormalizedModeBroker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshModel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: { QString _r = _t->gridPoint((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 2: { QRect _r = _t->visualRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 3: { QAbstractItemView* _r = _t->view((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAbstractItemView**>(_a[0]) = std::move(_r); }  break;
        case 4: { QRect _r = _t->iconRect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->selectAllItems();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ddplugin_organizer::NormalizedModeBroker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::NormalizedModeBroker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer20NormalizedModeBrokerE_t>.strings))
        return static_cast<void*>(this);
    return OrganizerBroker::qt_metacast(_clname);
}

int ddplugin_organizer::NormalizedModeBroker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = OrganizerBroker::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
