/****************************************************************************
** Meta object code from reading C++ file 'textindexclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-search/utils/textindexclient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textindexclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_search::TextIndexClient::qt_create_metaobjectdata<qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_search::TextIndexClient",
        "taskStarted",
        "",
        "TaskType",
        "type",
        "path",
        "taskFinished",
        "success",
        "taskFailed",
        "error",
        "taskProgressChanged",
        "count",
        "onDBusTaskFinished",
        "onDBusTaskProgressChanged",
        "Create",
        "Update",
        "Remove",
        "ServiceStatus",
        "Available",
        "Unavailable",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'taskStarted'
        QtMocHelpers::SignalData<void(enum TaskType, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'taskFinished'
        QtMocHelpers::SignalData<void(enum TaskType, const QString &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'taskFailed'
        QtMocHelpers::SignalData<void(enum TaskType, const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'taskProgressChanged'
        QtMocHelpers::SignalData<void(enum TaskType, const QString &, qlonglong)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { QMetaType::LongLong, 11 },
        }}),
        // Slot 'onDBusTaskFinished'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'onDBusTaskProgressChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &, qlonglong)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::LongLong, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TaskType'
        QtMocHelpers::EnumData<enum TaskType>(3, 3, QMC::EnumIsScoped).add({
            {   14, TaskType::Create },
            {   15, TaskType::Update },
            {   16, TaskType::Remove },
        }),
        // enum 'ServiceStatus'
        QtMocHelpers::EnumData<enum ServiceStatus>(17, 17, QMC::EnumIsScoped).add({
            {   18, ServiceStatus::Available },
            {   19, ServiceStatus::Unavailable },
            {   20, ServiceStatus::Error },
        }),
    };
    return QtMocHelpers::metaObjectData<TextIndexClient, qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_search::TextIndexClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>.metaTypes,
    nullptr
} };

void dfmplugin_search::TextIndexClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextIndexClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->taskStarted((*reinterpret_cast<std::add_pointer_t<enum TaskType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->taskFinished((*reinterpret_cast<std::add_pointer_t<enum TaskType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->taskFailed((*reinterpret_cast<std::add_pointer_t<enum TaskType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->taskProgressChanged((*reinterpret_cast<std::add_pointer_t<enum TaskType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 4: _t->onDBusTaskFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 5: _t->onDBusTaskProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextIndexClient::*)(TaskType , const QString & )>(_a, &TextIndexClient::taskStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextIndexClient::*)(TaskType , const QString & , bool )>(_a, &TextIndexClient::taskFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextIndexClient::*)(TaskType , const QString & , const QString & )>(_a, &TextIndexClient::taskFailed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextIndexClient::*)(TaskType , const QString & , qlonglong )>(_a, &TextIndexClient::taskProgressChanged, 3))
            return;
    }
}

const QMetaObject *dfmplugin_search::TextIndexClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_search::TextIndexClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16dfmplugin_search15TextIndexClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_search::TextIndexClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_search::TextIndexClient::taskStarted(TaskType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmplugin_search::TextIndexClient::taskFinished(TaskType _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void dfmplugin_search::TextIndexClient::taskFailed(TaskType _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void dfmplugin_search::TextIndexClient::taskProgressChanged(TaskType _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
