/****************************************************************************
** Meta object code from reading C++ file 'core.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-core/core.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'core.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14dfmplugin_core4CoreE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_core::Core::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_core4CoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_core::Core",
        "onAllPluginsInitialized",
        "",
        "onAllPluginsStarted",
        "onWindowOpened",
        "windd"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAllPluginsInitialized'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAllPluginsStarted'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWindowOpened'
        QtMocHelpers::SlotData<void(quint64)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::ULongLong, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Core, qt_meta_tag_ZN14dfmplugin_core4CoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_core::Core::staticMetaObject = { {
    QMetaObject::SuperData::link<dpf::Plugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_core4CoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_core4CoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_core4CoreE_t>.metaTypes,
    nullptr
} };

void dfmplugin_core::Core::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Core *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAllPluginsInitialized(); break;
        case 1: _t->onAllPluginsStarted(); break;
        case 2: _t->onWindowOpened((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_core::Core::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_core::Core::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_core4CoreE_t>.strings))
        return static_cast<void*>(this);
    return dpf::Plugin::qt_metacast(_clname);
}

int dfmplugin_core::Core::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dpf::Plugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
using namespace dfmplugin_core;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_Core[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1d,  'o',  'r',  'g',  '.',  'd', 
    'e',  'e',  'p',  'i',  'n',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  '.',  'f',  'i',  'l', 
    'e',  'm',  'a',  'n',  'a',  'g',  'e',  'r', 
    // "className"
    0x03,  0x64,  'C',  'o',  'r',  'e', 
    // "MetaData"
    0x04,  0xaa,  0x68,  'C',  'a',  't',  'e',  'g', 
    'o',  'r',  'y',  0x60,  0x6d,  'C',  'o',  'm', 
    'p',  'a',  't',  'V',  'e',  'r',  's',  'i', 
    'o',  'n',  0x65,  '1',  '.',  '0',  '.',  '0', 
    0x69,  'C',  'o',  'p',  'y',  'r',  'i',  'g', 
    'h',  't',  0x78,  0x41,  'C',  'o',  'p',  'y', 
    'r',  'i',  'g',  'h',  't',  ' ',  '(',  'C', 
    ')',  ' ',  '2',  '0',  '2',  '1',  ' ',  '~', 
    ' ',  '2',  '0',  '2',  '2',  ' ',  'U',  'n', 
    'i',  'o',  'n',  't',  'e',  'c',  'h',  ' ', 
    'S',  'o',  'f',  't',  'w',  'a',  'r',  'e', 
    ' ',  'T',  'e',  'c',  'h',  'n',  'o',  'l', 
    'o',  'g',  'y',  ' ',  'C',  'o',  '.',  ',', 
    ' ',  'L',  't',  'd',  '.',  0x67,  'D',  'e', 
    'p',  'e',  'n',  'd',  's',  0x80,  0x6b,  'D', 
    'e',  's',  'c',  'r',  'i',  'p',  't',  'i', 
    'o',  'n',  0x78,  0x24,  'T',  'h',  'e',  ' ', 
    'c',  'o',  'r',  'e',  ' ',  'p',  'l',  'u', 
    'g',  'i',  'n',  ' ',  'f',  'o',  'r',  ' ', 
    't',  'h',  'e',  ' ',  'f',  'i',  'l',  'e', 
    'm',  'a',  'n',  'a',  'g',  'e',  'r',  '.', 
    0x67,  'L',  'i',  'c',  'e',  'n',  's',  'e', 
    0x80,  0x64,  'N',  'a',  'm',  'e',  0x6e,  'd', 
    'f',  'm',  'p',  'l',  'u',  'g',  'i',  'n', 
    '-',  'c',  'o',  'r',  'e',  0x67,  'U',  'r', 
    'l',  'L',  'i',  'n',  'k',  0x78,  0x19,  'h', 
    't',  't',  'p',  's',  ':',  '/',  '/',  'w', 
    'w',  'w',  '.',  'u',  'n',  'i',  'o',  'n', 
    't',  'e',  'c',  'h',  '.',  'c',  'o',  'm', 
    0x66,  'V',  'e',  'n',  'd',  'o',  'r',  0x78, 
    0x2b,  'T',  'h',  'e',  ' ',  'U',  'n',  'i', 
    'o',  'n',  't',  'e',  'c',  'h',  ' ',  'S', 
    'o',  'f',  't',  'w',  'a',  'r',  'e',  ' ', 
    'T',  'e',  'c',  'h',  'n',  'o',  'l',  'o', 
    'g',  'y',  ' ',  'C',  'o',  '.',  ',',  ' ', 
    'L',  't',  'd',  '.',  0x67,  'V',  'e',  'r', 
    's',  'i',  'o',  'n',  0x65,  '1',  '.',  '0', 
    '.',  '0', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(dfmplugin_core::Core, Core, qt_pluginMetaDataV2_Core)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_Core[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x1d,  'o',  'r',  'g',  '.',  'd', 
    'e',  'e',  'p',  'i',  'n',  '.',  'p',  'l', 
    'u',  'g',  'i',  'n',  '.',  'f',  'i',  'l', 
    'e',  'm',  'a',  'n',  'a',  'g',  'e',  'r', 
    // "className"
    0x03,  0x64,  'C',  'o',  'r',  'e', 
    // "MetaData"
    0x04,  0xaa,  0x68,  'C',  'a',  't',  'e',  'g', 
    'o',  'r',  'y',  0x60,  0x6d,  'C',  'o',  'm', 
    'p',  'a',  't',  'V',  'e',  'r',  's',  'i', 
    'o',  'n',  0x65,  '1',  '.',  '0',  '.',  '0', 
    0x69,  'C',  'o',  'p',  'y',  'r',  'i',  'g', 
    'h',  't',  0x78,  0x41,  'C',  'o',  'p',  'y', 
    'r',  'i',  'g',  'h',  't',  ' ',  '(',  'C', 
    ')',  ' ',  '2',  '0',  '2',  '1',  ' ',  '~', 
    ' ',  '2',  '0',  '2',  '2',  ' ',  'U',  'n', 
    'i',  'o',  'n',  't',  'e',  'c',  'h',  ' ', 
    'S',  'o',  'f',  't',  'w',  'a',  'r',  'e', 
    ' ',  'T',  'e',  'c',  'h',  'n',  'o',  'l', 
    'o',  'g',  'y',  ' ',  'C',  'o',  '.',  ',', 
    ' ',  'L',  't',  'd',  '.',  0x67,  'D',  'e', 
    'p',  'e',  'n',  'd',  's',  0x80,  0x6b,  'D', 
    'e',  's',  'c',  'r',  'i',  'p',  't',  'i', 
    'o',  'n',  0x78,  0x24,  'T',  'h',  'e',  ' ', 
    'c',  'o',  'r',  'e',  ' ',  'p',  'l',  'u', 
    'g',  'i',  'n',  ' ',  'f',  'o',  'r',  ' ', 
    't',  'h',  'e',  ' ',  'f',  'i',  'l',  'e', 
    'm',  'a',  'n',  'a',  'g',  'e',  'r',  '.', 
    0x67,  'L',  'i',  'c',  'e',  'n',  's',  'e', 
    0x80,  0x64,  'N',  'a',  'm',  'e',  0x6e,  'd', 
    'f',  'm',  'p',  'l',  'u',  'g',  'i',  'n', 
    '-',  'c',  'o',  'r',  'e',  0x67,  'U',  'r', 
    'l',  'L',  'i',  'n',  'k',  0x78,  0x19,  'h', 
    't',  't',  'p',  's',  ':',  '/',  '/',  'w', 
    'w',  'w',  '.',  'u',  'n',  'i',  'o',  'n', 
    't',  'e',  'c',  'h',  '.',  'c',  'o',  'm', 
    0x66,  'V',  'e',  'n',  'd',  'o',  'r',  0x78, 
    0x2b,  'T',  'h',  'e',  ' ',  'U',  'n',  'i', 
    'o',  'n',  't',  'e',  'c',  'h',  ' ',  'S', 
    'o',  'f',  't',  'w',  'a',  'r',  'e',  ' ', 
    'T',  'e',  'c',  'h',  'n',  'o',  'l',  'o', 
    'g',  'y',  ' ',  'C',  'o',  '.',  ',',  ' ', 
    'L',  't',  'd',  '.',  0x67,  'V',  'e',  'r', 
    's',  'i',  'o',  'n',  0x65,  '1',  '.',  '0', 
    '.',  '0', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(dfmplugin_core::Core, Core)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
