/****************************************************************************
** Meta object code from reading C++ file 'dbusdock1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-core/screen/dbus-private/dbusdock1.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusdock1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8DBusDockE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusDock::qt_create_metaobjectdata<qt_meta_tag_ZN8DBusDockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusDock",
        "DockAppSettingsSynced",
        "",
        "EntryAdded",
        "QDBusObjectPath",
        "in0",
        "in1",
        "EntryRemoved",
        "PluginSettingsSynced",
        "ServiceRestarted",
        "FrontendWindowRectChanged",
        "HideModeChanged",
        "__propertyChanged__",
        "QDBusMessage",
        "msg",
        "ActivateWindow",
        "QDBusPendingReply<>",
        "CancelPreviewWindow",
        "CloseWindow",
        "GetDockedAppsDesktopFiles",
        "QDBusPendingReply<QStringList>",
        "GetEntryIDs",
        "GetPluginSettings",
        "QDBusPendingReply<QString>",
        "IsDocked",
        "QDBusPendingReply<bool>",
        "IsOnDock",
        "MakeWindowAbove",
        "MaximizeWindow",
        "MergePluginSettings",
        "MinimizeWindow",
        "MoveEntry",
        "MoveWindow",
        "PreviewWindow",
        "QueryWindowIdentifyMethod",
        "RemovePluginSettings",
        "RequestDock",
        "RequestUndock",
        "SetFrontendWindowRect",
        "in2",
        "in3",
        "SetPluginSettings",
        "FrontendWindowRect",
        "DockRect",
        "HideMode",
        "HideState",
        "Position"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DockAppSettingsSynced'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EntryAdded'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'EntryRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'PluginSettingsSynced'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ServiceRestarted'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'FrontendWindowRectChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'HideModeChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot '__propertyChanged__'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'ActivateWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(15, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'CancelPreviewWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(17, 2, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'CloseWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(18, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'GetDockedAppsDesktopFiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(19, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'GetEntryIDs'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(21, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'GetPluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(22, 2, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'IsDocked'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'IsOnDock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'MakeWindowAbove'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(27, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MaximizeWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(28, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MergePluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(29, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'MinimizeWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(30, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'MoveEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int)>(31, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'MoveWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(32, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'PreviewWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(33, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'QueryWindowIdentifyMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(uint)>(34, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::UInt, 5 },
        }}),
        // Slot 'RemovePluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QStringList &)>(35, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 5 }, { QMetaType::QStringList, 6 },
        }}),
        // Slot 'RequestDock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, int)>(36, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Slot 'RequestUndock'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetFrontendWindowRect'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, int, uint, uint)>(38, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::UInt, 39 }, { QMetaType::UInt, 40 },
        }}),
        // Slot 'SetPluginSettings'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'FrontendWindowRect'
        QtMocHelpers::PropertyData<DockRect>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'HideMode'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'HideState'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'Position'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusDock, qt_meta_tag_ZN8DBusDockE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusDock::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DBusDockE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DBusDockE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8DBusDockE_t>.metaTypes,
    nullptr
} };

void DBusDock::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusDock *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DockAppSettingsSynced(); break;
        case 1: _t->EntryAdded((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->EntryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->PluginSettingsSynced(); break;
        case 4: _t->ServiceRestarted(); break;
        case 5: _t->FrontendWindowRectChanged(); break;
        case 6: _t->HideModeChanged(); break;
        case 7: _t->__propertyChanged__((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 8: { QDBusPendingReply<> _r = _t->ActivateWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<> _r = _t->CancelPreviewWindow();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->CloseWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QStringList> _r = _t->GetDockedAppsDesktopFiles();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QStringList> _r = _t->GetEntryIDs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->GetPluginSettings();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<bool> _r = _t->IsDocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<bool> _r = _t->IsOnDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->MakeWindowAbove((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->MaximizeWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->MergePluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->MinimizeWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->MoveEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->MoveWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->PreviewWindow((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QString> _r = _t->QueryWindowIdentifyMethod((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->RemovePluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<bool> _r = _t->RequestDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<bool> _r = _t->RequestUndock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->SetFrontendWindowRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->SetPluginSettings((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)()>(_a, &DBusDock::DockAppSettingsSynced, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)(const QDBusObjectPath & , int )>(_a, &DBusDock::EntryAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)(const QString & )>(_a, &DBusDock::EntryRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)()>(_a, &DBusDock::PluginSettingsSynced, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)()>(_a, &DBusDock::ServiceRestarted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)()>(_a, &DBusDock::FrontendWindowRectChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDock::*)()>(_a, &DBusDock::HideModeChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DockRect >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DockRect*>(_v) = _t->frontendWindowRect(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->hideMode(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->hideState(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->position(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setHideMode(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DBusDock::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusDock::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8DBusDockE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusDock::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DBusDock::DockAppSettingsSynced()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusDock::EntryAdded(const QDBusObjectPath & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void DBusDock::EntryRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DBusDock::PluginSettingsSynced()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DBusDock::ServiceRestarted()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DBusDock::FrontendWindowRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DBusDock::HideModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
