/****************************************************************************
** Meta object code from reading C++ file 'fileoperatorproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/view/operator/fileoperatorproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileoperatorproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::FileOperatorProxy::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::FileOperatorProxy",
        "filePastedCallback",
        "",
        "fileTouchedCallback",
        "fileRenamedCallback",
        "renameFile",
        "wid",
        "QUrl",
        "oldUrl",
        "newUrl",
        "touchFileData",
        "std::pair<QString,std::pair<int,QPoint>>",
        "clearTouchFileData",
        "renameFileData",
        "QHash<QUrl,QUrl>",
        "removeRenameFileData",
        "clearRenameFileData",
        "pasteFileData",
        "QSet<QUrl>",
        "removePasteFileData",
        "clearPasteFileData"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filePastedCallback'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileTouchedCallback'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileRenamedCallback'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'renameFile'
        QtMocHelpers::MethodData<void(int, const QUrl &, const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 7, 9 },
        }}),
        // Method 'touchFileData'
        QtMocHelpers::MethodData<QPair<QString,QPair<int,QPoint>>() const>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'clearTouchFileData'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'renameFileData'
        QtMocHelpers::MethodData<QHash<QUrl,QUrl>() const>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Method 'removeRenameFileData'
        QtMocHelpers::MethodData<void(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'clearRenameFileData'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'pasteFileData'
        QtMocHelpers::MethodData<QSet<QUrl>() const>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'removePasteFileData'
        QtMocHelpers::MethodData<void(const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'clearPasteFileData'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileOperatorProxy, qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::FileOperatorProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::FileOperatorProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileOperatorProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filePastedCallback(); break;
        case 1: _t->fileTouchedCallback(); break;
        case 2: _t->fileRenamedCallback(); break;
        case 3: _t->renameFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 4: { std::pair<QString,std::pair<int,QPoint>> _r = _t->touchFileData();
            if (_a[0]) *reinterpret_cast<std::pair<QString,std::pair<int,QPoint>>*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->clearTouchFileData(); break;
        case 6: { QHash<QUrl,QUrl> _r = _t->renameFileData();
            if (_a[0]) *reinterpret_cast<QHash<QUrl,QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->removeRenameFileData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->clearRenameFileData(); break;
        case 9: { QSet<QUrl> _r = _t->pasteFileData();
            if (_a[0]) *reinterpret_cast<QSet<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->removePasteFileData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->clearPasteFileData(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileOperatorProxy::*)()>(_a, &FileOperatorProxy::filePastedCallback, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileOperatorProxy::*)()>(_a, &FileOperatorProxy::fileTouchedCallback, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileOperatorProxy::*)()>(_a, &FileOperatorProxy::fileRenamedCallback, 2))
            return;
    }
}

const QMetaObject *ddplugin_canvas::FileOperatorProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::FileOperatorProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17FileOperatorProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_canvas::FileOperatorProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_canvas::FileOperatorProxy::filePastedCallback()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ddplugin_canvas::FileOperatorProxy::fileTouchedCallback()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ddplugin_canvas::FileOperatorProxy::fileRenamedCallback()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
