/****************************************************************************
** Meta object code from reading C++ file 'canvasviewbroker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/broker/canvasviewbroker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasviewbroker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::CanvasViewBroker::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::CanvasViewBroker",
        "visualRect",
        "QRect",
        "",
        "idx",
        "QUrl",
        "url",
        "gridVisualRect",
        "QPoint",
        "gridPos",
        "viewPoint",
        "gridSize",
        "QSize",
        "refresh",
        "update",
        "select",
        "QList<QUrl>",
        "urls",
        "selectedUrls",
        "fileOperator"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'visualRect'
        QtMocHelpers::SlotData<QRect(int, const QUrl &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'gridVisualRect'
        QtMocHelpers::SlotData<QRect(int, const QPoint &)>(7, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'gridPos'
        QtMocHelpers::SlotData<QPoint(int, const QPoint &)>(9, 3, QMC::AccessPublic, 0x80000000 | 8, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 8, 10 },
        }}),
        // Slot 'gridSize'
        QtMocHelpers::SlotData<QSize(int)>(11, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(int)>(13, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'update'
        QtMocHelpers::SlotData<void(int)>(14, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'select'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(15, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'selectedUrls'
        QtMocHelpers::SlotData<QList<QUrl>(int)>(18, 3, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'fileOperator'
        QtMocHelpers::SlotData<QObject *()>(19, 3, QMC::AccessPublic, QMetaType::QObjectStar),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasViewBroker, qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::CanvasViewBroker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::CanvasViewBroker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasViewBroker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QRect _r = _t->visualRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 1: { QRect _r = _t->gridVisualRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 2: { QPoint _r = _t->gridPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 3: { QSize _r = _t->gridSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->refresh((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->update((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->select((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 7: { QList<QUrl> _r = _t->selectedUrls((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QObject* _r = _t->fileOperator();
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ddplugin_canvas::CanvasViewBroker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::CanvasViewBroker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasViewBrokerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_canvas::CanvasViewBroker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
