/****************************************************************************
** Meta object code from reading C++ file 'fileoperator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/utils/fileoperator.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileoperator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::FileOperator::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::FileOperator",
        "requestSelectFile",
        "",
        "QList<QUrl>&",
        "urls",
        "flag",
        "requestClearSelection",
        "requestDropFile",
        "collection",
        "onCanvasPastedFiles",
        "renameFile",
        "wid",
        "QUrl",
        "oldUrl",
        "newUrl",
        "touchFileData",
        "clearTouchFileData",
        "pasteFileData",
        "QSet<QUrl>",
        "removePasteFileData",
        "clearPasteFileData",
        "dropFileData",
        "QHash<QUrl,QString>",
        "removeDropFileData",
        "clearDropFileData"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestSelectFile'
        QtMocHelpers::SignalData<void(QList<QUrl> &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'requestClearSelection'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestDropFile'
        QtMocHelpers::SignalData<void(const QString &, QList<QUrl> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onCanvasPastedFiles'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Method 'renameFile'
        QtMocHelpers::MethodData<void(int, const QUrl &, const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 },
        }}),
        // Method 'touchFileData'
        QtMocHelpers::MethodData<QUrl() const>(15, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Method 'clearTouchFileData'
        QtMocHelpers::MethodData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'pasteFileData'
        QtMocHelpers::MethodData<QSet<QUrl>() const>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Method 'removePasteFileData'
        QtMocHelpers::MethodData<void(const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'clearPasteFileData'
        QtMocHelpers::MethodData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'dropFileData'
        QtMocHelpers::MethodData<QHash<QUrl,QString>() const>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
        // Method 'removeDropFileData'
        QtMocHelpers::MethodData<void(const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Method 'clearDropFileData'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileOperator, qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::FileOperator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::FileOperator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileOperator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestSelectFile((*reinterpret_cast<std::add_pointer_t<QList<QUrl>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->requestClearSelection(); break;
        case 2: _t->requestDropFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>&>>(_a[2]))); break;
        case 3: _t->onCanvasPastedFiles(); break;
        case 4: _t->renameFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 5: { QUrl _r = _t->touchFileData();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->clearTouchFileData(); break;
        case 7: { QSet<QUrl> _r = _t->pasteFileData();
            if (_a[0]) *reinterpret_cast<QSet<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->removePasteFileData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->clearPasteFileData(); break;
        case 10: { QHash<QUrl,QString> _r = _t->dropFileData();
            if (_a[0]) *reinterpret_cast<QHash<QUrl,QString>*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->removeDropFileData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: _t->clearDropFileData(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileOperator::*)(QList<QUrl> & , int )>(_a, &FileOperator::requestSelectFile, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileOperator::*)()>(_a, &FileOperator::requestClearSelection, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileOperator::*)(const QString & , QList<QUrl> & )>(_a, &FileOperator::requestDropFile, 2))
            return;
    }
}

const QMetaObject *ddplugin_organizer::FileOperator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::FileOperator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer12FileOperatorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_organizer::FileOperator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_organizer::FileOperator::requestSelectFile(QList<QUrl> & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ddplugin_organizer::FileOperator::requestClearSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ddplugin_organizer::FileOperator::requestDropFile(const QString & _t1, QList<QUrl> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}
QT_WARNING_POP
