/****************************************************************************
** Meta object code from reading C++ file 'recentmanagerdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/daemon/recent/recentmanagerdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recentmanagerdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17RecentManagerDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto RecentManagerDBus::qt_create_metaobjectdata<qt_meta_tag_ZN17RecentManagerDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RecentManagerDBus",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.RecentManager",
        "ReloadFinished",
        "",
        "timestamp",
        "PurgeFinished",
        "ItemAdded",
        "path",
        "href",
        "modified",
        "ItemsRemoved",
        "paths",
        "ItemChanged",
        "Reload",
        "AddItem",
        "QVariantMap",
        "item",
        "RemoveItems",
        "hrefs",
        "PurgeItems",
        "GetItemsPath",
        "GetItemsInfo",
        "QVariantList",
        "GetItemInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ReloadFinished'
        QtMocHelpers::SignalData<void(qint64)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 5 },
        }}),
        // Signal 'PurgeFinished'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ItemAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qint64)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::LongLong, 10 },
        }}),
        // Signal 'ItemsRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 12 },
        }}),
        // Signal 'ItemChanged'
        QtMocHelpers::SignalData<void(const QString &, qint64)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::LongLong, 10 },
        }}),
        // Slot 'Reload'
        QtMocHelpers::SlotData<qint64()>(14, 4, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'AddItem'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'RemoveItems'
        QtMocHelpers::SlotData<void(const QStringList &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 19 },
        }}),
        // Slot 'PurgeItems'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'GetItemsPath'
        QtMocHelpers::SlotData<QStringList()>(21, 4, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'GetItemsInfo'
        QtMocHelpers::SlotData<QVariantList()>(22, 4, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'GetItemInfo'
        QtMocHelpers::SlotData<QVariantMap(const QString &)>(24, 4, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<RecentManagerDBus, qt_meta_tag_ZN17RecentManagerDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject RecentManagerDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RecentManagerDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RecentManagerDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17RecentManagerDBusE_t>.metaTypes,
    nullptr
} };

void RecentManagerDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecentManagerDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ReloadFinished((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 1: _t->PurgeFinished(); break;
        case 2: _t->ItemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 3: _t->ItemsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->ItemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 5: { qint64 _r = _t->Reload();
            if (_a[0]) *reinterpret_cast<qint64*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->AddItem((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: _t->RemoveItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->PurgeItems(); break;
        case 9: { QStringList _r = _t->GetItemsPath();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantList _r = _t->GetItemsInfo();
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariantMap _r = _t->GetItemInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecentManagerDBus::*)(qint64 )>(_a, &RecentManagerDBus::ReloadFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManagerDBus::*)()>(_a, &RecentManagerDBus::PurgeFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManagerDBus::*)(const QString & , const QString & , qint64 )>(_a, &RecentManagerDBus::ItemAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManagerDBus::*)(const QStringList & )>(_a, &RecentManagerDBus::ItemsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManagerDBus::*)(const QString & , qint64 )>(_a, &RecentManagerDBus::ItemChanged, 4))
            return;
    }
}

const QMetaObject *RecentManagerDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RecentManagerDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17RecentManagerDBusE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RecentManagerDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void RecentManagerDBus::ReloadFinished(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void RecentManagerDBus::PurgeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void RecentManagerDBus::ItemAdded(const QString & _t1, const QString & _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void RecentManagerDBus::ItemsRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void RecentManagerDBus::ItemChanged(const QString & _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
