/****************************************************************************
** Meta object code from reading C++ file 'titlebarwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-titlebar/views/titlebarwidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'titlebarwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_titlebar::TitleBarWidget::qt_create_metaobjectdata<qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_titlebar::TitleBarWidget",
        "currentUrlChanged",
        "",
        "QUrl",
        "url",
        "handleHotkeyCtrlF",
        "handleHotkeyCtrlL",
        "handleHotketSwitchViewMode",
        "mode",
        "handleHotketNextTab",
        "handleHotketPreviousTab",
        "handleHotketCloseCurrentTab",
        "handleHotketCreateNewTab",
        "handleHotketActivateTab",
        "index",
        "onAddressBarJump",
        "onTabCreated",
        "uniqueId",
        "onTabRemoved",
        "oldIndex",
        "nextIndex",
        "onTabMoved",
        "from",
        "to",
        "onTabCurrentChanged",
        "newIndex",
        "onTabCloseRequested",
        "remainState",
        "onTabAddButtonClicked",
        "quitSearch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentUrlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleHotkeyCtrlF'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotkeyCtrlL'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotketSwitchViewMode'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'handleHotketNextTab'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotketPreviousTab'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotketCloseCurrentTab'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotketCreateNewTab'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleHotketActivateTab'
        QtMocHelpers::SlotData<void(const int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'onAddressBarJump'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTabCreated'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'onTabRemoved'
        QtMocHelpers::SlotData<void(int, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'onTabMoved'
        QtMocHelpers::SlotData<void(int, int)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'onTabCurrentChanged'
        QtMocHelpers::SlotData<void(int, int)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'onTabCloseRequested'
        QtMocHelpers::SlotData<void(int, bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'onTabAddButtonClicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'quitSearch'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TitleBarWidget, qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_titlebar::TitleBarWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<dfmbase::AbstractFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>.metaTypes,
    nullptr
} };

void dfmplugin_titlebar::TitleBarWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TitleBarWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->handleHotkeyCtrlF(); break;
        case 2: _t->handleHotkeyCtrlL(); break;
        case 3: _t->handleHotketSwitchViewMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->handleHotketNextTab(); break;
        case 5: _t->handleHotketPreviousTab(); break;
        case 6: _t->handleHotketCloseCurrentTab(); break;
        case 7: _t->handleHotketCreateNewTab(); break;
        case 8: _t->handleHotketActivateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->onAddressBarJump(); break;
        case 10: _t->onTabCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->onTabRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->onTabMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 13: _t->onTabCurrentChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->onTabCloseRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->onTabAddButtonClicked(); break;
        case 16: _t->quitSearch(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TitleBarWidget::*)(const QUrl & )>(_a, &TitleBarWidget::currentUrlChanged, 0))
            return;
    }
}

const QMetaObject *dfmplugin_titlebar::TitleBarWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_titlebar::TitleBarWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar14TitleBarWidgetE_t>.strings))
        return static_cast<void*>(this);
    return dfmbase::AbstractFrame::qt_metacast(_clname);
}

int dfmplugin_titlebar::TitleBarWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = dfmbase::AbstractFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_titlebar::TitleBarWidget::currentUrlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
