/****************************************************************************
** Meta object code from reading C++ file 'tageventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-tag/events/tageventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tageventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_tag::TagEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_tag::TagEventReceiver",
        "handleHideFilesResult",
        "",
        "winId",
        "QList<QUrl>",
        "urls",
        "ok",
        "handleFileCutResult",
        "srcUrls",
        "destUrls",
        "errMsg",
        "handleFileRemoveResult",
        "handleFileRenameResult",
        "QMap<QUrl,QUrl>",
        "renamedUrls",
        "handleWindowUrlChanged",
        "QUrl",
        "url",
        "handleRestoreFromTrashResult",
        "QVariantList",
        "customInfos",
        "handleGetTags",
        "handleSidebarOrderChanged",
        "group"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleHideFilesResult'
        QtMocHelpers::SlotData<void(const quint64 &, const QList<QUrl> &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'handleFileCutResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QList<QUrl> &, bool, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 8 }, { 0x80000000 | 4, 9 }, { QMetaType::Bool, 6 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'handleFileRemoveResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, bool, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 8 }, { QMetaType::Bool, 6 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'handleFileRenameResult'
        QtMocHelpers::SlotData<void(quint64, const QMap<QUrl,QUrl> &, bool, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 13, 14 }, { QMetaType::Bool, 6 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'handleWindowUrlChanged'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleRestoreFromTrashResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QList<QUrl> &, const QVariantList &, bool, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 8 }, { 0x80000000 | 4, 9 }, { 0x80000000 | 19, 20 }, { QMetaType::Bool, 6 },
            { QMetaType::QString, 10 },
        }}),
        // Slot 'handleGetTags'
        QtMocHelpers::SlotData<QStringList(const QUrl &)>(21, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleSidebarOrderChanged'
        QtMocHelpers::SlotData<void(quint64, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TagEventReceiver, qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_tag::TagEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_tag::TagEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TagEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleHideFilesResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->handleFileCutResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->handleFileRemoveResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 3: _t->handleFileRenameResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QUrl,QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 4: _t->handleWindowUrlChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 5: _t->handleRestoreFromTrashResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 6: { QStringList _r = _t->handleGetTags((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->handleSidebarOrderChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_tag::TagEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_tag::TagEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13dfmplugin_tag16TagEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_tag::TagEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
