/****************************************************************************
** Meta object code from reading C++ file 'filedialoghandle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filedialog/core/dbus/filedialoghandle.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialoghandle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16FileDialogHandleE_t {};
} // unnamed namespace

template <> constexpr inline auto FileDialogHandle::qt_create_metaobjectdata<qt_meta_tag_ZN16FileDialogHandleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileDialogHandle",
        "finished",
        "",
        "result",
        "accepted",
        "rejected",
        "selectionFilesChanged",
        "currentUrlChanged",
        "selectedNameFilterChanged",
        "setParent",
        "QWidget*",
        "parent",
        "widget",
        "setDirectory",
        "directory",
        "QDir",
        "setDirectoryUrl",
        "QUrl",
        "directoryUrl",
        "selectFile",
        "filename",
        "selectedFiles",
        "selectUrl",
        "url",
        "selectedUrls",
        "QList<QUrl>",
        "addDisableUrlScheme",
        "scheme",
        "setNameFilters",
        "filters",
        "nameFilters",
        "selectNameFilter",
        "filter",
        "selectedNameFilter",
        "selectNameFilterByIndex",
        "index",
        "selectedNameFilterIndex",
        "winId",
        "QDir::Filters",
        "setFilter",
        "setViewMode",
        "QFileDialog::ViewMode",
        "mode",
        "viewMode",
        "setFileMode",
        "QFileDialog::FileMode",
        "setAcceptMode",
        "QFileDialog::AcceptMode",
        "acceptMode",
        "setLabelText",
        "QFileDialog::DialogLabel",
        "label",
        "text",
        "labelText",
        "setOptions",
        "QFileDialog::Options",
        "options",
        "setOption",
        "QFileDialog::Option",
        "option",
        "on",
        "testOption",
        "setCurrentInputName",
        "name",
        "addCustomWidget",
        "type",
        "data",
        "getCustomWidgetValue",
        "QDBusVariant",
        "allCustomWidgetsValue",
        "QVariantMap",
        "beginAddCustomWidget",
        "endAddCustomWidget",
        "setAllowMixedSelection",
        "setHideOnAccept",
        "enable",
        "hideOnAccept",
        "show",
        "hide",
        "accept",
        "done",
        "r",
        "exec",
        "open",
        "reject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'accepted'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rejected'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionFilesChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentUrlChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedNameFilterChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setParent'
        QtMocHelpers::SlotData<void(QWidget *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'widget'
        QtMocHelpers::SlotData<QWidget *() const>(12, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'setDirectory'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setDirectory'
        QtMocHelpers::SlotData<void(const QDir &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 14 },
        }}),
        // Slot 'directory'
        QtMocHelpers::SlotData<QDir() const>(14, 2, QMC::AccessPublic, 0x80000000 | 15),
        // Slot 'setDirectoryUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 14 },
        }}),
        // Slot 'directoryUrl'
        QtMocHelpers::SlotData<QUrl() const>(18, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'selectFile'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'selectedFiles'
        QtMocHelpers::SlotData<QStringList() const>(21, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'selectUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 23 },
        }}),
        // Slot 'selectedUrls'
        QtMocHelpers::SlotData<QList<QUrl>() const>(24, 2, QMC::AccessPublic, 0x80000000 | 25),
        // Slot 'addDisableUrlScheme'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 },
        }}),
        // Slot 'setNameFilters'
        QtMocHelpers::SlotData<void(const QStringList &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 29 },
        }}),
        // Slot 'nameFilters'
        QtMocHelpers::SlotData<QStringList() const>(30, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'selectNameFilter'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'selectedNameFilter'
        QtMocHelpers::SlotData<QString() const>(33, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectNameFilterByIndex'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'selectedNameFilterIndex'
        QtMocHelpers::SlotData<int() const>(36, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'winId'
        QtMocHelpers::SlotData<qulonglong() const>(37, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'filter'
        QtMocHelpers::SlotData<QDir::Filters() const>(32, 2, QMC::AccessPublic, 0x80000000 | 38),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<void(QDir::Filters)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 29 },
        }}),
        // Slot 'setViewMode'
        QtMocHelpers::SlotData<void(QFileDialog::ViewMode)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'viewMode'
        QtMocHelpers::SlotData<QFileDialog::ViewMode() const>(43, 2, QMC::AccessPublic, 0x80000000 | 41),
        // Slot 'setFileMode'
        QtMocHelpers::SlotData<void(QFileDialog::FileMode)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 42 },
        }}),
        // Slot 'setAcceptMode'
        QtMocHelpers::SlotData<void(QFileDialog::AcceptMode)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 42 },
        }}),
        // Slot 'acceptMode'
        QtMocHelpers::SlotData<QFileDialog::AcceptMode() const>(48, 2, QMC::AccessPublic, 0x80000000 | 47),
        // Slot 'setLabelText'
        QtMocHelpers::SlotData<void(QFileDialog::DialogLabel, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 50, 51 }, { QMetaType::QString, 52 },
        }}),
        // Slot 'labelText'
        QtMocHelpers::SlotData<QString(QFileDialog::DialogLabel) const>(53, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 50, 51 },
        }}),
        // Slot 'setOptions'
        QtMocHelpers::SlotData<void(QFileDialog::Options)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(QFileDialog::Option, bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 }, { QMetaType::Bool, 60 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(QFileDialog::Option)>(57, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'options'
        QtMocHelpers::SlotData<QFileDialog::Options() const>(56, 2, QMC::AccessPublic, 0x80000000 | 55),
        // Slot 'testOption'
        QtMocHelpers::SlotData<bool(QFileDialog::Option) const>(61, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'setCurrentInputName'
        QtMocHelpers::SlotData<void(const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 63 },
        }}),
        // Slot 'addCustomWidget'
        QtMocHelpers::SlotData<void(int, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 65 }, { QMetaType::QString, 66 },
        }}),
        // Slot 'getCustomWidgetValue'
        QtMocHelpers::SlotData<QDBusVariant(int, const QString &) const>(67, 2, QMC::AccessPublic, 0x80000000 | 68, {{
            { QMetaType::Int, 65 }, { QMetaType::QString, 52 },
        }}),
        // Slot 'allCustomWidgetsValue'
        QtMocHelpers::SlotData<QVariantMap(int) const>(69, 2, QMC::AccessPublic, 0x80000000 | 70, {{
            { QMetaType::Int, 65 },
        }}),
        // Slot 'beginAddCustomWidget'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'endAddCustomWidget'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAllowMixedSelection'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'setHideOnAccept'
        QtMocHelpers::SlotData<void(bool)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 75 },
        }}),
        // Slot 'hideOnAccept'
        QtMocHelpers::SlotData<bool() const>(76, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'show'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'hide'
        QtMocHelpers::SlotData<void()>(78, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'done'
        QtMocHelpers::SlotData<void(int)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 81 },
        }}),
        // Slot 'exec'
        QtMocHelpers::SlotData<int()>(82, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'open'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reject'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileDialogHandle, qt_meta_tag_ZN16FileDialogHandleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FileDialogHandle::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileDialogHandleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileDialogHandleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16FileDialogHandleE_t>.metaTypes,
    nullptr
} };

void FileDialogHandle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileDialogHandle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->accepted(); break;
        case 2: _t->rejected(); break;
        case 3: _t->selectionFilesChanged(); break;
        case 4: _t->currentUrlChanged(); break;
        case 5: _t->selectedNameFilterChanged(); break;
        case 6: _t->setParent((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 7: { QWidget* _r = _t->widget();
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setDirectory((*reinterpret_cast<std::add_pointer_t<QDir>>(_a[1]))); break;
        case 10: { QDir _r = _t->directory();
            if (_a[0]) *reinterpret_cast<QDir*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setDirectoryUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 12: { QUrl _r = _t->directoryUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->selectFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: { QStringList _r = _t->selectedFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->selectUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: { QList<QUrl> _r = _t->selectedUrls();
            if (_a[0]) *reinterpret_cast<QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->addDisableUrlScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->setNameFilters((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 19: { QStringList _r = _t->nameFilters();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->selectNameFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: { QString _r = _t->selectedNameFilter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->selectNameFilterByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: { int _r = _t->selectedNameFilterIndex();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { qulonglong _r = _t->winId();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDir::Filters _r = _t->filter();
            if (_a[0]) *reinterpret_cast<QDir::Filters*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setFilter((*reinterpret_cast<std::add_pointer_t<QDir::Filters>>(_a[1]))); break;
        case 27: _t->setViewMode((*reinterpret_cast<std::add_pointer_t<QFileDialog::ViewMode>>(_a[1]))); break;
        case 28: { QFileDialog::ViewMode _r = _t->viewMode();
            if (_a[0]) *reinterpret_cast<QFileDialog::ViewMode*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setFileMode((*reinterpret_cast<std::add_pointer_t<QFileDialog::FileMode>>(_a[1]))); break;
        case 30: _t->setAcceptMode((*reinterpret_cast<std::add_pointer_t<QFileDialog::AcceptMode>>(_a[1]))); break;
        case 31: { QFileDialog::AcceptMode _r = _t->acceptMode();
            if (_a[0]) *reinterpret_cast<QFileDialog::AcceptMode*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->setLabelText((*reinterpret_cast<std::add_pointer_t<QFileDialog::DialogLabel>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 33: { QString _r = _t->labelText((*reinterpret_cast<std::add_pointer_t<QFileDialog::DialogLabel>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->setOptions((*reinterpret_cast<std::add_pointer_t<QFileDialog::Options>>(_a[1]))); break;
        case 35: _t->setOption((*reinterpret_cast<std::add_pointer_t<QFileDialog::Option>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->setOption((*reinterpret_cast<std::add_pointer_t<QFileDialog::Option>>(_a[1]))); break;
        case 37: { QFileDialog::Options _r = _t->options();
            if (_a[0]) *reinterpret_cast<QFileDialog::Options*>(_a[0]) = std::move(_r); }  break;
        case 38: { bool _r = _t->testOption((*reinterpret_cast<std::add_pointer_t<QFileDialog::Option>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->setCurrentInputName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: _t->addCustomWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 41: { QDBusVariant _r = _t->getCustomWidgetValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 42: { QVariantMap _r = _t->allCustomWidgetsValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->beginAddCustomWidget(); break;
        case 44: _t->endAddCustomWidget(); break;
        case 45: _t->setAllowMixedSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->setHideOnAccept((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: { bool _r = _t->hideOnAccept();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->show(); break;
        case 49: _t->hide(); break;
        case 50: _t->accept(); break;
        case 51: _t->done((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->open(); break;
        case 54: _t->reject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)(int )>(_a, &FileDialogHandle::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)()>(_a, &FileDialogHandle::accepted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)()>(_a, &FileDialogHandle::rejected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)()>(_a, &FileDialogHandle::selectionFilesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)()>(_a, &FileDialogHandle::currentUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandle::*)()>(_a, &FileDialogHandle::selectedNameFilterChanged, 5))
            return;
    }
}

const QMetaObject *FileDialogHandle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileDialogHandle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileDialogHandleE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int FileDialogHandle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void FileDialogHandle::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FileDialogHandle::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FileDialogHandle::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FileDialogHandle::selectionFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FileDialogHandle::currentUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FileDialogHandle::selectedNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
