/****************************************************************************
** Meta object code from reading C++ file 'computermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-computer/models/computermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'computermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_computer::ComputerModel::qt_create_metaobjectdata<qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_computer::ComputerModel",
        "requestClearSelection",
        "",
        "QUrl",
        "url",
        "requestHandleItemVisible",
        "requestUpdateIndex",
        "QModelIndex",
        "index",
        "onItemAdded",
        "ComputerItemData",
        "data",
        "onItemRemoved",
        "onItemUpdated",
        "updateItemInfo",
        "pos",
        "onItemSizeChanged",
        "total",
        "free",
        "onItemPropertyChanged",
        "key",
        "QVariant",
        "val",
        "addGroup",
        "removeOrphanGroup",
        "DataRoles",
        "kSizeTotalRole",
        "kSizeUsageRole",
        "kFileSystemRole",
        "kRealUrlRole",
        "kDeviceUrlRole",
        "kDeviceIsEncryptedRole",
        "kDeviceIsUnlockedRole",
        "kDeviceClearDevIdRole",
        "kSuffixRole",
        "kProgressVisiableRole",
        "kTotalSizeVisiableRole",
        "kUsedSizeVisiableRole",
        "kDeviceNameMaxLengthRole",
        "kItemShapeTypeRole",
        "kActionListRole",
        "kItemIsEditingRole",
        "kDeviceDescriptionRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestClearSelection'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestHandleItemVisible'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateIndex'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onItemAdded'
        QtMocHelpers::SlotData<void(const ComputerItemData &)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'onItemRemoved'
        QtMocHelpers::SlotData<void(const QUrl &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onItemUpdated'
        QtMocHelpers::SlotData<void(const QUrl &)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateItemInfo'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'onItemSizeChanged'
        QtMocHelpers::SlotData<void(const QUrl &, qlonglong, qlonglong)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::LongLong, 17 }, { QMetaType::LongLong, 18 },
        }}),
        // Slot 'onItemPropertyChanged'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &, const QVariant &)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'addGroup'
        QtMocHelpers::SlotData<void(const ComputerItemData &)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'removeOrphanGroup'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DataRoles'
        QtMocHelpers::EnumData<enum DataRoles>(25, 25, QMC::EnumFlags{}).add({
            {   26, DataRoles::kSizeTotalRole },
            {   27, DataRoles::kSizeUsageRole },
            {   28, DataRoles::kFileSystemRole },
            {   29, DataRoles::kRealUrlRole },
            {   30, DataRoles::kDeviceUrlRole },
            {   31, DataRoles::kDeviceIsEncryptedRole },
            {   32, DataRoles::kDeviceIsUnlockedRole },
            {   33, DataRoles::kDeviceClearDevIdRole },
            {   34, DataRoles::kSuffixRole },
            {   35, DataRoles::kProgressVisiableRole },
            {   36, DataRoles::kTotalSizeVisiableRole },
            {   37, DataRoles::kUsedSizeVisiableRole },
            {   38, DataRoles::kDeviceNameMaxLengthRole },
            {   39, DataRoles::kItemShapeTypeRole },
            {   40, DataRoles::kActionListRole },
            {   41, DataRoles::kItemIsEditingRole },
            {   42, DataRoles::kDeviceDescriptionRole },
        }),
    };
    return QtMocHelpers::metaObjectData<ComputerModel, qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_computer::ComputerModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>.metaTypes,
    nullptr
} };

void dfmplugin_computer::ComputerModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComputerModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestClearSelection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->requestHandleItemVisible(); break;
        case 2: _t->requestUpdateIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 3: _t->onItemAdded((*reinterpret_cast<std::add_pointer_t<ComputerItemData>>(_a[1]))); break;
        case 4: _t->onItemRemoved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->onItemUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->updateItemInfo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->onItemSizeChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 8: _t->onItemPropertyChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 9: _t->addGroup((*reinterpret_cast<std::add_pointer_t<ComputerItemData>>(_a[1]))); break;
        case 10: _t->removeOrphanGroup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ComputerModel::*)(const QUrl & )>(_a, &ComputerModel::requestClearSelection, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerModel::*)()>(_a, &ComputerModel::requestHandleItemVisible, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerModel::*)(const QModelIndex & )>(_a, &ComputerModel::requestUpdateIndex, 2))
            return;
    }
}

const QMetaObject *dfmplugin_computer::ComputerModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_computer::ComputerModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer13ComputerModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int dfmplugin_computer::ComputerModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_computer::ComputerModel::requestClearSelection(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_computer::ComputerModel::requestHandleItemVisible()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmplugin_computer::ComputerModel::requestUpdateIndex(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
