/****************************************************************************
** Meta object code from reading C++ file 'diskencryptdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../dde-file-manager/src/services/diskencrypt/diskencryptdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'diskencryptdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DiskEncryptDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto DiskEncryptDBus::qt_create_metaobjectdata<qt_meta_tag_ZN15DiskEncryptDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DiskEncryptDBus",
        "D-Bus Interface",
        "org.deepin.Filemanager.DiskEncrypt",
        "PrepareEncryptDiskResult",
        "",
        "device",
        "devName",
        "jobID",
        "errCode",
        "EncryptDiskResult",
        "msg",
        "DecryptDiskResult",
        "ChangePassphressResult",
        "EncryptProgress",
        "progress",
        "DecryptProgress",
        "RequestEncryptParams",
        "QVariantMap",
        "encConfig",
        "PrepareEncryptDisk",
        "params",
        "DecryptDisk",
        "ChangeEncryptPassphress",
        "IgnoreParamRequest",
        "ResumeEncryption",
        "SetEncryptParams",
        "QueryTPMToken",
        "EncryptStatus",
        "HasPendingTask",
        "IsWorkerRunning",
        "UnfinishedDecryptJob",
        "onFstabDiskEncProgressUpdated",
        "dev",
        "offset",
        "total",
        "onFstabDiskEncFinished",
        "result",
        "errstr"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PrepareEncryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'EncryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, int, const QString &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::Int, 8 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'DecryptDiskResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'ChangePassphressResult'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, int)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'EncryptProgress'
        QtMocHelpers::SignalData<void(const QString &, const QString &, double)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::Double, 14 },
        }}),
        // Signal 'DecryptProgress'
        QtMocHelpers::SignalData<void(const QString &, const QString &, double)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::Double, 14 },
        }}),
        // Signal 'RequestEncryptParams'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'PrepareEncryptDisk'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(19, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 20 },
        }}),
        // Slot 'DecryptDisk'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(21, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 20 },
        }}),
        // Slot 'ChangeEncryptPassphress'
        QtMocHelpers::SlotData<QString(const QVariantMap &)>(22, 4, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 17, 20 },
        }}),
        // Slot 'IgnoreParamRequest'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ResumeEncryption'
        QtMocHelpers::SlotData<void(const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'SetEncryptParams'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 20 },
        }}),
        // Slot 'QueryTPMToken'
        QtMocHelpers::SlotData<QString(const QString &)>(26, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'EncryptStatus'
        QtMocHelpers::SlotData<int(const QString &)>(27, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'HasPendingTask'
        QtMocHelpers::SlotData<bool()>(28, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'IsWorkerRunning'
        QtMocHelpers::SlotData<bool()>(29, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'UnfinishedDecryptJob'
        QtMocHelpers::SlotData<QString()>(30, 4, QMC::AccessPublic, QMetaType::QString),
        // Slot 'onFstabDiskEncProgressUpdated'
        QtMocHelpers::SlotData<void(const QString &, qint64, qint64)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::LongLong, 33 }, { QMetaType::LongLong, 34 },
        }}),
        // Slot 'onFstabDiskEncFinished'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(35, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::Int, 36 }, { QMetaType::QString, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DiskEncryptDBus, qt_meta_tag_ZN15DiskEncryptDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DiskEncryptDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusService::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DiskEncryptDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DiskEncryptDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DiskEncryptDBusE_t>.metaTypes,
    nullptr
} };

void DiskEncryptDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DiskEncryptDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PrepareEncryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 1: _t->EncryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 2: _t->DecryptDiskResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 3: _t->ChangePassphressResult((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 4: _t->EncryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 5: _t->DecryptProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 6: _t->RequestEncryptParams((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 7: { QString _r = _t->PrepareEncryptDisk((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->DecryptDisk((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->ChangeEncryptPassphress((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->IgnoreParamRequest(); break;
        case 11: _t->ResumeEncryption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->SetEncryptParams((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 13: { QString _r = _t->QueryTPMToken((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->EncryptStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->HasPendingTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->IsWorkerRunning();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { QString _r = _t->UnfinishedDecryptJob();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->onFstabDiskEncProgressUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 19: _t->onFstabDiskEncFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptDBus::PrepareEncryptDiskResult, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , int , const QString & )>(_a, &DiskEncryptDBus::EncryptDiskResult, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptDBus::DecryptDiskResult, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , const QString & , int )>(_a, &DiskEncryptDBus::ChangePassphressResult, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , double )>(_a, &DiskEncryptDBus::EncryptProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QString & , const QString & , double )>(_a, &DiskEncryptDBus::DecryptProgress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DiskEncryptDBus::*)(const QVariantMap & )>(_a, &DiskEncryptDBus::RequestEncryptParams, 6))
            return;
    }
}

const QMetaObject *DiskEncryptDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DiskEncryptDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DiskEncryptDBusE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QDBusService::qt_metacast(_clname);
}

int DiskEncryptDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusService::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void DiskEncryptDBus::PrepareEncryptDiskResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void DiskEncryptDBus::EncryptDiskResult(const QString & _t1, const QString & _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void DiskEncryptDBus::DecryptDiskResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void DiskEncryptDBus::ChangePassphressResult(const QString & _t1, const QString & _t2, const QString & _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void DiskEncryptDBus::EncryptProgress(const QString & _t1, const QString & _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void DiskEncryptDBus::DecryptProgress(const QString & _t1, const QString & _t2, double _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void DiskEncryptDBus::RequestEncryptParams(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
