/****************************************************************************
** Meta object code from reading C++ file 'textindexdbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../dde-file-manager/src/services/textindex/textindexdbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textindexdbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TextIndexDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto TextIndexDBus::qt_create_metaobjectdata<qt_meta_tag_ZN13TextIndexDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextIndexDBus",
        "D-Bus Interface",
        "org.deepin.Filemanager.TextIndex",
        "TaskFinished",
        "",
        "type",
        "path",
        "success",
        "TaskProgressChanged",
        "count",
        "CreateIndexTask",
        "UpdateIndexTask",
        "RemoveIndexTask",
        "paths",
        "StopCurrentTask",
        "HasRunningTask",
        "IndexDatabaseExists",
        "GetLastUpdateTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TaskFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'TaskProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qint64)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 }, { QMetaType::LongLong, 9 },
        }}),
        // Slot 'CreateIndexTask'
        QtMocHelpers::SlotData<bool(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'UpdateIndexTask'
        QtMocHelpers::SlotData<bool(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'RemoveIndexTask'
        QtMocHelpers::SlotData<bool(const QStringList &)>(12, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 13 },
        }}),
        // Slot 'StopCurrentTask'
        QtMocHelpers::SlotData<bool()>(14, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'HasRunningTask'
        QtMocHelpers::SlotData<bool()>(15, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'IndexDatabaseExists'
        QtMocHelpers::SlotData<bool()>(16, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetLastUpdateTime'
        QtMocHelpers::SlotData<QString()>(17, 4, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TextIndexDBus, qt_meta_tag_ZN13TextIndexDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TextIndexDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TextIndexDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TextIndexDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TextIndexDBusE_t>.metaTypes,
    nullptr
} };

void TextIndexDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextIndexDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TaskFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->TaskProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 2: { bool _r = _t->CreateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->UpdateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->RemoveIndexTask((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->StopCurrentTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->HasRunningTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->IndexDatabaseExists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->GetLastUpdateTime();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextIndexDBus::*)(const QString & , const QString & , bool )>(_a, &TextIndexDBus::TaskFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextIndexDBus::*)(const QString & , const QString & , qint64 )>(_a, &TextIndexDBus::TaskProgressChanged, 1))
            return;
    }
}

const QMetaObject *TextIndexDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextIndexDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TextIndexDBusE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int TextIndexDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void TextIndexDBus::TaskFinished(const QString & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TextIndexDBus::TaskProgressChanged(const QString & _t1, const QString & _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
