/****************************************************************************
** Meta object code from reading C++ file 'fileinfoasycworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/utils/fileinfoasycworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileinfoasycworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::FileInfoAsycWorker::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::FileInfoAsycWorker",
        "fileConutAsyncFinish",
        "",
        "QUrl",
        "url",
        "files",
        "fileMimeTypeFinished",
        "QMimeType",
        "type",
        "fileConutAsync",
        "QSharedPointer<FileInfoHelperUeserData>",
        "data",
        "fileMimeType",
        "QMimeDatabase::MatchMode",
        "mode",
        "inod",
        "isGvfs",
        "fileRefresh",
        "QSharedPointer<dfmio::DFileInfo>",
        "dfileInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileConutAsyncFinish'
        QtMocHelpers::SignalData<void(const QUrl &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'fileMimeTypeFinished'
        QtMocHelpers::SignalData<void(const QUrl &, const QMimeType &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'fileConutAsync'
        QtMocHelpers::SlotData<void(const QUrl &, const QSharedPointer<FileInfoHelperUeserData>)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'fileMimeType'
        QtMocHelpers::SlotData<void(const QUrl &, const QMimeDatabase::MatchMode, const QString &, const bool, const QSharedPointer<FileInfoHelperUeserData>)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 }, { QMetaType::Bool, 16 },
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'fileRefresh'
        QtMocHelpers::SlotData<void(const QUrl &, const QSharedPointer<dfmio::DFileInfo>)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileInfoAsycWorker, qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::FileInfoAsycWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>.metaTypes,
    nullptr
} };

void dfmbase::FileInfoAsycWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileInfoAsycWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileConutAsyncFinish((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->fileMimeTypeFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeType>>(_a[2]))); break;
        case 2: _t->fileConutAsync((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfoHelperUeserData>>>(_a[2]))); break;
        case 3: _t->fileMimeType((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeDatabase::MatchMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfoHelperUeserData>>>(_a[5]))); break;
        case 4: _t->fileRefresh((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<dfmio::DFileInfo>>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileInfoAsycWorker::*)(const QUrl & , int )>(_a, &FileInfoAsycWorker::fileConutAsyncFinish, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoAsycWorker::*)(const QUrl & , const QMimeType & )>(_a, &FileInfoAsycWorker::fileMimeTypeFinished, 1))
            return;
    }
}

const QMetaObject *dfmbase::FileInfoAsycWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::FileInfoAsycWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase18FileInfoAsycWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::FileInfoAsycWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::FileInfoAsycWorker::fileConutAsyncFinish(const QUrl & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmbase::FileInfoAsycWorker::fileMimeTypeFinished(const QUrl & _t1, const QMimeType & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
