/****************************************************************************
** Meta object code from reading C++ file 'appendcompresseventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/appendcompress/appendcompresseventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appendcompresseventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_utils::AppendCompressEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_utils::AppendCompressEventReceiver",
        "handleSetMouseStyle",
        "",
        "QList<QUrl>",
        "fromUrls",
        "QUrl",
        "toUrl",
        "Qt::DropAction*",
        "type",
        "handleDragDropCompress",
        "handleSetMouseStyleOnDesktop",
        "viewIndex",
        "const QMimeData*",
        "mime",
        "QPoint",
        "viewPos",
        "extData",
        "handleDragDropCompressOnDesktop",
        "md",
        "handleSetMouseStyleOnOrganizer",
        "viewId",
        "handleDragDropCompressOnOsrganizer",
        "handleIsDrop"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleSetMouseStyle'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &, Qt::DropAction *)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'handleDragDropCompress'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'handleSetMouseStyleOnDesktop'
        QtMocHelpers::SlotData<bool(int, const QMimeData *, const QPoint &, void *)>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 }, { QMetaType::VoidStar, 16 },
        }}),
        // Slot 'handleDragDropCompressOnDesktop'
        QtMocHelpers::SlotData<bool(int, const QMimeData *, const QPoint &, void *)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 }, { 0x80000000 | 12, 18 }, { 0x80000000 | 14, 15 }, { QMetaType::VoidStar, 16 },
        }}),
        // Slot 'handleSetMouseStyleOnOrganizer'
        QtMocHelpers::SlotData<bool(const QString &, const QMimeData *, const QPoint &, void *)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 }, { QMetaType::VoidStar, 16 },
        }}),
        // Slot 'handleDragDropCompressOnOsrganizer'
        QtMocHelpers::SlotData<bool(const QString &, const QMimeData *, const QPoint &, void *)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 20 }, { 0x80000000 | 12, 18 }, { 0x80000000 | 14, 15 }, { QMetaType::VoidStar, 16 },
        }}),
        // Slot 'handleIsDrop'
        QtMocHelpers::SlotData<bool(const QUrl &)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AppendCompressEventReceiver, qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_utils::AppendCompressEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_utils::AppendCompressEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppendCompressEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->handleSetMouseStyle((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::DropAction*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->handleDragDropCompress((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->handleSetMouseStyleOnDesktop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->handleDragDropCompressOnDesktop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->handleSetMouseStyleOnOrganizer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->handleDragDropCompressOnOsrganizer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const QMimeData*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<void*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->handleIsDrop((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_utils::AppendCompressEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::AppendCompressEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_utils27AppendCompressEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::AppendCompressEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
