/****************************************************************************
** Meta object code from reading C++ file 'burnjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-burn/utils/burnjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'burnjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::AbstractBurnJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::AbstractBurnJob",
        "requestErrorMessageDialog",
        "",
        "title",
        "message",
        "requestFailureDialog",
        "type",
        "err",
        "details",
        "requestCompletionDialog",
        "msg",
        "icon",
        "requestCloseTab",
        "QUrl",
        "url",
        "requestReloadDisc",
        "devId",
        "burnFinished",
        "reuslt",
        "onJobUpdated",
        "dfmburn::JobStatus",
        "status",
        "progress",
        "speed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestErrorMessageDialog'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'requestFailureDialog'
        QtMocHelpers::SignalData<void(int, const QString &, const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Signal 'requestCompletionDialog'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'requestCloseTab'
        QtMocHelpers::SignalData<void(const QUrl &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'requestReloadDisc'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'burnFinished'
        QtMocHelpers::SignalData<void(int, bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'onJobUpdated'
        QtMocHelpers::SlotData<void(dfmburn::JobStatus, int, const QString &, const QStringList &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Int, 22 }, { QMetaType::QString, 23 }, { QMetaType::QStringList, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractBurnJob, qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::AbstractBurnJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::AbstractBurnJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractBurnJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestErrorMessageDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->requestFailureDialog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 2: _t->requestCompletionDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->requestCloseTab((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->requestReloadDisc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->burnFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->onJobUpdated((*reinterpret_cast<std::add_pointer_t<dfmburn::JobStatus>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(const QString & , const QString & )>(_a, &AbstractBurnJob::requestErrorMessageDialog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(int , const QString & , const QStringList & )>(_a, &AbstractBurnJob::requestFailureDialog, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(const QString & , const QString & )>(_a, &AbstractBurnJob::requestCompletionDialog, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(const QUrl & )>(_a, &AbstractBurnJob::requestCloseTab, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(const QString & )>(_a, &AbstractBurnJob::requestReloadDisc, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractBurnJob::*)(int , bool )>(_a, &AbstractBurnJob::burnFinished, 5))
            return;
    }
}

const QMetaObject *dfmplugin_burn::AbstractBurnJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::AbstractBurnJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15AbstractBurnJobE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dfmplugin_burn::AbstractBurnJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_burn::AbstractBurnJob::requestErrorMessageDialog(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmplugin_burn::AbstractBurnJob::requestFailureDialog(int _t1, const QString & _t2, const QStringList & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void dfmplugin_burn::AbstractBurnJob::requestCompletionDialog(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmplugin_burn::AbstractBurnJob::requestCloseTab(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmplugin_burn::AbstractBurnJob::requestReloadDisc(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmplugin_burn::AbstractBurnJob::burnFinished(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::EraseJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::EraseJob",
        "eraseFinished",
        "",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'eraseFinished'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EraseJob, qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::EraseJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::EraseJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EraseJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->eraseFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EraseJob::*)(bool )>(_a, &EraseJob::eraseFinished, 0))
            return;
    }
}

const QMetaObject *dfmplugin_burn::EraseJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::EraseJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn8EraseJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBurnJob::qt_metacast(_clname);
}

int dfmplugin_burn::EraseJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBurnJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_burn::EraseJob::eraseFinished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::BurnISOFilesJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::BurnISOFilesJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BurnISOFilesJob, qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::BurnISOFilesJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::BurnISOFilesJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BurnISOFilesJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::BurnISOFilesJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::BurnISOFilesJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOFilesJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBurnJob::qt_metacast(_clname);
}

int dfmplugin_burn::BurnISOFilesJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBurnJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::BurnISOImageJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::BurnISOImageJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BurnISOImageJob, qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::BurnISOImageJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::BurnISOImageJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BurnISOImageJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::BurnISOImageJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::BurnISOImageJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnISOImageJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBurnJob::qt_metacast(_clname);
}

int dfmplugin_burn::BurnISOImageJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBurnJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::BurnUDFFilesJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::BurnUDFFilesJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BurnUDFFilesJob, qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::BurnUDFFilesJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::BurnUDFFilesJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BurnUDFFilesJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::BurnUDFFilesJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::BurnUDFFilesJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15BurnUDFFilesJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBurnJob::qt_metacast(_clname);
}

int dfmplugin_burn::BurnUDFFilesJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBurnJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::DumpISOImageJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::DumpISOImageJob",
        "requestOpticalDumpISOSuccessDialog",
        "",
        "QUrl",
        "imageUrl",
        "requestOpticalDumpISOFailedDialog"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestOpticalDumpISOSuccessDialog'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'requestOpticalDumpISOFailedDialog'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DumpISOImageJob, qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::DumpISOImageJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractBurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::DumpISOImageJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DumpISOImageJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestOpticalDumpISOSuccessDialog((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->requestOpticalDumpISOFailedDialog(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DumpISOImageJob::*)(const QUrl & )>(_a, &DumpISOImageJob::requestOpticalDumpISOSuccessDialog, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DumpISOImageJob::*)()>(_a, &DumpISOImageJob::requestOpticalDumpISOFailedDialog, 1))
            return;
    }
}

const QMetaObject *dfmplugin_burn::DumpISOImageJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::DumpISOImageJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn15DumpISOImageJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractBurnJob::qt_metacast(_clname);
}

int dfmplugin_burn::DumpISOImageJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractBurnJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_burn::DumpISOImageJob::requestOpticalDumpISOSuccessDialog(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_burn::DumpISOImageJob::requestOpticalDumpISOFailedDialog()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
