/****************************************************************************
** Meta object code from reading C++ file 'computeritemwatcher.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-computer/watcher/computeritemwatcher.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'computeritemwatcher.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_computer::ComputerItemWatcher::qt_create_metaobjectdata<qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_computer::ComputerItemWatcher",
        "itemQueryFinished",
        "",
        "ComputerDataList",
        "results",
        "itemAdded",
        "ComputerItemData",
        "item",
        "itemRemoved",
        "QUrl",
        "url",
        "itemUpdated",
        "itemPropertyChanged",
        "property",
        "QVariant",
        "var",
        "itemSizeChanged",
        "hideFileSystemTag",
        "hide",
        "updatePartitionsVisiable",
        "onViewRefresh",
        "onDeviceAdded",
        "devUrl",
        "groupId",
        "ComputerItemData::ShapeType",
        "shape",
        "needSidebarItem",
        "onDevicePropertyChangedQVar",
        "id",
        "propertyName",
        "onDevicePropertyChangedQDBusVar",
        "QDBusVariant",
        "onGenAttributeChanged",
        "Application::GenericAttribute",
        "ga",
        "value",
        "onDConfigChanged",
        "cfg",
        "cfgKey",
        "onBlockDeviceAdded",
        "onBlockDeviceRemoved",
        "onBlockDeviceMounted",
        "mntPath",
        "onBlockDeviceUnmounted",
        "onBlockDeviceLocked",
        "onUpdateBlockItem",
        "onProtocolDeviceMounted",
        "onProtocolDeviceUnmounted",
        "onDeviceSizeChanged",
        "total",
        "free",
        "onProtocolDeviceRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemQueryFinished'
        QtMocHelpers::SignalData<void(const ComputerDataList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const ComputerItemData &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'itemRemoved'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'itemUpdated'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'itemPropertyChanged'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &, const QVariant &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'itemSizeChanged'
        QtMocHelpers::SignalData<void(const QUrl &, qlonglong, qlonglong)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::LongLong, 2 }, { QMetaType::LongLong, 2 },
        }}),
        // Signal 'hideFileSystemTag'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Signal 'updatePartitionsVisiable'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onViewRefresh'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QUrl &, int, ComputerItemData::ShapeType, bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { QMetaType::Int, 23 }, { 0x80000000 | 24, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QUrl &, int, ComputerItemData::ShapeType)>(21, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { QMetaType::Int, 23 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(const QUrl &, int)>(21, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'onDevicePropertyChangedQVar'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QVariant &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onDevicePropertyChangedQDBusVar'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QDBusVariant &)>(30, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 }, { 0x80000000 | 31, 15 },
        }}),
        // Slot 'onGenAttributeChanged'
        QtMocHelpers::SlotData<void(Application::GenericAttribute, const QVariant &)>(32, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { 0x80000000 | 14, 35 },
        }}),
        // Slot 'onDConfigChanged'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(36, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 37 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'onBlockDeviceAdded'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onBlockDeviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onBlockDeviceMounted'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(41, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'onBlockDeviceUnmounted'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onBlockDeviceLocked'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onUpdateBlockItem'
        QtMocHelpers::SlotData<void(const QString &)>(45, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onProtocolDeviceMounted'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(46, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 42 },
        }}),
        // Slot 'onProtocolDeviceUnmounted'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'onDeviceSizeChanged'
        QtMocHelpers::SlotData<void(const QString &, qlonglong, qlonglong)>(48, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::LongLong, 49 }, { QMetaType::LongLong, 50 },
        }}),
        // Slot 'onProtocolDeviceRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComputerItemWatcher, qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_computer::ComputerItemWatcher::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>.metaTypes,
    nullptr
} };

void dfmplugin_computer::ComputerItemWatcher::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComputerItemWatcher *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemQueryFinished((*reinterpret_cast<std::add_pointer_t<ComputerDataList>>(_a[1]))); break;
        case 1: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<ComputerItemData>>(_a[1]))); break;
        case 2: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->itemUpdated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->itemPropertyChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 5: _t->itemSizeChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 6: _t->hideFileSystemTag((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->updatePartitionsVisiable(); break;
        case 8: _t->onViewRefresh(); break;
        case 9: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ComputerItemData::ShapeType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 10: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ComputerItemData::ShapeType>>(_a[3]))); break;
        case 11: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->onDevicePropertyChangedQVar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 13: _t->onDevicePropertyChangedQDBusVar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3]))); break;
        case 14: _t->onGenAttributeChanged((*reinterpret_cast<std::add_pointer_t<Application::GenericAttribute>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 15: _t->onDConfigChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->onBlockDeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->onBlockDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->onBlockDeviceMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->onBlockDeviceUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->onBlockDeviceLocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->onUpdateBlockItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->onProtocolDeviceMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->onProtocolDeviceUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->onDeviceSizeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 25: _t->onProtocolDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const ComputerDataList & )>(_a, &ComputerItemWatcher::itemQueryFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const ComputerItemData & )>(_a, &ComputerItemWatcher::itemAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const QUrl & )>(_a, &ComputerItemWatcher::itemRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const QUrl & )>(_a, &ComputerItemWatcher::itemUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const QUrl & , const QString & , const QVariant & )>(_a, &ComputerItemWatcher::itemPropertyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(const QUrl & , qlonglong , qlonglong )>(_a, &ComputerItemWatcher::itemSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)(bool )>(_a, &ComputerItemWatcher::hideFileSystemTag, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComputerItemWatcher::*)()>(_a, &ComputerItemWatcher::updatePartitionsVisiable, 7))
            return;
    }
}

const QMetaObject *dfmplugin_computer::ComputerItemWatcher::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_computer::ComputerItemWatcher::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_computer19ComputerItemWatcherE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_computer::ComputerItemWatcher::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_computer::ComputerItemWatcher::itemQueryFinished(const ComputerDataList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_computer::ComputerItemWatcher::itemAdded(const ComputerItemData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_computer::ComputerItemWatcher::itemRemoved(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmplugin_computer::ComputerItemWatcher::itemUpdated(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmplugin_computer::ComputerItemWatcher::itemPropertyChanged(const QUrl & _t1, const QString & _t2, const QVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void dfmplugin_computer::ComputerItemWatcher::itemSizeChanged(const QUrl & _t1, qlonglong _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void dfmplugin_computer::ComputerItemWatcher::hideFileSystemTag(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dfmplugin_computer::ComputerItemWatcher::updatePartitionsVisiable()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
