/****************************************************************************
** Meta object code from reading C++ file 'devicemanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "devicemanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicemanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20DeviceManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DeviceManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN20DeviceManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeviceManagerAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.DeviceManager",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.Daemon.DeviceManager\">"
        "\n    <signal name=\"SizeUsedChanged\">\n      <arg direction=\"ou"
        "t\" type=\"s\" name=\"id\"/>\n      <arg direction=\"out\" type=\""
        "x\" name=\"total\"/>\n      <arg direction=\"out\" type=\"x\" name"
        "=\"free\"/>\n    </signal>\n    <signal name=\"NotifyDeviceBusy\">"
        "\n      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n      <ar"
        "g direction=\"out\" type=\"s\" name=\"action\"/>\n    </signal>\n "
        "   <signal name=\"BlockDriveAdded\"/>\n    <signal name=\"BlockDri"
        "veRemoved\"/>\n    <signal name=\"BlockDeviceAdded\">\n      <arg "
        "direction=\"out\" type=\"s\" name=\"id\"/>\n    </signal>\n    <si"
        "gnal name=\"BlockDeviceRemoved\">\n      <arg direction=\"out\" ty"
        "pe=\"s\" name=\"id\"/>\n      <arg direction=\"out\" type=\"s\" na"
        "me=\"oldMpt\"/>\n    </signal>\n    <signal name=\"BlockDeviceFile"
        "systemAdded\">\n      <arg direction=\"out\" type=\"s\" name=\"id\""
        "/>\n    </signal>\n    <signal name=\"BlockDeviceFilesystemRemoved"
        "\">\n      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n    </"
        "signal>\n    <signal name=\"BlockDeviceMounted\">\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"id\"/>\n      <arg direction=\"out"
        "\" type=\"s\" name=\"mountPoint\"/>\n    </signal>\n    <signal na"
        "me=\"BlockDeviceUnmounted\">\n      <arg direction=\"out\" type=\""
        "s\" name=\"id\"/>\n      <arg direction=\"out\" type=\"s\" name=\""
        "oldMpt\"/>\n    </signal>\n    <signal name=\"BlockDevicePropertyC"
        "hanged\">\n      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"property\"/>\n     "
        " <arg direction=\"out\" type=\"v\" name=\"value\"/>\n    </signal>"
        "\n    <signal name=\"BlockDeviceUnlocked\">\n      <arg direction="
        "\"out\" type=\"s\" name=\"id\"/>\n      <arg direction=\"out\" typ"
        "e=\"s\" name=\"clearDeviceId\"/>\n    </signal>\n    <signal name="
        "\"BlockDeviceLocked\">\n      <arg direction=\"out\" type=\"s\" na"
        "me=\"id\"/>\n    </signal>\n    <signal name=\"ProtocolDeviceAdded"
        "\">\n      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n    </"
        "signal>\n    <signal name=\"ProtocolDeviceRemoved\">\n      <arg d"
        "irection=\"out\" type=\"s\" name=\"id\"/>\n      <arg direction=\""
        "out\" type=\"s\" name=\"oldMpt\"/>\n    </signal>\n    <signal nam"
        "e=\"ProtocolDeviceMounted\">\n      <arg direction=\"out\" type=\""
        "s\" name=\"id\"/>\n      <arg direction=\"out\" type=\"s\" name=\""
        "mountPoint\"/>\n    </signal>\n    <signal name=\"ProtocolDeviceUn"
        "mounted\">\n      <arg direction=\"out\" type=\"s\" name=\"id\"/>\n"
        "      <arg direction=\"out\" type=\"s\" name=\"oldMpt\"/>\n    </s"
        "ignal>\n    <method name=\"IsMonotorWorking\">\n      <arg directi"
        "on=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"DetachB"
        "lockDevice\">\n      <arg direction=\"in\" type=\"s\" name=\"id\"/"
        ">\n    </method>\n    <method name=\"DetachProtocolDevice\">\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"id\"/>\n    </method>\n "
        "   <method name=\"DetachAllMountedDevices\"/>\n    <method name=\""
        "GetBlockDevicesIdList\">\n      <arg direction=\"out\" type=\"as\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"opts\"/>\n    </"
        "method>\n    <method name=\"QueryBlockDeviceInfo\">\n      <arg di"
        "rection=\"out\" type=\"a{sv}\"/>\n      <annotation value=\"QVaria"
        "ntMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"id\"/>\n      <arg direction="
        "\"in\" type=\"b\" name=\"reload\"/>\n    </method>\n    <method na"
        "me=\"GetProtocolDevicesIdList\">\n      <arg direction=\"out\" typ"
        "e=\"as\"/>\n    </method>\n    <method name=\"QueryProtocolDeviceI"
        "nfo\">\n      <arg direction=\"out\" type=\"a{sv}\"/>\n      <anno"
        "tation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeNam"
        "e.Out0\"/>\n      <arg direction=\"in\" type=\"s\" name=\"id\"/>\n"
        "      <arg direction=\"in\" type=\"b\" name=\"reload\"/>\n    </me"
        "thod>\n  </interface>\n",
        "BlockDeviceAdded",
        "",
        "id",
        "BlockDeviceFilesystemAdded",
        "BlockDeviceFilesystemRemoved",
        "BlockDeviceLocked",
        "BlockDeviceMounted",
        "mountPoint",
        "BlockDevicePropertyChanged",
        "property",
        "QDBusVariant",
        "value",
        "BlockDeviceRemoved",
        "oldMpt",
        "BlockDeviceUnlocked",
        "clearDeviceId",
        "BlockDeviceUnmounted",
        "BlockDriveAdded",
        "BlockDriveRemoved",
        "NotifyDeviceBusy",
        "action",
        "ProtocolDeviceAdded",
        "ProtocolDeviceMounted",
        "ProtocolDeviceRemoved",
        "ProtocolDeviceUnmounted",
        "SizeUsedChanged",
        "total",
        "free",
        "DetachAllMountedDevices",
        "DetachBlockDevice",
        "DetachProtocolDevice",
        "GetBlockDevicesIdList",
        "opts",
        "GetProtocolDevicesIdList",
        "IsMonotorWorking",
        "QueryBlockDeviceInfo",
        "QVariantMap",
        "reload",
        "QueryProtocolDeviceInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BlockDeviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BlockDeviceFilesystemAdded'
        QtMocHelpers::SignalData<void(const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BlockDeviceFilesystemRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BlockDeviceLocked'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'BlockDeviceMounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'BlockDevicePropertyChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QDBusVariant &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'BlockDeviceRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'BlockDeviceUnlocked'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'BlockDeviceUnmounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'BlockDriveAdded'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'BlockDriveRemoved'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'NotifyDeviceBusy'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 25 },
        }}),
        // Signal 'ProtocolDeviceAdded'
        QtMocHelpers::SignalData<void(const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'ProtocolDeviceMounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'ProtocolDeviceRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'ProtocolDeviceUnmounted'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'SizeUsedChanged'
        QtMocHelpers::SignalData<void(const QString &, qlonglong, qlonglong)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::LongLong, 31 }, { QMetaType::LongLong, 32 },
        }}),
        // Slot 'DetachAllMountedDevices'
        QtMocHelpers::SlotData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DetachBlockDevice'
        QtMocHelpers::SlotData<void(const QString &)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'DetachProtocolDevice'
        QtMocHelpers::SlotData<void(const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'GetBlockDevicesIdList'
        QtMocHelpers::SlotData<QStringList(int)>(36, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 37 },
        }}),
        // Slot 'GetProtocolDevicesIdList'
        QtMocHelpers::SlotData<QStringList()>(38, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'IsMonotorWorking'
        QtMocHelpers::SlotData<bool()>(39, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'QueryBlockDeviceInfo'
        QtMocHelpers::SlotData<QVariantMap(const QString &, bool)>(40, 6, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 42 },
        }}),
        // Slot 'QueryProtocolDeviceInfo'
        QtMocHelpers::SlotData<QVariantMap(const QString &, bool)>(43, 6, QMC::AccessPublic, 0x80000000 | 41, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 42 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DeviceManagerAdaptor, qt_meta_tag_ZN20DeviceManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeviceManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeviceManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeviceManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20DeviceManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void DeviceManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeviceManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BlockDeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->BlockDeviceFilesystemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BlockDeviceFilesystemRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->BlockDeviceLocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->BlockDeviceMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->BlockDevicePropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3]))); break;
        case 6: _t->BlockDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 7: _t->BlockDeviceUnlocked((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->BlockDeviceUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->BlockDriveAdded(); break;
        case 10: _t->BlockDriveRemoved(); break;
        case 11: _t->NotifyDeviceBusy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->ProtocolDeviceAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->ProtocolDeviceMounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->ProtocolDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: _t->ProtocolDeviceUnmounted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->SizeUsedChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 17: _t->DetachAllMountedDevices(); break;
        case 18: _t->DetachBlockDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->DetachProtocolDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: { QStringList _r = _t->GetBlockDevicesIdList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: { QStringList _r = _t->GetProtocolDevicesIdList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->IsMonotorWorking();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { QVariantMap _r = _t->QueryBlockDeviceInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 24: { QVariantMap _r = _t->QueryProtocolDeviceInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceFilesystemAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceFilesystemRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceLocked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceMounted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & , const QDBusVariant & )>(_a, &DeviceManagerAdaptor::BlockDevicePropertyChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceUnlocked, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::BlockDeviceUnmounted, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)()>(_a, &DeviceManagerAdaptor::BlockDriveAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)()>(_a, &DeviceManagerAdaptor::BlockDriveRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::NotifyDeviceBusy, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & )>(_a, &DeviceManagerAdaptor::ProtocolDeviceAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::ProtocolDeviceMounted, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::ProtocolDeviceRemoved, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , const QString & )>(_a, &DeviceManagerAdaptor::ProtocolDeviceUnmounted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeviceManagerAdaptor::*)(const QString & , qlonglong , qlonglong )>(_a, &DeviceManagerAdaptor::SizeUsedChanged, 16))
            return;
    }
}

const QMetaObject *DeviceManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20DeviceManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DeviceManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void DeviceManagerAdaptor::BlockDeviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeviceManagerAdaptor::BlockDeviceFilesystemAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeviceManagerAdaptor::BlockDeviceFilesystemRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeviceManagerAdaptor::BlockDeviceLocked(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeviceManagerAdaptor::BlockDeviceMounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DeviceManagerAdaptor::BlockDevicePropertyChanged(const QString & _t1, const QString & _t2, const QDBusVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void DeviceManagerAdaptor::BlockDeviceRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DeviceManagerAdaptor::BlockDeviceUnlocked(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void DeviceManagerAdaptor::BlockDeviceUnmounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void DeviceManagerAdaptor::BlockDriveAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void DeviceManagerAdaptor::BlockDriveRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void DeviceManagerAdaptor::NotifyDeviceBusy(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void DeviceManagerAdaptor::ProtocolDeviceAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DeviceManagerAdaptor::ProtocolDeviceMounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void DeviceManagerAdaptor::ProtocolDeviceRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}

// SIGNAL 15
void DeviceManagerAdaptor::ProtocolDeviceUnmounted(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void DeviceManagerAdaptor::SizeUsedChanged(const QString & _t1, qlonglong _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
