/****************************************************************************
** Meta object code from reading C++ file 'fileinfohelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/utils/fileinfohelper.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'fileinfohelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::FileInfoHelper::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::FileInfoHelper",
        "mediaDataFinished",
        "",
        "QUrl",
        "sourceFile",
        "QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>",
        "properties",
        "fileCountFinished",
        "url",
        "fileCount",
        "fileMimeTypeFinished",
        "QMimeType",
        "type",
        "QSharedPointer<FileInfoHelperUeserData>",
        "data",
        "fileMimeType",
        "QMimeDatabase::MatchMode",
        "mode",
        "inod",
        "isGvfs",
        "fileInfoRefresh",
        "QSharedPointer<dfmio::DFileInfo>",
        "dfileInfo",
        "fileRefreshFinished",
        "infoPtr",
        "isLinkOrg",
        "fileRefreshRequest",
        "QSharedPointer<FileInfo>",
        "smbSeverMayModifyPassword",
        "aboutToQuit",
        "handleFileRefresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mediaDataFinished'
        QtMocHelpers::SignalData<void(const QUrl &, QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'fileCountFinished'
        QtMocHelpers::SignalData<void(const QUrl &, const int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'fileMimeTypeFinished'
        QtMocHelpers::SignalData<void(const QUrl &, const QMimeType &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'fileCount'
        QtMocHelpers::SignalData<void(const QUrl &, const QSharedPointer<FileInfoHelperUeserData>)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'fileMimeType'
        QtMocHelpers::SignalData<void(const QUrl &, const QMimeDatabase::MatchMode, const QString &, const bool, const QSharedPointer<FileInfoHelperUeserData>)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::Bool, 19 },
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'fileInfoRefresh'
        QtMocHelpers::SignalData<void(const QUrl &, QSharedPointer<dfmio::DFileInfo>)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { 0x80000000 | 21, 22 },
        }}),
        // Signal 'fileRefreshFinished'
        QtMocHelpers::SignalData<void(const QUrl, const QString &, const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Signal 'fileRefreshRequest'
        QtMocHelpers::SignalData<void(QSharedPointer<FileInfo>)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 22 },
        }}),
        // Signal 'smbSeverMayModifyPassword'
        QtMocHelpers::SignalData<void(const QUrl &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 8 },
        }}),
        // Slot 'aboutToQuit'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleFileRefresh'
        QtMocHelpers::SlotData<void(QSharedPointer<FileInfo>)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileInfoHelper, qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::FileInfoHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>.metaTypes,
    nullptr
} };

void dfmbase::FileInfoHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileInfoHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mediaDataFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>>>(_a[2]))); break;
        case 1: _t->fileCountFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->fileMimeTypeFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeType>>(_a[2]))); break;
        case 3: _t->fileCount((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfoHelperUeserData>>>(_a[2]))); break;
        case 4: _t->fileMimeType((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMimeDatabase::MatchMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfoHelperUeserData>>>(_a[5]))); break;
        case 5: _t->fileInfoRefresh((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<dfmio::DFileInfo>>>(_a[2]))); break;
        case 6: _t->fileRefreshFinished((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->fileRefreshRequest((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfo>>>(_a[1]))); break;
        case 8: _t->smbSeverMayModifyPassword((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->aboutToQuit(); break;
        case 10: _t->handleFileRefresh((*reinterpret_cast<std::add_pointer_t<QSharedPointer<FileInfo>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , QMap<dfmio::DFileInfo::AttributeExtendID,QVariant> )>(_a, &FileInfoHelper::mediaDataFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , const int )>(_a, &FileInfoHelper::fileCountFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , const QMimeType & )>(_a, &FileInfoHelper::fileMimeTypeFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , const QSharedPointer<FileInfoHelperUeserData> )>(_a, &FileInfoHelper::fileCount, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , const QMimeDatabase::MatchMode , const QString & , const bool , const QSharedPointer<FileInfoHelperUeserData> )>(_a, &FileInfoHelper::fileMimeType, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & , QSharedPointer<dfmio::DFileInfo> )>(_a, &FileInfoHelper::fileInfoRefresh, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl , const QString & , const bool )>(_a, &FileInfoHelper::fileRefreshFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(QSharedPointer<FileInfo> )>(_a, &FileInfoHelper::fileRefreshRequest, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileInfoHelper::*)(const QUrl & )>(_a, &FileInfoHelper::smbSeverMayModifyPassword, 8))
            return;
    }
}

const QMetaObject *dfmbase::FileInfoHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::FileInfoHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase14FileInfoHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmbase::FileInfoHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::FileInfoHelper::mediaDataFinished(const QUrl & _t1, QMap<dfmio::DFileInfo::AttributeExtendID,QVariant> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dfmbase::FileInfoHelper::fileCountFinished(const QUrl & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void dfmbase::FileInfoHelper::fileMimeTypeFinished(const QUrl & _t1, const QMimeType & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dfmbase::FileInfoHelper::fileCount(const QUrl & _t1, const QSharedPointer<FileInfoHelperUeserData> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dfmbase::FileInfoHelper::fileMimeType(const QUrl & _t1, const QMimeDatabase::MatchMode _t2, const QString & _t3, const bool _t4, const QSharedPointer<FileInfoHelperUeserData> _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 5
void dfmbase::FileInfoHelper::fileInfoRefresh(const QUrl & _t1, QSharedPointer<dfmio::DFileInfo> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dfmbase::FileInfoHelper::fileRefreshFinished(const QUrl _t1, const QString & _t2, const bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void dfmbase::FileInfoHelper::fileRefreshRequest(QSharedPointer<FileInfo> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dfmbase::FileInfoHelper::smbSeverMayModifyPassword(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
