/****************************************************************************
** Meta object code from reading C++ file 'propertydialogutil.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-propertydialog/utils/propertydialogutil.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'propertydialogutil.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_propertydialog::PropertyDialogUtil::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_propertydialog::PropertyDialogUtil",
        "showPropertyDialog",
        "",
        "QList<QUrl>",
        "urls",
        "QVariantHash",
        "option",
        "showFilePropertyDialog",
        "showCustomDialog",
        "QUrl",
        "url",
        "insertExtendedControlFileProperty",
        "index",
        "QWidget*",
        "widget",
        "addExtendedControlFileProperty",
        "closeFilePropertyDialog",
        "closeCustomPropertyDialog",
        "closeAllFilePropertyDialog",
        "closeAllPropertyDialog",
        "createControlView",
        "updateCloseIndicator"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'showPropertyDialog'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QVariantHash &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'showPropertyDialog'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showFilePropertyDialog'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QVariantHash &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'showFilePropertyDialog'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showCustomDialog'
        QtMocHelpers::SlotData<bool(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'insertExtendedControlFileProperty'
        QtMocHelpers::SlotData<void(const QUrl &, int, QWidget *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'addExtendedControlFileProperty'
        QtMocHelpers::SlotData<void(const QUrl &, QWidget *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'closeFilePropertyDialog'
        QtMocHelpers::SlotData<void(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'closeCustomPropertyDialog'
        QtMocHelpers::SlotData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'closeAllFilePropertyDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeAllPropertyDialog'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createControlView'
        QtMocHelpers::SlotData<void(const QUrl &, const QVariantHash &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'createControlView'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'updateCloseIndicator'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PropertyDialogUtil, qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_propertydialog::PropertyDialogUtil::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>.metaTypes,
    nullptr
} };

void dfmplugin_propertydialog::PropertyDialogUtil::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PropertyDialogUtil *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showPropertyDialog((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantHash>>(_a[2]))); break;
        case 1: _t->showPropertyDialog((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 2: _t->showFilePropertyDialog((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantHash>>(_a[2]))); break;
        case 3: _t->showFilePropertyDialog((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 4: { bool _r = _t->showCustomDialog((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->insertExtendedControlFileProperty((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[3]))); break;
        case 6: _t->addExtendedControlFileProperty((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 7: _t->closeFilePropertyDialog((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->closeCustomPropertyDialog((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->closeAllFilePropertyDialog(); break;
        case 10: _t->closeAllPropertyDialog(); break;
        case 11: _t->createControlView((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantHash>>(_a[2]))); break;
        case 12: _t->createControlView((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->updateCloseIndicator(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dfmplugin_propertydialog::PropertyDialogUtil::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_propertydialog::PropertyDialogUtil::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_propertydialog18PropertyDialogUtilE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_propertydialog::PropertyDialogUtil::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
