/****************************************************************************
** Meta object code from reading C++ file 'collectionframe.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-organizer/view/collectionframe.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collectionframe.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_organizer::CollectionFrame::qt_create_metaobjectdata<qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_organizer::CollectionFrame",
        "sizeModeChanged",
        "",
        "CollectionFrameSize",
        "size",
        "geometryChanged",
        "editingStatusChanged",
        "editing",
        "requestChangeSurface",
        "cursorScreenName",
        "oldScreenName",
        "surfaceChanged",
        "QWidget*",
        "surface",
        "requestDeactiveAllPredictors",
        "moveStateChanged",
        "moving",
        "adjustSizeMode",
        "CollectionFrameFeatures",
        "CollectionFrameFeature",
        "NoCollectionFrameFeatures",
        "CollectionFrameClosable",
        "CollectionFrameMovable",
        "CollectionFrameFloatable",
        "CollectionFrameHiddable",
        "CollectionFrameAdjustable",
        "CollectionFrameStretchable",
        "CollectionGroupFeatureMask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sizeModeChanged'
        QtMocHelpers::SignalData<void(const CollectionFrameSize &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editingStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'requestChangeSurface'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'surfaceChanged'
        QtMocHelpers::SignalData<void(QWidget *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'requestDeactiveAllPredictors'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'moveStateChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'adjustSizeMode'
        QtMocHelpers::SlotData<void(const CollectionFrameSize &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'CollectionFrameFeatures'
        QtMocHelpers::EnumData<CollectionFrameFeatures>(18, 19, QMC::EnumIsFlag).add({
            {   20, CollectionFrameFeature::NoCollectionFrameFeatures },
            {   21, CollectionFrameFeature::CollectionFrameClosable },
            {   22, CollectionFrameFeature::CollectionFrameMovable },
            {   23, CollectionFrameFeature::CollectionFrameFloatable },
            {   24, CollectionFrameFeature::CollectionFrameHiddable },
            {   25, CollectionFrameFeature::CollectionFrameAdjustable },
            {   26, CollectionFrameFeature::CollectionFrameStretchable },
            {   27, CollectionFrameFeature::CollectionGroupFeatureMask },
        }),
    };
    return QtMocHelpers::metaObjectData<CollectionFrame, qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_organizer::CollectionFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Widget::DFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>.metaTypes,
    nullptr
} };

void ddplugin_organizer::CollectionFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollectionFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sizeModeChanged((*reinterpret_cast<std::add_pointer_t<CollectionFrameSize>>(_a[1]))); break;
        case 1: _t->geometryChanged(); break;
        case 2: _t->editingStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->requestChangeSurface((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->surfaceChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 5: _t->requestDeactiveAllPredictors(); break;
        case 6: _t->moveStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->adjustSizeMode((*reinterpret_cast<std::add_pointer_t<CollectionFrameSize>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)(const CollectionFrameSize & )>(_a, &CollectionFrame::sizeModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)()>(_a, &CollectionFrame::geometryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)(bool )>(_a, &CollectionFrame::editingStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)(const QString & , const QString & )>(_a, &CollectionFrame::requestChangeSurface, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)(QWidget * )>(_a, &CollectionFrame::surfaceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)()>(_a, &CollectionFrame::requestDeactiveAllPredictors, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollectionFrame::*)(bool )>(_a, &CollectionFrame::moveStateChanged, 6))
            return;
    }
}

const QMetaObject *ddplugin_organizer::CollectionFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_organizer::CollectionFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ddplugin_organizer15CollectionFrameE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Widget::DFrame::qt_metacast(_clname);
}

int ddplugin_organizer::CollectionFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Widget::DFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_organizer::CollectionFrame::sizeModeChanged(const CollectionFrameSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ddplugin_organizer::CollectionFrame::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ddplugin_organizer::CollectionFrame::editingStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ddplugin_organizer::CollectionFrame::requestChangeSurface(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ddplugin_organizer::CollectionFrame::surfaceChanged(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ddplugin_organizer::CollectionFrame::requestDeactiveAllPredictors()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ddplugin_organizer::CollectionFrame::moveStateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
