/****************************************************************************
** Meta object code from reading C++ file 'eventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-encrypt-manager/events/eventreceiver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'eventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_encrypt_manager::EventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_encrypt_manager::EventReceiver",
        "tpmIsAvailable",
        "",
        "getRandomByTpm",
        "size",
        "QString*",
        "output",
        "isTpmSupportAlgo",
        "algoName",
        "bool*",
        "support",
        "encrypyByTpm",
        "hashAlgo",
        "keyAlgo",
        "keyPin",
        "password",
        "dirPath",
        "decryptByTpm",
        "pwd",
        "tpmIsAvailableProcess",
        "getRandomByTpmProcess",
        "isTpmSupportAlgoProcess",
        "encryptByTpmProcess",
        "QVariantMap",
        "encryptParams",
        "decryptByTpmProcess",
        "decryptParams",
        "ownerAuthStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'tpmIsAvailable'
        QtMocHelpers::SlotData<bool()>(1, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'getRandomByTpm'
        QtMocHelpers::SlotData<bool(int, QString *)>(3, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'isTpmSupportAlgo'
        QtMocHelpers::SlotData<bool(const QString &, bool *)>(7, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'encrypyByTpm'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 }, { QMetaType::QString, 15 },
            { QMetaType::QString, 16 },
        }}),
        // Slot 'decryptByTpm'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, QString *)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 16 }, { 0x80000000 | 5, 18 },
        }}),
        // Slot 'tpmIsAvailableProcess'
        QtMocHelpers::SlotData<int()>(19, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'getRandomByTpmProcess'
        QtMocHelpers::SlotData<int(int, QString *)>(20, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'isTpmSupportAlgoProcess'
        QtMocHelpers::SlotData<int(const QString &, bool *)>(21, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'encryptByTpmProcess'
        QtMocHelpers::SlotData<int(const QVariantMap &)>(22, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'decryptByTpmProcess'
        QtMocHelpers::SlotData<int(const QVariantMap &, QString *)>(25, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 23, 26 }, { 0x80000000 | 5, 18 },
        }}),
        // Slot 'ownerAuthStatus'
        QtMocHelpers::SlotData<int()>(27, 2, QMC::AccessPublic, QMetaType::Int),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EventReceiver, qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_encrypt_manager::EventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_encrypt_manager::EventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->tpmIsAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->getRandomByTpm((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->isTpmSupportAlgo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->encrypyByTpm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->decryptByTpm((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { int _r = _t->tpmIsAvailableProcess();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->getRandomByTpmProcess((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->isTpmSupportAlgoProcess((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->encryptByTpmProcess((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->decryptByTpmProcess((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->ownerAuthStatus();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_encrypt_manager::EventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_encrypt_manager::EventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25dfmplugin_encrypt_manager13EventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_encrypt_manager::EventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
