/****************************************************************************
** Meta object code from reading C++ file 'packetwritingjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-burn/utils/packetwritingjob.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'packetwritingjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::PacketWritingScheduler::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::PacketWritingScheduler",
        "onTimeout",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onTimeout'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PacketWritingScheduler, qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::PacketWritingScheduler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::PacketWritingScheduler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PacketWritingScheduler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onTimeout(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *dfmplugin_burn::PacketWritingScheduler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::PacketWritingScheduler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22PacketWritingSchedulerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_burn::PacketWritingScheduler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::AbstractPacketWritingJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::AbstractPacketWritingJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractPacketWritingJob, qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::AbstractPacketWritingJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::AbstractPacketWritingJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractPacketWritingJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::AbstractPacketWritingJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::AbstractPacketWritingJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn24AbstractPacketWritingJobE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dfmplugin_burn::AbstractPacketWritingJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::PutPacketWritingJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::PutPacketWritingJob",
        "pendingUrls",
        "QList<QUrl>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pendingUrls'
        QtMocHelpers::PropertyData<QList<QUrl>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PutPacketWritingJob, qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::PutPacketWritingJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPacketWritingJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::PutPacketWritingJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PutPacketWritingJob *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QUrl>*>(_v) = _t->getPendingUrls(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPendingUrls(*reinterpret_cast<QList<QUrl>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dfmplugin_burn::PutPacketWritingJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::PutPacketWritingJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19PutPacketWritingJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPacketWritingJob::qt_metacast(_clname);
}

int dfmplugin_burn::PutPacketWritingJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPacketWritingJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::RemovePacketWritingJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::RemovePacketWritingJob",
        "pendingUrls",
        "QList<QUrl>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pendingUrls'
        QtMocHelpers::PropertyData<QList<QUrl>>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RemovePacketWritingJob, qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::RemovePacketWritingJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPacketWritingJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::RemovePacketWritingJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RemovePacketWritingJob *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QUrl>*>(_v) = _t->getPendingUrls(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPendingUrls(*reinterpret_cast<QList<QUrl>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dfmplugin_burn::RemovePacketWritingJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::RemovePacketWritingJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RemovePacketWritingJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPacketWritingJob::qt_metacast(_clname);
}

int dfmplugin_burn::RemovePacketWritingJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPacketWritingJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::RenamePacketWritingJob::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::RenamePacketWritingJob",
        "srcUrl",
        "QUrl",
        "destUrl"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'srcUrl'
        QtMocHelpers::PropertyData<QUrl>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'destUrl'
        QtMocHelpers::PropertyData<QUrl>(3, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenamePacketWritingJob, qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::RenamePacketWritingJob::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractPacketWritingJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::RenamePacketWritingJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenamePacketWritingJob *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->getSrcUrl(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->getDestUrl(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSrcUrl(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setDestUrl(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dfmplugin_burn::RenamePacketWritingJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::RenamePacketWritingJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RenamePacketWritingJobE_t>.strings))
        return static_cast<void*>(this);
    return AbstractPacketWritingJob::qt_metacast(_clname);
}

int dfmplugin_burn::RenamePacketWritingJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractPacketWritingJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
