/****************************************************************************
** Meta object code from reading C++ file 'detailspaceeventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-detailspace/events/detailspaceeventreceiver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'detailspaceeventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_detailspace::DetailSpaceEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_detailspace::DetailSpaceEventReceiver",
        "handleTileBarShowDetailView",
        "",
        "windowId",
        "checked",
        "handleSetSelect",
        "QUrl",
        "url",
        "handleViewExtensionRegister",
        "CustomViewExtensionView",
        "view",
        "index",
        "handleBasicViewExtensionRegister",
        "BasicViewFieldFunc",
        "func",
        "scheme",
        "handleBasicViewExtensionRootRegister",
        "handleBasicFiledFilterAdd",
        "enums",
        "handleBasicFiledFilterRootAdd",
        "handleViewSelectionChanged",
        "windowID",
        "QItemSelection",
        "selected",
        "deselected"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleTileBarShowDetailView'
        QtMocHelpers::SlotData<void(quint64, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'handleSetSelect'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'handleViewExtensionRegister'
        QtMocHelpers::SlotData<bool(CustomViewExtensionView, int)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'handleBasicViewExtensionRegister'
        QtMocHelpers::SlotData<bool(BasicViewFieldFunc, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'handleBasicViewExtensionRootRegister'
        QtMocHelpers::SlotData<bool(BasicViewFieldFunc, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'handleBasicFiledFilterAdd'
        QtMocHelpers::SlotData<bool(const QString &, const QStringList &)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::QStringList, 18 },
        }}),
        // Slot 'handleBasicFiledFilterRootAdd'
        QtMocHelpers::SlotData<bool(const QString &, const QStringList &)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 15 }, { QMetaType::QStringList, 18 },
        }}),
        // Slot 'handleViewSelectionChanged'
        QtMocHelpers::SlotData<void(const quint64, const QItemSelection &, const QItemSelection &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 21 }, { 0x80000000 | 22, 23 }, { 0x80000000 | 22, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DetailSpaceEventReceiver, qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_detailspace::DetailSpaceEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_detailspace::DetailSpaceEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DetailSpaceEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleTileBarShowDetailView((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->handleSetSelect((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 2: { bool _r = _t->handleViewExtensionRegister((*reinterpret_cast<std::add_pointer_t<CustomViewExtensionView>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->handleBasicViewExtensionRegister((*reinterpret_cast<std::add_pointer_t<BasicViewFieldFunc>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->handleBasicViewExtensionRootRegister((*reinterpret_cast<std::add_pointer_t<BasicViewFieldFunc>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->handleBasicFiledFilterAdd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->handleBasicFiledFilterRootAdd((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->handleViewSelectionChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dfmplugin_detailspace::DetailSpaceEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_detailspace::DetailSpaceEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace24DetailSpaceEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_detailspace::DetailSpaceEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
