/****************************************************************************
** Meta object code from reading C++ file 'canvasproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/model/canvasproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::CanvasProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::CanvasProxyModel",
        "dataReplaced",
        "",
        "QUrl",
        "oldUrl",
        "newUrl",
        "sort",
        "refresh",
        "QModelIndex",
        "parent",
        "global",
        "ms",
        "updateFile",
        "setShowHiddenFiles",
        "show",
        "fetch",
        "url",
        "take",
        "mapToSource",
        "proxyIndex",
        "mapFromSource",
        "sourceIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataReplaced'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Slot 'sort'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool, int, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 10 }, { QMetaType::Int, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool, int)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setShowHiddenFiles'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'fetch'
        QtMocHelpers::SlotData<bool(const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'take'
        QtMocHelpers::SlotData<bool(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Method 'mapToSource'
        QtMocHelpers::MethodData<QModelIndex(const QModelIndex &) const>(18, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 19 },
        }}),
        // Method 'mapFromSource'
        QtMocHelpers::MethodData<QModelIndex(const QModelIndex &) const>(20, 2, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasProxyModel, qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::CanvasProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::CanvasProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataReplaced((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: { bool _r = _t->sort();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 3: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 6: _t->setShowHiddenFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { bool _r = _t->fetch((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->take((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { QModelIndex _r = _t->mapToSource((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 10: { QModelIndex _r = _t->mapFromSource((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CanvasProxyModel::*)(const QUrl & , const QUrl & )>(_a, &CanvasProxyModel::dataReplaced, 0))
            return;
    }
}

const QMetaObject *ddplugin_canvas::CanvasProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::CanvasProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas16CanvasProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int ddplugin_canvas::CanvasProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_canvas::CanvasProxyModel::dataReplaced(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
