/****************************************************************************
** Meta object code from reading C++ file 'filebaseinfoview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-detailspace/views/filebaseinfoview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filebaseinfoview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_detailspace::FileBaseInfoView::qt_create_metaobjectdata<qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_detailspace::FileBaseInfoView",
        "sigImageExtenInfo",
        "",
        "properties",
        "sigVideoExtenInfo",
        "sigAudioExtenInfo",
        "imageExtenInfo",
        "QUrl",
        "url",
        "QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>",
        "videoExtenInfo",
        "audioExtenInfo",
        "slotImageExtenInfo",
        "slotVideoExtenInfo",
        "slotAudioExtenInfo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigImageExtenInfo'
        QtMocHelpers::SignalData<void(const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'sigVideoExtenInfo'
        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'sigAudioExtenInfo'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'imageExtenInfo'
        QtMocHelpers::SlotData<void(const QUrl &, QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 3 },
        }}),
        // Slot 'videoExtenInfo'
        QtMocHelpers::SlotData<void(const QUrl &, QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 3 },
        }}),
        // Slot 'audioExtenInfo'
        QtMocHelpers::SlotData<void(const QUrl &, QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 3 },
        }}),
        // Slot 'slotImageExtenInfo'
        QtMocHelpers::SlotData<void(const QStringList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'slotVideoExtenInfo'
        QtMocHelpers::SlotData<void(const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Slot 'slotAudioExtenInfo'
        QtMocHelpers::SlotData<void(const QStringList &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileBaseInfoView, qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_detailspace::FileBaseInfoView::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>.metaTypes,
    nullptr
} };

void dfmplugin_detailspace::FileBaseInfoView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileBaseInfoView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigImageExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->sigVideoExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->sigAudioExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->imageExtenInfo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>>>(_a[2]))); break;
        case 4: _t->videoExtenInfo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>>>(_a[2]))); break;
        case 5: _t->audioExtenInfo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<dfmio::DFileInfo::AttributeExtendID,QVariant>>>(_a[2]))); break;
        case 6: _t->slotImageExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 7: _t->slotVideoExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->slotAudioExtenInfo((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileBaseInfoView::*)(const QStringList & )>(_a, &FileBaseInfoView::sigImageExtenInfo, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBaseInfoView::*)(const QStringList & )>(_a, &FileBaseInfoView::sigVideoExtenInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBaseInfoView::*)(const QStringList & )>(_a, &FileBaseInfoView::sigAudioExtenInfo, 2))
            return;
    }
}

const QMetaObject *dfmplugin_detailspace::FileBaseInfoView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_detailspace::FileBaseInfoView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21dfmplugin_detailspace16FileBaseInfoViewE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dfmplugin_detailspace::FileBaseInfoView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_detailspace::FileBaseInfoView::sigImageExtenInfo(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_detailspace::FileBaseInfoView::sigVideoExtenInfo(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_detailspace::FileBaseInfoView::sigAudioExtenInfo(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
