/****************************************************************************
** Meta object code from reading C++ file 'tagmanageradaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "tagmanageradaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tagmanageradaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17TagManagerAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto TagManagerAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN17TagManagerAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TagManagerAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.Daemon.TagManager",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.Daemon.TagManager\">\n "
        "   <signal name=\"TagsServiceReady\"/>\n    <signal name=\"NewTags"
        "Added\">\n      <arg direction=\"out\" type=\"a{sv}\" name=\"tags\""
        "/>\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.Q"
        "tDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name=\"TagsD"
        "eleted\">\n      <arg direction=\"out\" type=\"as\" name=\"tags\"/"
        ">\n    </signal>\n    <signal name=\"TagsColorChanged\">\n      <a"
        "rg direction=\"out\" type=\"a{sv}\" name=\"oldAndNew\"/>\n      <a"
        "nnotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtType"
        "Name.Out0\"/>\n    </signal>\n    <signal name=\"TagsNameChanged\""
        ">\n      <arg direction=\"out\" type=\"a{sv}\" name=\"oldAndNew\"/"
        ">\n      <annotation value=\"QVariantMap\" name=\"org.qtproject.Qt"
        "DBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name=\"FilesT"
        "agged\">\n      <arg direction=\"out\" type=\"a{sv}\" name=\"fileA"
        "ndTags\"/>\n      <annotation value=\"QVariantMap\" name=\"org.qtp"
        "roject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <signal name"
        "=\"FilesUntagged\">\n      <arg direction=\"out\" type=\"a{sv}\" n"
        "ame=\"fileAndTags\"/>\n      <annotation value=\"QVariantMap\" nam"
        "e=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>\n    <"
        "method name=\"Query\">\n      <arg direction=\"out\" type=\"v\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"opt\"/>\n      <arg "
        "direction=\"in\" type=\"as\" name=\"value\"/>\n    </method>\n    "
        "<method name=\"Query\">\n      <arg direction=\"out\" type=\"v\"/>"
        "\n      <arg direction=\"in\" type=\"i\" name=\"opt\"/>\n    </met"
        "hod>\n    <method name=\"Insert\">\n      <arg direction=\"out\" t"
        "ype=\"b\"/>\n      <arg direction=\"in\" type=\"i\" name=\"opt\"/>"
        "\n      <arg direction=\"in\" type=\"a{sv}\" name=\"value\"/>\n   "
        "   <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.Q"
        "tTypeName.In1\"/>\n    </method>\n    <method name=\"Delete\">\n  "
        "    <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"opt\"/>\n      <arg direction=\"in\" type=\"a"
        "{sv}\" name=\"value\"/>\n      <annotation value=\"QVariantMap\" n"
        "ame=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n    </method>\n    "
        "<method name=\"Update\">\n      <arg direction=\"out\" type=\"b\"/"
        ">\n      <arg direction=\"in\" type=\"i\" name=\"opt\"/>\n      <a"
        "rg direction=\"in\" type=\"a{sv}\" name=\"value\"/>\n      <annota"
        "tion value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName."
        "In1\"/>\n    </method>\n  </interface>\n",
        "FilesTagged",
        "",
        "QVariantMap",
        "fileAndTags",
        "FilesUntagged",
        "NewTagsAdded",
        "tags",
        "TagsColorChanged",
        "oldAndNew",
        "TagsDeleted",
        "TagsNameChanged",
        "TagsServiceReady",
        "Delete",
        "opt",
        "value",
        "Insert",
        "Query",
        "QDBusVariant",
        "Update"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'FilesTagged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'FilesUntagged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'NewTagsAdded'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 11 },
        }}),
        // Signal 'TagsColorChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 13 },
        }}),
        // Signal 'TagsDeleted'
        QtMocHelpers::SignalData<void(const QStringList &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Signal 'TagsNameChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 13 },
        }}),
        // Signal 'TagsServiceReady'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Delete'
        QtMocHelpers::SlotData<bool(int, const QVariantMap &)>(17, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 18 }, { 0x80000000 | 7, 19 },
        }}),
        // Slot 'Insert'
        QtMocHelpers::SlotData<bool(int, const QVariantMap &)>(20, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 18 }, { 0x80000000 | 7, 19 },
        }}),
        // Slot 'Query'
        QtMocHelpers::SlotData<QDBusVariant(int)>(21, 6, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'Query'
        QtMocHelpers::SlotData<QDBusVariant(int, const QStringList &)>(21, 6, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::Int, 18 }, { QMetaType::QStringList, 19 },
        }}),
        // Slot 'Update'
        QtMocHelpers::SlotData<bool(int, const QVariantMap &)>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 18 }, { 0x80000000 | 7, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TagManagerAdaptor, qt_meta_tag_ZN17TagManagerAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TagManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TagManagerAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TagManagerAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TagManagerAdaptorE_t>.metaTypes,
    nullptr
} };

void TagManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TagManagerAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->FilesTagged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->FilesUntagged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->NewTagsAdded((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->TagsColorChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->TagsDeleted((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->TagsNameChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 6: _t->TagsServiceReady(); break;
        case 7: { bool _r = _t->Delete((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->Insert((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusVariant _r = _t->Query((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusVariant _r = _t->Query((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->Update((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QVariantMap & )>(_a, &TagManagerAdaptor::FilesTagged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QVariantMap & )>(_a, &TagManagerAdaptor::FilesUntagged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QVariantMap & )>(_a, &TagManagerAdaptor::NewTagsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QVariantMap & )>(_a, &TagManagerAdaptor::TagsColorChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QStringList & )>(_a, &TagManagerAdaptor::TagsDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)(const QVariantMap & )>(_a, &TagManagerAdaptor::TagsNameChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TagManagerAdaptor::*)()>(_a, &TagManagerAdaptor::TagsServiceReady, 6))
            return;
    }
}

const QMetaObject *TagManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TagManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TagManagerAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int TagManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void TagManagerAdaptor::FilesTagged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TagManagerAdaptor::FilesUntagged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TagManagerAdaptor::NewTagsAdded(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TagManagerAdaptor::TagsColorChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TagManagerAdaptor::TagsDeleted(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void TagManagerAdaptor::TagsNameChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TagManagerAdaptor::TagsServiceReady()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
