/****************************************************************************
** Meta object code from reading C++ file 'filestatisticsjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/src/dfm-base/utils/filestatisticsjob.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filestatisticsjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::FileStatisticsJob::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::FileStatisticsJob",
        "stateChanged",
        "",
        "State",
        "state",
        "sizeChanged",
        "size",
        "dataNotify",
        "filesCount",
        "directoryCount",
        "start",
        "QList<QUrl>",
        "sourceUrls",
        "stop",
        "togglePause",
        "setFileHints",
        "FileHints",
        "fileHints",
        "kStoppedState",
        "kRunningState",
        "kPausedState",
        "FileHint",
        "kNoHint",
        "kNoFollowSymlink",
        "kExcludeSourceFile",
        "kSingleDepth",
        "kDontSkipAVFSDStorage",
        "kDontSkipPROCStorage",
        "kDontSkipCharDeviceFile",
        "kDontSkipBlockDeviceFile",
        "kDontSkipFIFOFile",
        "kDontSkipSocketFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(enum State)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sizeChanged'
        QtMocHelpers::SignalData<void(qint64)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 },
        }}),
        // Signal 'dataNotify'
        QtMocHelpers::SignalData<void(qint64, int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 6 }, { QMetaType::Int, 8 }, { QMetaType::Int, 9 },
        }}),
        // Slot 'start'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'togglePause'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFileHints'
        QtMocHelpers::SlotData<void(FileHints)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<enum State>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'fileHints'
        QtMocHelpers::PropertyData<FileHints>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'State'
        QtMocHelpers::EnumData<enum State>(3, 3, QMC::EnumFlags{}).add({
            {   18, State::kStoppedState },
            {   19, State::kRunningState },
            {   20, State::kPausedState },
        }),
        // enum 'FileHint'
        QtMocHelpers::EnumData<enum FileHint>(21, 21, QMC::EnumFlags{}).add({
            {   22, FileHint::kNoHint },
            {   23, FileHint::kNoFollowSymlink },
            {   24, FileHint::kExcludeSourceFile },
            {   25, FileHint::kSingleDepth },
            {   26, FileHint::kDontSkipAVFSDStorage },
            {   27, FileHint::kDontSkipPROCStorage },
            {   28, FileHint::kDontSkipCharDeviceFile },
            {   29, FileHint::kDontSkipBlockDeviceFile },
            {   30, FileHint::kDontSkipFIFOFile },
            {   31, FileHint::kDontSkipSocketFile },
        }),
    };
    return QtMocHelpers::metaObjectData<FileStatisticsJob, qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::FileStatisticsJob::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>.metaTypes,
    nullptr
} };

void dfmbase::FileStatisticsJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileStatisticsJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<enum State>>(_a[1]))); break;
        case 1: _t->sizeChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 2: _t->dataNotify((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 3: _t->start((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 4: _t->stop(); break;
        case 5: _t->togglePause(); break;
        case 6: _t->setFileHints((*reinterpret_cast<std::add_pointer_t<FileHints>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileStatisticsJob::*)(State )>(_a, &FileStatisticsJob::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileStatisticsJob::*)(qint64 )>(_a, &FileStatisticsJob::sizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileStatisticsJob::*)(qint64 , int , int )>(_a, &FileStatisticsJob::dataNotify, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum State*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<FileHints*>(_v) = _t->fileHints(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setFileHints(*reinterpret_cast<FileHints*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dfmbase::FileStatisticsJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::FileStatisticsJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileStatisticsJobE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dfmbase::FileStatisticsJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::FileStatisticsJob::stateChanged(State _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmbase::FileStatisticsJob::sizeChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmbase::FileStatisticsJob::dataNotify(qint64 _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
