/****************************************************************************
** Meta object code from reading C++ file 'canvasmodelbroker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-canvas/broker/canvasmodelbroker.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvasmodelbroker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_canvas::CanvasModelBroker::qt_create_metaobjectdata<qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_canvas::CanvasModelBroker",
        "rootUrl",
        "QUrl",
        "",
        "urlIndex",
        "QModelIndex",
        "url",
        "index",
        "row",
        "fileUrl",
        "files",
        "QList<QUrl>",
        "showHiddenFiles",
        "setShowHiddenFiles",
        "show",
        "sortOrder",
        "setSortOrder",
        "order",
        "sortRole",
        "setSortRole",
        "role",
        "rowCount",
        "data",
        "QVariant",
        "itemRole",
        "sort",
        "refresh",
        "global",
        "ms",
        "updateFile",
        "fetch",
        "take"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'rootUrl'
        QtMocHelpers::SlotData<QUrl()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'urlIndex'
        QtMocHelpers::SlotData<QModelIndex(const QUrl &)>(4, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { 0x80000000 | 2, 6 },
        }}),
        // Slot 'index'
        QtMocHelpers::SlotData<QModelIndex(int)>(7, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'fileUrl'
        QtMocHelpers::SlotData<QUrl(const QModelIndex &)>(9, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 5, 7 },
        }}),
        // Slot 'files'
        QtMocHelpers::SlotData<QList<QUrl>()>(10, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'showHiddenFiles'
        QtMocHelpers::SlotData<bool()>(12, 3, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShowHiddenFiles'
        QtMocHelpers::SlotData<void(bool)>(13, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'sortOrder'
        QtMocHelpers::SlotData<int()>(15, 3, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setSortOrder'
        QtMocHelpers::SlotData<void(int)>(16, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'sortRole'
        QtMocHelpers::SlotData<int()>(18, 3, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setSortRole'
        QtMocHelpers::SlotData<void(int, int)>(19, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'rowCount'
        QtMocHelpers::SlotData<int()>(21, 3, QMC::AccessPublic, QMetaType::Int),
        // Slot 'data'
        QtMocHelpers::SlotData<QVariant(const QUrl &, int)>(22, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 2, 6 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'sort'
        QtMocHelpers::SlotData<void()>(25, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(bool, int, bool)>(26, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 }, { QMetaType::Int, 28 }, { QMetaType::Bool, 29 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(bool, int)>(26, 3, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 27 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'fetch'
        QtMocHelpers::SlotData<bool(const QUrl &)>(30, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 6 },
        }}),
        // Slot 'take'
        QtMocHelpers::SlotData<bool(const QUrl &)>(31, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CanvasModelBroker, qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_canvas::CanvasModelBroker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>.metaTypes,
    nullptr
} };

void ddplugin_canvas::CanvasModelBroker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CanvasModelBroker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QUrl _r = _t->rootUrl();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 1: { QModelIndex _r = _t->urlIndex((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 2: { QModelIndex _r = _t->index((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 3: { QUrl _r = _t->fileUrl((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 4: { QList<QUrl> _r = _t->files();
            if (_a[0]) *reinterpret_cast<QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->showHiddenFiles();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setShowHiddenFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { int _r = _t->sortOrder();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setSortOrder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: { int _r = _t->sortRole();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setSortRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->sort(); break;
        case 14: _t->refresh((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->refresh((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: { bool _r = _t->fetch((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->take((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ddplugin_canvas::CanvasModelBroker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_canvas::CanvasModelBroker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ddplugin_canvas17CanvasModelBrokerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ddplugin_canvas::CanvasModelBroker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
