/****************************************************************************
** Meta object code from reading C++ file 'dbusdisplay1.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-core/screen/dbus-private/dbusdisplay1.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusdisplay1.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DBusDisplayE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusDisplay::qt_create_metaobjectdata<qt_meta_tag_ZN11DBusDisplayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusDisplay",
        "MonitorsChanged",
        "",
        "PrimaryChanged",
        "DisplayModeChanged",
        "PrimaryRectChanged",
        "__propertyChanged__",
        "QDBusMessage",
        "msg",
        "ApplyChanges",
        "QDBusPendingReply<>",
        "AssociateTouch",
        "outputName",
        "touchSerial",
        "AssociateTouchByUUID",
        "touchUUID",
        "CanRotate",
        "QDBusPendingReply<bool>",
        "CanSetBrightness",
        "ChangeBrightness",
        "raised",
        "DeleteCustomMode",
        "name",
        "GetBuiltinMonitor",
        "QDBusPendingReply<QString,QDBusObjectPath>",
        "QDBusReply<QString>",
        "QDBusObjectPath&",
        "outArg1",
        "GetRealDisplayMode",
        "QDBusPendingReply<uchar>",
        "ListOutputNames",
        "QDBusPendingReply<QStringList>",
        "ModifyConfigName",
        "newName",
        "RefreshBrightness",
        "Reset",
        "ResetChanges",
        "Save",
        "SetAndSaveBrightness",
        "value",
        "SetBrightness",
        "SetColorTemperature",
        "SetMethodAdjustCCT",
        "adjustMethod",
        "SetPrimary",
        "SwitchMode",
        "mode",
        "DisplayMode",
        "HasChanged",
        "Monitors",
        "QList<QDBusObjectPath>",
        "Primary",
        "PrimaryRect",
        "DisplayRect",
        "ScreenHeight",
        "ScreenWidth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'MonitorsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PrimaryChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayModeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PrimaryRectChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot '__propertyChanged__'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'ApplyChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(9, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'AssociateTouch'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'AssociateTouchByUUID'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(14, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'CanRotate'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(16, 2, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'CanSetBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'ChangeBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(19, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'DeleteCustomMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'GetBuiltinMonitor'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,QDBusObjectPath>()>(23, 2, QMC::AccessPublic, 0x80000000 | 24),
        // Slot 'GetBuiltinMonitor'
        QtMocHelpers::SlotData<QDBusReply<QString>(QDBusObjectPath &)>(23, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'GetRealDisplayMode'
        QtMocHelpers::SlotData<QDBusPendingReply<uchar>()>(28, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'ListOutputNames'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(30, 2, QMC::AccessPublic, 0x80000000 | 31),
        // Slot 'ModifyConfigName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 33 },
        }}),
        // Slot 'RefreshBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(34, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'Reset'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(35, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'ResetChanges'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(36, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'Save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(37, 2, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'SetAndSaveBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(38, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 12 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'SetBrightness'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, double)>(40, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 12 }, { QMetaType::Double, 39 },
        }}),
        // Slot 'SetColorTemperature'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(41, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'SetMethodAdjustCCT'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(42, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'SetPrimary'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(44, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'SwitchMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uchar, const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::UChar, 46 }, { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<uchar>(47, QMetaType::UChar, QMC::DefaultPropertyFlags, 2),
        // property 'HasChanged'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Monitors'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'Primary'
        QtMocHelpers::PropertyData<QString>(51, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'PrimaryRect'
        QtMocHelpers::PropertyData<DisplayRect>(52, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'ScreenHeight'
        QtMocHelpers::PropertyData<ushort>(54, QMetaType::UShort, QMC::DefaultPropertyFlags),
        // property 'ScreenWidth'
        QtMocHelpers::PropertyData<ushort>(55, QMetaType::UShort, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusDisplay, qt_meta_tag_ZN11DBusDisplayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusDisplay::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusDisplayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusDisplayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DBusDisplayE_t>.metaTypes,
    nullptr
} };

void DBusDisplay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusDisplay *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->MonitorsChanged(); break;
        case 1: _t->PrimaryChanged(); break;
        case 2: _t->DisplayModeChanged(); break;
        case 3: _t->PrimaryRectChanged(); break;
        case 4: _t->__propertyChanged__((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 5: { QDBusPendingReply<> _r = _t->ApplyChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->AssociateTouch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->AssociateTouchByUUID((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<bool> _r = _t->CanRotate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<bool> _r = _t->CanSetBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->ChangeBrightness((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->DeleteCustomMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<QString,QDBusObjectPath> _r = _t->GetBuiltinMonitor();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusReply<QString> _r = _t->GetBuiltinMonitor((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<uchar> _r = _t->GetRealDisplayMode();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uchar>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QStringList> _r = _t->ListOutputNames();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->ModifyConfigName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->RefreshBrightness();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->Reset();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->ResetChanges();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->Save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->SetAndSaveBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetBrightness((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetColorTemperature((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->SetMethodAdjustCCT((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->SetPrimary((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->SwitchMode((*reinterpret_cast<std::add_pointer_t<uchar>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusDisplay::*)()>(_a, &DBusDisplay::MonitorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDisplay::*)()>(_a, &DBusDisplay::PrimaryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDisplay::*)()>(_a, &DBusDisplay::DisplayModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusDisplay::*)()>(_a, &DBusDisplay::PrimaryRectChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DisplayRect >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uchar*>(_v) = _t->displayMode(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasChanged(); break;
        case 2: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->monitors(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->primary(); break;
        case 4: *reinterpret_cast<DisplayRect*>(_v) = _t->primaryRect(); break;
        case 5: *reinterpret_cast<ushort*>(_v) = _t->screenHeight(); break;
        case 6: *reinterpret_cast<ushort*>(_v) = _t->screenWidth(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusDisplay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusDisplay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DBusDisplayE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusDisplay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DBusDisplay::MonitorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusDisplay::PrimaryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DBusDisplay::DisplayModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DBusDisplay::PrimaryRectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
