/****************************************************************************
** Meta object code from reading C++ file 'abstractworker.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-fileoperations/fileoperations/fileoperationutils/abstractworker.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractworker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_fileoperations::AbstractWorker::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_fileoperations::AbstractWorker",
        "progressChangedNotify",
        "",
        "JobInfoPointer",
        "jobInfo",
        "stateChangedNotify",
        "currentTaskNotify",
        "finishedNotify",
        "speedUpdatedNotify",
        "removeTaskWidget",
        "requestShowTipsDialog",
        "dfmbase::AbstractJobHandler::ShowDialogType",
        "type",
        "QList<QUrl>",
        "list",
        "workerFinish",
        "requestSaveRedoOperation",
        "token",
        "deleteFirstFileSize",
        "startUpdateProgressTimer",
        "startWork",
        "errorNotify",
        "retryErrSuccess",
        "id",
        "requestTaskDailog",
        "doWork",
        "onUpdateProgress",
        "onStatisticsFilesSizeFinish",
        "onStatisticsFilesSizeUpdate",
        "size"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'progressChangedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'stateChangedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'currentTaskNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finishedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'speedUpdatedNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'removeTaskWidget'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestShowTipsDialog'
        QtMocHelpers::SignalData<void(dfmbase::AbstractJobHandler::ShowDialogType, const QList<QUrl> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Signal 'workerFinish'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSaveRedoOperation'
        QtMocHelpers::SignalData<void(const QString &, const qint64)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::LongLong, 18 },
        }}),
        // Signal 'startUpdateProgressTimer'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startWork'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorNotify'
        QtMocHelpers::SignalData<void(const JobInfoPointer)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'retryErrSuccess'
        QtMocHelpers::SignalData<void(const quint64)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 23 },
        }}),
        // Signal 'requestTaskDailog'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doWork'
        QtMocHelpers::SlotData<bool()>(25, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'onUpdateProgress'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onStatisticsFilesSizeFinish'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onStatisticsFilesSizeUpdate'
        QtMocHelpers::SlotData<void(qint64)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::LongLong, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractWorker, qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_fileoperations::AbstractWorker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>.metaTypes,
    nullptr
} };

void dfmplugin_fileoperations::AbstractWorker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractWorker *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->progressChangedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 1: _t->stateChangedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 2: _t->currentTaskNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 3: _t->finishedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 4: _t->speedUpdatedNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 5: _t->removeTaskWidget(); break;
        case 6: _t->requestShowTipsDialog((*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::ShowDialogType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 7: _t->workerFinish(); break;
        case 8: _t->requestSaveRedoOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 9: _t->startUpdateProgressTimer(); break;
        case 10: _t->startWork(); break;
        case 11: _t->errorNotify((*reinterpret_cast<std::add_pointer_t<JobInfoPointer>>(_a[1]))); break;
        case 12: _t->retryErrSuccess((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 13: _t->requestTaskDailog(); break;
        case 14: { bool _r = _t->doWork();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->onUpdateProgress(); break;
        case 16: _t->onStatisticsFilesSizeFinish(); break;
        case 17: _t->onStatisticsFilesSizeUpdate((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::ShowDialogType >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< JobInfoPointer >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::progressChangedNotify, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::stateChangedNotify, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::currentTaskNotify, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::finishedNotify, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::speedUpdatedNotify, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)()>(_a, &AbstractWorker::removeTaskWidget, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(dfmbase::AbstractJobHandler::ShowDialogType , const QList<QUrl> & )>(_a, &AbstractWorker::requestShowTipsDialog, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)()>(_a, &AbstractWorker::workerFinish, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const QString & , const qint64 )>(_a, &AbstractWorker::requestSaveRedoOperation, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)()>(_a, &AbstractWorker::startUpdateProgressTimer, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)()>(_a, &AbstractWorker::startWork, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const JobInfoPointer )>(_a, &AbstractWorker::errorNotify, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)(const quint64 )>(_a, &AbstractWorker::retryErrSuccess, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractWorker::*)()>(_a, &AbstractWorker::requestTaskDailog, 13))
            return;
    }
}

const QMetaObject *dfmplugin_fileoperations::AbstractWorker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_fileoperations::AbstractWorker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations14AbstractWorkerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_fileoperations::AbstractWorker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_fileoperations::AbstractWorker::progressChangedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dfmplugin_fileoperations::AbstractWorker::stateChangedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dfmplugin_fileoperations::AbstractWorker::currentTaskNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmplugin_fileoperations::AbstractWorker::finishedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmplugin_fileoperations::AbstractWorker::speedUpdatedNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dfmplugin_fileoperations::AbstractWorker::removeTaskWidget()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dfmplugin_fileoperations::AbstractWorker::requestShowTipsDialog(dfmbase::AbstractJobHandler::ShowDialogType _t1, const QList<QUrl> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dfmplugin_fileoperations::AbstractWorker::workerFinish()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dfmplugin_fileoperations::AbstractWorker::requestSaveRedoOperation(const QString & _t1, const qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void dfmplugin_fileoperations::AbstractWorker::startUpdateProgressTimer()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void dfmplugin_fileoperations::AbstractWorker::startWork()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dfmplugin_fileoperations::AbstractWorker::errorNotify(const JobInfoPointer _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void dfmplugin_fileoperations::AbstractWorker::retryErrSuccess(const quint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void dfmplugin_fileoperations::AbstractWorker::requestTaskDailog()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
