/****************************************************************************
** Meta object code from reading C++ file 'filemanagerwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../dde-file-manager/include/dfm-base/widgets/filemanagerwindow.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filemanagerwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmbase::FileManagerWindow::qt_create_metaobjectdata<qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmbase::FileManagerWindow",
        "aboutToOpen",
        "",
        "aboutToClose",
        "positionChanged",
        "QPoint",
        "pos",
        "currentUrlChanged",
        "QUrl",
        "url",
        "currentViewStateChanged",
        "selectUrlChanged",
        "QList<QUrl>",
        "urlList",
        "aboutToPlaySplitterAnimation",
        "startValue",
        "endValue",
        "windowSplitterWidthChanged",
        "QVariant",
        "value",
        "reqRefresh",
        "reqActivateNextTab",
        "reqActivatePreviousTab",
        "reqSearchCtrlF",
        "reqSearchCtrlL",
        "reqBack",
        "reqForward",
        "reqCloseCurrentTab",
        "reqCreateTab",
        "reqCreateWindow",
        "reqTriggerActionByIndex",
        "index",
        "reqActivateTabByIndex",
        "reqShowHotkeyHelp",
        "titleBarInstallFinished",
        "sideBarInstallFinished",
        "workspaceInstallFinished",
        "detailViewInstallFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToOpen'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToClose'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const QPoint &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'currentUrlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'currentViewStateChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectUrlChanged'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'aboutToPlaySplitterAnimation'
        QtMocHelpers::SignalData<void(int, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'windowSplitterWidthChanged'
        QtMocHelpers::SignalData<void(const QVariant &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'reqRefresh'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqActivateNextTab'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqActivatePreviousTab'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqSearchCtrlF'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqSearchCtrlL'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqBack'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqForward'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqCloseCurrentTab'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqCreateTab'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqCreateWindow'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reqTriggerActionByIndex'
        QtMocHelpers::SignalData<void(int)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Signal 'reqActivateTabByIndex'
        QtMocHelpers::SignalData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Signal 'reqShowHotkeyHelp'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleBarInstallFinished'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sideBarInstallFinished'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'workspaceInstallFinished'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detailViewInstallFinished'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileManagerWindow, qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmbase::FileManagerWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<DMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>.metaTypes,
    nullptr
} };

void dfmbase::FileManagerWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileManagerWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToOpen(); break;
        case 1: _t->aboutToClose(); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->currentUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->currentViewStateChanged(); break;
        case 5: _t->selectUrlChanged((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 6: _t->aboutToPlaySplitterAnimation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->windowSplitterWidthChanged((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 8: _t->reqRefresh(); break;
        case 9: _t->reqActivateNextTab(); break;
        case 10: _t->reqActivatePreviousTab(); break;
        case 11: _t->reqSearchCtrlF(); break;
        case 12: _t->reqSearchCtrlL(); break;
        case 13: _t->reqBack(); break;
        case 14: _t->reqForward(); break;
        case 15: _t->reqCloseCurrentTab(); break;
        case 16: _t->reqCreateTab(); break;
        case 17: _t->reqCreateWindow(); break;
        case 18: _t->reqTriggerActionByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->reqActivateTabByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->reqShowHotkeyHelp(); break;
        case 21: _t->titleBarInstallFinished(); break;
        case 22: _t->sideBarInstallFinished(); break;
        case 23: _t->workspaceInstallFinished(); break;
        case 24: _t->detailViewInstallFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::aboutToOpen, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::aboutToClose, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(const QPoint & )>(_a, &FileManagerWindow::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(const QUrl & )>(_a, &FileManagerWindow::currentUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::currentViewStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(const QList<QUrl> & )>(_a, &FileManagerWindow::selectUrlChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(int , int )>(_a, &FileManagerWindow::aboutToPlaySplitterAnimation, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(const QVariant & )>(_a, &FileManagerWindow::windowSplitterWidthChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqRefresh, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqActivateNextTab, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqActivatePreviousTab, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqSearchCtrlF, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqSearchCtrlL, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqBack, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqForward, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqCloseCurrentTab, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqCreateTab, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqCreateWindow, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(int )>(_a, &FileManagerWindow::reqTriggerActionByIndex, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)(int )>(_a, &FileManagerWindow::reqActivateTabByIndex, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::reqShowHotkeyHelp, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::titleBarInstallFinished, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::sideBarInstallFinished, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::workspaceInstallFinished, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileManagerWindow::*)()>(_a, &FileManagerWindow::detailViewInstallFinished, 24))
            return;
    }
}

const QMetaObject *dfmbase::FileManagerWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmbase::FileManagerWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7dfmbase17FileManagerWindowE_t>.strings))
        return static_cast<void*>(this);
    return DMainWindow::qt_metacast(_clname);
}

int dfmbase::FileManagerWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void dfmbase::FileManagerWindow::aboutToOpen()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dfmbase::FileManagerWindow::aboutToClose()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dfmbase::FileManagerWindow::positionChanged(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dfmbase::FileManagerWindow::currentUrlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dfmbase::FileManagerWindow::currentViewStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dfmbase::FileManagerWindow::selectUrlChanged(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dfmbase::FileManagerWindow::aboutToPlaySplitterAnimation(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void dfmbase::FileManagerWindow::windowSplitterWidthChanged(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dfmbase::FileManagerWindow::reqRefresh()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dfmbase::FileManagerWindow::reqActivateNextTab()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void dfmbase::FileManagerWindow::reqActivatePreviousTab()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void dfmbase::FileManagerWindow::reqSearchCtrlF()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dfmbase::FileManagerWindow::reqSearchCtrlL()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void dfmbase::FileManagerWindow::reqBack()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dfmbase::FileManagerWindow::reqForward()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void dfmbase::FileManagerWindow::reqCloseCurrentTab()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void dfmbase::FileManagerWindow::reqCreateTab()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void dfmbase::FileManagerWindow::reqCreateWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void dfmbase::FileManagerWindow::reqTriggerActionByIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void dfmbase::FileManagerWindow::reqActivateTabByIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void dfmbase::FileManagerWindow::reqShowHotkeyHelp()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void dfmbase::FileManagerWindow::titleBarInstallFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void dfmbase::FileManagerWindow::sideBarInstallFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void dfmbase::FileManagerWindow::workspaceInstallFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void dfmbase::FileManagerWindow::detailViewInstallFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}
QT_WARNING_POP
