/****************************************************************************
** Meta object code from reading C++ file 'textindexadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "textindexadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'textindexadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TextIndexAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto TextIndexAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16TextIndexAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TextIndexAdaptor",
        "D-Bus Interface",
        "org.deepin.Filemanager.TextIndex",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.Filemanager.TextIndex\">\n    <sign"
        "al name=\"TaskFinished\">\n      <arg direction=\"out\" type=\"s\""
        " name=\"type\"/>\n      <arg direction=\"out\" type=\"s\" name=\"p"
        "ath\"/>\n      <arg direction=\"out\" type=\"b\" name=\"success\"/"
        ">\n    </signal>\n    <signal name=\"TaskProgressChanged\">\n     "
        " <arg direction=\"out\" type=\"s\" name=\"type\"/>\n      <arg dir"
        "ection=\"out\" type=\"s\" name=\"path\"/>\n      <arg direction=\""
        "out\" type=\"x\" name=\"count\"/>\n    </signal>\n    <method name"
        "=\"CreateIndexTask\">\n      <arg direction=\"out\" type=\"b\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n    </meth"
        "od>\n    <method name=\"UpdateIndexTask\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "path\"/>\n    </method>\n    <method name=\"RemoveIndexTask\">\n  "
        "    <arg direction=\"out\" type=\"b\"/>\n      <arg direction=\"in"
        "\" type=\"as\" name=\"paths\"/>\n    </method>\n    <method name=\""
        "StopCurrentTask\">\n      <arg direction=\"out\" type=\"b\"/>\n   "
        " </method>\n    <method name=\"HasRunningTask\">\n      <arg direc"
        "tion=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"Index"
        "DatabaseExists\">\n      <arg direction=\"out\" type=\"b\"/>\n    "
        "</method>\n    <method name=\"GetLastUpdateTime\">\n      <arg dir"
        "ection=\"out\" type=\"s\"/>\n    </method>\n  </interface>\n",
        "TaskFinished",
        "",
        "type",
        "path",
        "success",
        "TaskProgressChanged",
        "count",
        "CreateIndexTask",
        "GetLastUpdateTime",
        "HasRunningTask",
        "IndexDatabaseExists",
        "RemoveIndexTask",
        "paths",
        "StopCurrentTask",
        "UpdateIndexTask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'TaskFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &, bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::Bool, 9 },
        }}),
        // Signal 'TaskProgressChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qlonglong)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::LongLong, 11 },
        }}),
        // Slot 'CreateIndexTask'
        QtMocHelpers::SlotData<bool(const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'GetLastUpdateTime'
        QtMocHelpers::SlotData<QString()>(13, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'HasRunningTask'
        QtMocHelpers::SlotData<bool()>(14, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'IndexDatabaseExists'
        QtMocHelpers::SlotData<bool()>(15, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'RemoveIndexTask'
        QtMocHelpers::SlotData<bool(const QStringList &)>(16, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QStringList, 17 },
        }}),
        // Slot 'StopCurrentTask'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'UpdateIndexTask'
        QtMocHelpers::SlotData<bool(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TextIndexAdaptor, qt_meta_tag_ZN16TextIndexAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TextIndexAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TextIndexAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TextIndexAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TextIndexAdaptorE_t>.metaTypes,
    nullptr
} };

void TextIndexAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TextIndexAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->TaskFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->TaskProgressChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[3]))); break;
        case 2: { bool _r = _t->CreateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { QString _r = _t->GetLastUpdateTime();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->HasRunningTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->IndexDatabaseExists();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->RemoveIndexTask((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->StopCurrentTask();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->UpdateIndexTask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TextIndexAdaptor::*)(const QString & , const QString & , bool )>(_a, &TextIndexAdaptor::TaskFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TextIndexAdaptor::*)(const QString & , const QString & , qlonglong )>(_a, &TextIndexAdaptor::TaskProgressChanged, 1))
            return;
    }
}

const QMetaObject *TextIndexAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TextIndexAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TextIndexAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int TextIndexAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void TextIndexAdaptor::TaskFinished(const QString & _t1, const QString & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TextIndexAdaptor::TaskProgressChanged(const QString & _t1, const QString & _t2, qlonglong _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
