/****************************************************************************
** Meta object code from reading C++ file 'vaulteventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-vault/events/vaulteventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vaulteventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_vault::VaultEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_vault::VaultEventReceiver",
        "computerOpenItem",
        "",
        "winId",
        "QUrl",
        "url",
        "handleNotAllowedAppendCompress",
        "QList<QUrl>",
        "fromUrls",
        "toUrl",
        "handleCurrentUrlChanged",
        "handleSideBarItemDragMoveData",
        "urls",
        "Qt::DropAction*",
        "action",
        "handleShortCutPasteFiles",
        "to",
        "changeUrlEventFilter",
        "windowId",
        "handlePathtoVirtual",
        "files",
        "QList<QUrl>*",
        "virtualFiles",
        "detailViewIcon",
        "QString*",
        "iconName",
        "fileDropHandleWithAction",
        "handlePermissionViewAsh",
        "bool*",
        "isAsh",
        "handleFileCanTaged",
        "canTag"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'computerOpenItem'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleNotAllowedAppendCompress'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 4, 9 },
        }}),
        // Slot 'handleCurrentUrlChanged'
        QtMocHelpers::SlotData<void(const quint64 &, const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleSideBarItemDragMoveData'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &, Qt::DropAction *)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 12 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'handleShortCutPasteFiles'
        QtMocHelpers::SlotData<bool(const quint64 &, const QList<QUrl> &, const QUrl &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 4, 16 },
        }}),
        // Slot 'changeUrlEventFilter'
        QtMocHelpers::SlotData<bool(quint64, const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 18 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handlePathtoVirtual'
        QtMocHelpers::SlotData<bool(const QList<QUrl>, QList<QUrl> *)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 20 }, { 0x80000000 | 21, 22 },
        }}),
        // Slot 'detailViewIcon'
        QtMocHelpers::SlotData<bool(const QUrl &, QString *)>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 24, 25 },
        }}),
        // Slot 'fileDropHandleWithAction'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QUrl &, Qt::DropAction *)>(26, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 4, 9 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'handlePermissionViewAsh'
        QtMocHelpers::SlotData<bool(const QUrl &, bool *)>(27, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'handleFileCanTaged'
        QtMocHelpers::SlotData<bool(const QUrl &, bool *)>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 28, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VaultEventReceiver, qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_vault::VaultEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_vault::VaultEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VaultEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->computerOpenItem((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 1: { bool _r = _t->handleNotAllowedAppendCompress((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->handleCurrentUrlChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 3: { bool _r = _t->handleSideBarItemDragMoveData((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::DropAction*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->handleShortCutPasteFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->changeUrlEventFilter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->handlePathtoVirtual((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->detailViewIcon((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->fileDropHandleWithAction((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Qt::DropAction*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->handlePermissionViewAsh((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->handleFileCanTaged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_vault::VaultEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_vault::VaultEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15dfmplugin_vault18VaultEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_vault::VaultEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
