/****************************************************************************
** Meta object code from reading C++ file 'recentmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/daemon/recent/recentmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recentmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto serverplugin_recentmanager::RecentManager::qt_create_metaobjectdata<qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "serverplugin_recentmanager::RecentManager",
        "requestReload",
        "",
        "xbelPath",
        "timestamp",
        "requestAddRecentItem",
        "QVariantMap",
        "items",
        "requestRemoveItems",
        "paths",
        "requestPurgeItems",
        "reloadFinished",
        "purgeFinished",
        "itemAdded",
        "path",
        "href",
        "modified",
        "itemsRemoved",
        "itemChanged",
        "initialize",
        "finalize",
        "startWatch",
        "stopWatch",
        "reload",
        "doReload",
        "onItemAdded",
        "RecentItem",
        "item",
        "onItemsRemoved",
        "onItemChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestReload'
        QtMocHelpers::SignalData<void(const QString &, qint64)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::LongLong, 4 },
        }}),
        // Signal 'requestAddRecentItem'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'requestRemoveItems'
        QtMocHelpers::SignalData<void(const QStringList &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Signal 'requestPurgeItems'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'reloadFinished'
        QtMocHelpers::SignalData<void(qint64)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Signal 'purgeFinished'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &, qint64)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::LongLong, 16 },
        }}),
        // Signal 'itemsRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void(const QString &, qint64)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::LongLong, 16 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finalize'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startWatch'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopWatch'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doReload'
        QtMocHelpers::SlotData<void(qint64)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 4 },
        }}),
        // Slot 'doReload'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'onItemAdded'
        QtMocHelpers::SlotData<void(const QString &, const RecentItem &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'onItemsRemoved'
        QtMocHelpers::SlotData<void(const QStringList &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Slot 'onItemChanged'
        QtMocHelpers::SlotData<void(const QString &, const RecentItem &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RecentManager, qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject serverplugin_recentmanager::RecentManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>.metaTypes,
    nullptr
} };

void serverplugin_recentmanager::RecentManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RecentManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestReload((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 1: _t->requestAddRecentItem((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->requestRemoveItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 3: _t->requestPurgeItems((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->reloadFinished((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 5: _t->purgeFinished(); break;
        case 6: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 7: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 8: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 9: _t->initialize(); break;
        case 10: _t->finalize(); break;
        case 11: _t->startWatch(); break;
        case 12: _t->stopWatch(); break;
        case 13: _t->reload(); break;
        case 14: _t->doReload((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 15: _t->doReload(); break;
        case 16: _t->onItemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RecentItem>>(_a[2]))); break;
        case 17: _t->onItemsRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 18: _t->onItemChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RecentItem>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QString & , qint64 )>(_a, &RecentManager::requestReload, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QVariantMap & )>(_a, &RecentManager::requestAddRecentItem, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QStringList & )>(_a, &RecentManager::requestRemoveItems, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QString & )>(_a, &RecentManager::requestPurgeItems, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(qint64 )>(_a, &RecentManager::reloadFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)()>(_a, &RecentManager::purgeFinished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QString & , const QString & , qint64 )>(_a, &RecentManager::itemAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QStringList & )>(_a, &RecentManager::itemsRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (RecentManager::*)(const QString & , qint64 )>(_a, &RecentManager::itemChanged, 8))
            return;
    }
}

const QMetaObject *serverplugin_recentmanager::RecentManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *serverplugin_recentmanager::RecentManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26serverplugin_recentmanager13RecentManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int serverplugin_recentmanager::RecentManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void serverplugin_recentmanager::RecentManager::requestReload(const QString & _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void serverplugin_recentmanager::RecentManager::requestAddRecentItem(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void serverplugin_recentmanager::RecentManager::requestRemoveItems(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void serverplugin_recentmanager::RecentManager::requestPurgeItems(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void serverplugin_recentmanager::RecentManager::reloadFinished(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void serverplugin_recentmanager::RecentManager::purgeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void serverplugin_recentmanager::RecentManager::itemAdded(const QString & _t1, const QString & _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void serverplugin_recentmanager::RecentManager::itemsRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void serverplugin_recentmanager::RecentManager::itemChanged(const QString & _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}
QT_WARNING_POP
