/****************************************************************************
** Meta object code from reading C++ file 'burncheckstrategy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-burn/utils/burncheckstrategy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'burncheckstrategy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::BurnCheckStrategy::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::BurnCheckStrategy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BurnCheckStrategy, qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::BurnCheckStrategy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::BurnCheckStrategy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BurnCheckStrategy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::BurnCheckStrategy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::BurnCheckStrategy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn17BurnCheckStrategyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_burn::BurnCheckStrategy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::ISO9660CheckStrategy::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::ISO9660CheckStrategy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ISO9660CheckStrategy, qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::ISO9660CheckStrategy::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnCheckStrategy::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::ISO9660CheckStrategy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ISO9660CheckStrategy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::ISO9660CheckStrategy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::ISO9660CheckStrategy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn20ISO9660CheckStrategyE_t>.strings))
        return static_cast<void*>(this);
    return BurnCheckStrategy::qt_metacast(_clname);
}

int dfmplugin_burn::ISO9660CheckStrategy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnCheckStrategy::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::JolietCheckStrategy::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::JolietCheckStrategy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<JolietCheckStrategy, qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::JolietCheckStrategy::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnCheckStrategy::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::JolietCheckStrategy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JolietCheckStrategy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::JolietCheckStrategy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::JolietCheckStrategy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn19JolietCheckStrategyE_t>.strings))
        return static_cast<void*>(this);
    return BurnCheckStrategy::qt_metacast(_clname);
}

int dfmplugin_burn::JolietCheckStrategy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnCheckStrategy::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::RockRidgeCheckStrategy::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::RockRidgeCheckStrategy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RockRidgeCheckStrategy, qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::RockRidgeCheckStrategy::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnCheckStrategy::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::RockRidgeCheckStrategy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RockRidgeCheckStrategy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::RockRidgeCheckStrategy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::RockRidgeCheckStrategy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn22RockRidgeCheckStrategyE_t>.strings))
        return static_cast<void*>(this);
    return BurnCheckStrategy::qt_metacast(_clname);
}

int dfmplugin_burn::RockRidgeCheckStrategy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnCheckStrategy::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_burn::UDFCheckStrategy::qt_create_metaobjectdata<qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_burn::UDFCheckStrategy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UDFCheckStrategy, qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_burn::UDFCheckStrategy::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnCheckStrategy::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>.metaTypes,
    nullptr
} };

void dfmplugin_burn::UDFCheckStrategy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UDFCheckStrategy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dfmplugin_burn::UDFCheckStrategy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_burn::UDFCheckStrategy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14dfmplugin_burn16UDFCheckStrategyE_t>.strings))
        return static_cast<void*>(this);
    return BurnCheckStrategy::qt_metacast(_clname);
}

int dfmplugin_burn::UDFCheckStrategy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnCheckStrategy::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
