/****************************************************************************
** Meta object code from reading C++ file 'filedialoghandledbus.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filedialog/core/dbus/filedialoghandledbus.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialoghandledbus.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20FileDialogHandleDBusE_t {};
} // unnamed namespace

template <> constexpr inline auto FileDialogHandleDBus::qt_create_metaobjectdata<qt_meta_tag_ZN20FileDialogHandleDBusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileDialogHandleDBus",
        "windowActiveChanged",
        "",
        "directoryChanged",
        "directoryUrlChanged",
        "directory",
        "setDirectoryUrl",
        "directoryUrl",
        "selectUrl",
        "url",
        "selectedUrls",
        "filter",
        "setFilter",
        "filters",
        "setViewMode",
        "mode",
        "viewMode",
        "setFileMode",
        "setAcceptMode",
        "acceptMode",
        "setLabelText",
        "label",
        "text",
        "labelText",
        "setOptions",
        "options",
        "setOption",
        "option",
        "on",
        "testOption",
        "winId",
        "setWindowTitle",
        "title",
        "windowActive",
        "activateWindow",
        "heartbeatInterval",
        "makeHeartbeat",
        "windowFlags",
        "setHeartbeatInterval",
        "interval",
        "setWindowFlags",
        "nameFilters",
        "hideOnAccept"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowActiveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryUrlChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'directory'
        QtMocHelpers::SlotData<QString() const>(5, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDirectoryUrl'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'directoryUrl'
        QtMocHelpers::SlotData<QString() const>(7, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'selectUrl'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'selectedUrls'
        QtMocHelpers::SlotData<QStringList() const>(10, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'filter'
        QtMocHelpers::SlotData<int() const>(11, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setFilter'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'setViewMode'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'viewMode'
        QtMocHelpers::SlotData<int() const>(16, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setFileMode'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setAcceptMode'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'acceptMode'
        QtMocHelpers::SlotData<int() const>(19, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'setLabelText'
        QtMocHelpers::SlotData<void(int, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'labelText'
        QtMocHelpers::SlotData<QString(int) const>(23, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'setOptions'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(int, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'options'
        QtMocHelpers::SlotData<int() const>(25, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'testOption'
        QtMocHelpers::SlotData<bool(int) const>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'winId'
        QtMocHelpers::SlotData<qulonglong() const>(30, 2, QMC::AccessPublic, QMetaType::ULongLong),
        // Slot 'setWindowTitle'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 },
        }}),
        // Slot 'windowActive'
        QtMocHelpers::SlotData<bool() const>(33, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'activateWindow'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'heartbeatInterval'
        QtMocHelpers::SlotData<int() const>(35, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'makeHeartbeat'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'windowFlags'
        QtMocHelpers::SlotData<quint32() const>(37, 2, QMC::AccessPublic, QMetaType::UInt),
        // Slot 'setHeartbeatInterval'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setWindowFlags'
        QtMocHelpers::SlotData<void(quint32)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'directory'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'directoryUrl'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'nameFilters'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'filter'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'viewMode'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'acceptMode'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'windowActive'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'heartbeatInterval'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'windowFlags'
        QtMocHelpers::PropertyData<quint32>(37, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hideOnAccept'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FileDialogHandleDBus, qt_meta_tag_ZN20FileDialogHandleDBusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FileDialogHandleDBus::staticMetaObject = { {
    QMetaObject::SuperData::link<FileDialogHandle::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20FileDialogHandleDBusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20FileDialogHandleDBusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20FileDialogHandleDBusE_t>.metaTypes,
    nullptr
} };

void FileDialogHandleDBus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileDialogHandleDBus *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowActiveChanged(); break;
        case 1: _t->directoryChanged(); break;
        case 2: _t->directoryUrlChanged(); break;
        case 3: { QString _r = _t->directory();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->setDirectoryUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { QString _r = _t->directoryUrl();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->selectUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: { QStringList _r = _t->selectedUrls();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { int _r = _t->filter();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->setFilter((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setViewMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: { int _r = _t->viewMode();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setFileMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->setAcceptMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: { int _r = _t->acceptMode();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->setLabelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: { QString _r = _t->labelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->setOptions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->setOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: { int _r = _t->options();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->testOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { qulonglong _r = _t->winId();
            if (_a[0]) *reinterpret_cast<qulonglong*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->setWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: { bool _r = _t->windowActive();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->activateWindow(); break;
        case 26: { int _r = _t->heartbeatInterval();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->makeHeartbeat(); break;
        case 28: { quint32 _r = _t->windowFlags();
            if (_a[0]) *reinterpret_cast<quint32*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->setHeartbeatInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setWindowFlags((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandleDBus::*)()>(_a, &FileDialogHandleDBus::windowActiveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandleDBus::*)()>(_a, &FileDialogHandleDBus::directoryChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileDialogHandleDBus::*)()>(_a, &FileDialogHandleDBus::directoryUrlChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->directory(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->directoryUrl(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->nameFilters(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->filter(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->viewMode(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->acceptMode(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->windowActive(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->heartbeatInterval(); break;
        case 8: *reinterpret_cast<quint32*>(_v) = _t->windowFlags(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->hideOnAccept(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setDirectoryUrl(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setNameFilters(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setFilter(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setViewMode(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setAcceptMode(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setHeartbeatInterval(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setWindowFlags(*reinterpret_cast<quint32*>(_v)); break;
        case 9: _t->setHideOnAccept(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FileDialogHandleDBus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileDialogHandleDBus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20FileDialogHandleDBusE_t>.strings))
        return static_cast<void*>(this);
    return FileDialogHandle::qt_metacast(_clname);
}

int FileDialogHandleDBus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FileDialogHandle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void FileDialogHandleDBus::windowActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FileDialogHandleDBus::directoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void FileDialogHandleDBus::directoryUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
