/****************************************************************************
** Meta object code from reading C++ file 'wallpaperitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/desktop/ddplugin-wallpapersetting/wallpaperitem.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QQueue>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wallpaperitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_wallpapersetting::WrapperWidget::qt_create_metaobjectdata<qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_wallpapersetting::WrapperWidget"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WrapperWidget, qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_wallpapersetting::WrapperWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>.metaTypes,
    nullptr
} };

void ddplugin_wallpapersetting::WrapperWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WrapperWidget *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ddplugin_wallpapersetting::WrapperWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_wallpapersetting::WrapperWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WrapperWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ddplugin_wallpapersetting::WrapperWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t {};
} // unnamed namespace

template <> constexpr inline auto ddplugin_wallpapersetting::WallpaperItem::qt_create_metaobjectdata<qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ddplugin_wallpapersetting::WallpaperItem",
        "pressed",
        "",
        "WallpaperItem*",
        "self",
        "hoverIn",
        "hoverOut",
        "tab",
        "backtab",
        "buttonClicked",
        "id",
        "onButtonClicked",
        "onThumbnailFounded",
        "key",
        "QPixmap",
        "pixmap",
        "onFindAborted",
        "QQueue<QString>",
        "list"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(WallpaperItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hoverIn'
        QtMocHelpers::SignalData<void(WallpaperItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'hoverOut'
        QtMocHelpers::SignalData<void(WallpaperItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'tab'
        QtMocHelpers::SignalData<void(WallpaperItem *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'backtab'
        QtMocHelpers::SignalData<void(WallpaperItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'buttonClicked'
        QtMocHelpers::SignalData<void(WallpaperItem *, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'onButtonClicked'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onThumbnailFounded'
        QtMocHelpers::SlotData<void(const QString &, QPixmap)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onFindAborted'
        QtMocHelpers::SlotData<void(const QQueue<QString> &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperItem, qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ddplugin_wallpapersetting::WallpaperItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>.metaTypes,
    nullptr
} };

void ddplugin_wallpapersetting::WallpaperItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pressed((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1]))); break;
        case 1: _t->hoverIn((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1]))); break;
        case 2: _t->hoverOut((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1]))); break;
        case 3: _t->tab((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1]))); break;
        case 4: _t->backtab((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1]))); break;
        case 5: _t->buttonClicked((*reinterpret_cast<std::add_pointer_t<WallpaperItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->onButtonClicked(); break;
        case 7: _t->onThumbnailFounded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 8: _t->onFindAborted((*reinterpret_cast<std::add_pointer_t<QQueue<QString>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< WallpaperItem* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQueue<QString> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * )>(_a, &WallpaperItem::pressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * )>(_a, &WallpaperItem::hoverIn, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * )>(_a, &WallpaperItem::hoverOut, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * )>(_a, &WallpaperItem::tab, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * )>(_a, &WallpaperItem::backtab, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WallpaperItem::*)(WallpaperItem * , const QString & )>(_a, &WallpaperItem::buttonClicked, 5))
            return;
    }
}

const QMetaObject *ddplugin_wallpapersetting::WallpaperItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ddplugin_wallpapersetting::WallpaperItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ddplugin_wallpapersetting13WallpaperItemE_t>.strings))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int ddplugin_wallpapersetting::WallpaperItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ddplugin_wallpapersetting::WallpaperItem::pressed(WallpaperItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ddplugin_wallpapersetting::WallpaperItem::hoverIn(WallpaperItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ddplugin_wallpapersetting::WallpaperItem::hoverOut(WallpaperItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ddplugin_wallpapersetting::WallpaperItem::tab(WallpaperItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ddplugin_wallpapersetting::WallpaperItem::backtab(WallpaperItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ddplugin_wallpapersetting::WallpaperItem::buttonClicked(WallpaperItem * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
