/****************************************************************************
** Meta object code from reading C++ file 'trashfileeventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-fileoperations/fileoperationsevent/trashfileeventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trashfileeventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_fileoperations::TrashFileEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_fileoperations::TrashFileEventReceiver",
        "cleanTrashUrls",
        "",
        "windowId",
        "QList<QUrl>",
        "sources",
        "dfmbase::AbstractJobHandler::DeleteDialogNoticeType",
        "deleteNoticeType",
        "dfmbase::AbstractJobHandler::OperatorHandleCallback",
        "handleCallback",
        "handleOperationMoveToTrash",
        "dfmbase::AbstractJobHandler::JobFlag",
        "flags",
        "handle",
        "QVariant",
        "custom",
        "dfmbase::AbstractJobHandler::OperatorCallback",
        "callback",
        "handleOperationRestoreFromTrash",
        "QUrl",
        "target",
        "handleOperationCleanTrash",
        "handleOperationCopyFromTrash",
        "handleSaveRedoOpt",
        "token",
        "moreThanZero",
        "handleOperationUndoMoveToTrash",
        "QVariantMap",
        "op",
        "handleOperationUndoRestoreFromTrash",
        "onCleanTrashUrls",
        "JobHandlePointer"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cleanTrashUrls'
        QtMocHelpers::SignalData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::DeleteDialogNoticeType, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleOperationMoveToTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 13 },
        }}),
        // Slot 'handleOperationMoveToTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 13 },
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleOperationRestoreFromTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 8, 13 },
        }}),
        // Slot 'handleOperationRestoreFromTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const QUrl, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 8, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleOperationCleanTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, const dfmbase::AbstractJobHandler::DeleteDialogNoticeType, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 13 },
        }}),
        // Slot 'handleOperationCleanTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl>, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 8, 13 }, { 0x80000000 | 14, 15 },
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleOperationCopyFromTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const QUrl &, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 8, 13 },
        }}),
        // Slot 'handleOperationCopyFromTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const QUrl &, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariant, dfmbase::AbstractJobHandler::OperatorCallback)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 8, 13 }, { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleSaveRedoOpt'
        QtMocHelpers::SlotData<void(const QString &, const bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'handleOperationUndoMoveToTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariantMap &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 8, 9 },
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'handleOperationUndoRestoreFromTrash'
        QtMocHelpers::SlotData<void(const quint64, const QList<QUrl> &, const QUrl &, const dfmbase::AbstractJobHandler::JobFlag, dfmbase::AbstractJobHandler::OperatorHandleCallback, const QVariantMap &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 19, 20 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 8, 9 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'onCleanTrashUrls'
        QtMocHelpers::SlotData<JobHandlePointer(const quint64, const QList<QUrl> &, const dfmbase::AbstractJobHandler::DeleteDialogNoticeType, dfmbase::AbstractJobHandler::OperatorHandleCallback)>(30, 2, QMC::AccessPrivate, 0x80000000 | 31, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TrashFileEventReceiver, qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_fileoperations::TrashFileEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_fileoperations::TrashFileEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrashFileEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cleanTrashUrls((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::DeleteDialogNoticeType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4]))); break;
        case 1: _t->handleOperationMoveToTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4]))); break;
        case 2: _t->handleOperationMoveToTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[6]))); break;
        case 3: _t->handleOperationRestoreFromTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5]))); break;
        case 4: _t->handleOperationRestoreFromTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[7]))); break;
        case 5: _t->handleOperationCleanTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::DeleteDialogNoticeType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4]))); break;
        case 6: _t->handleOperationCleanTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[5]))); break;
        case 7: _t->handleOperationCopyFromTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5]))); break;
        case 8: _t->handleOperationCopyFromTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorCallback>>(_a[7]))); break;
        case 9: _t->handleSaveRedoOpt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->handleOperationUndoMoveToTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5]))); break;
        case 11: _t->handleOperationUndoRestoreFromTrash((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::JobFlag>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[6]))); break;
        case 12: { JobHandlePointer _r = _t->onCleanTrashUrls((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::DeleteDialogNoticeType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<dfmbase::AbstractJobHandler::OperatorHandleCallback>>(_a[4])));
            if (_a[0]) *reinterpret_cast<JobHandlePointer*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 6:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorCallback >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::JobFlag >(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::AbstractJobHandler::OperatorHandleCallback >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrashFileEventReceiver::*)(const quint64 , const QList<QUrl> , const dfmbase::AbstractJobHandler::DeleteDialogNoticeType , dfmbase::AbstractJobHandler::OperatorHandleCallback )>(_a, &TrashFileEventReceiver::cleanTrashUrls, 0))
            return;
    }
}

const QMetaObject *dfmplugin_fileoperations::TrashFileEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_fileoperations::TrashFileEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24dfmplugin_fileoperations22TrashFileEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_fileoperations::TrashFileEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_fileoperations::TrashFileEventReceiver::cleanTrashUrls(const quint64 _t1, const QList<QUrl> _t2, const dfmbase::AbstractJobHandler::DeleteDialogNoticeType _t3, dfmbase::AbstractJobHandler::OperatorHandleCallback _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
