/****************************************************************************
** Meta object code from reading C++ file 'pagerenderthread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../../dde-file-manager/src/apps/dde-file-manager-preview/pluginpreviews/pdf-preview/pagerenderthread.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pagerenderthread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto plugin_filepreview::PageRenderThread::qt_create_metaobjectdata<qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "plugin_filepreview::PageRenderThread",
        "sigDocPageNormalImageTaskFinished",
        "",
        "DocPageNormalImageTask",
        "QPixmap",
        "sigDocPageThumbnailTaskFinished",
        "DocPageThumbnailTask",
        "sigDocOpenTask",
        "DocOpenTask",
        "Document::Error",
        "Document*",
        "QList<Page*>",
        "onDocPageNormalImageTaskFinished",
        "task",
        "pixmap",
        "onDocPageThumbnailTask",
        "onDocOpenTask",
        "error",
        "document",
        "pages"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigDocPageNormalImageTaskFinished'
        QtMocHelpers::SignalData<void(DocPageNormalImageTask, QPixmap)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigDocPageThumbnailTaskFinished'
        QtMocHelpers::SignalData<void(DocPageThumbnailTask, QPixmap)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'sigDocOpenTask'
        QtMocHelpers::SignalData<void(DocOpenTask, Document::Error, Document *, QList<Page*>)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 9, 2 }, { 0x80000000 | 10, 2 }, { 0x80000000 | 11, 2 },
        }}),
        // Slot 'onDocPageNormalImageTaskFinished'
        QtMocHelpers::SlotData<void(DocPageNormalImageTask, QPixmap)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 13 }, { 0x80000000 | 4, 14 },
        }}),
        // Slot 'onDocPageThumbnailTask'
        QtMocHelpers::SlotData<void(DocPageThumbnailTask, QPixmap)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 13 }, { 0x80000000 | 4, 14 },
        }}),
        // Slot 'onDocOpenTask'
        QtMocHelpers::SlotData<void(DocOpenTask, Document::Error, Document *, QList<Page*>)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 13 }, { 0x80000000 | 9, 17 }, { 0x80000000 | 10, 18 }, { 0x80000000 | 11, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PageRenderThread, qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject plugin_filepreview::PageRenderThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>.metaTypes,
    nullptr
} };

void plugin_filepreview::PageRenderThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PageRenderThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigDocPageNormalImageTaskFinished((*reinterpret_cast<std::add_pointer_t<DocPageNormalImageTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 1: _t->sigDocPageThumbnailTaskFinished((*reinterpret_cast<std::add_pointer_t<DocPageThumbnailTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 2: _t->sigDocOpenTask((*reinterpret_cast<std::add_pointer_t<DocOpenTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Document::Error>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Document*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<Page*>>>(_a[4]))); break;
        case 3: _t->onDocPageNormalImageTaskFinished((*reinterpret_cast<std::add_pointer_t<DocPageNormalImageTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 4: _t->onDocPageThumbnailTask((*reinterpret_cast<std::add_pointer_t<DocPageThumbnailTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 5: _t->onDocOpenTask((*reinterpret_cast<std::add_pointer_t<DocOpenTask>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Document::Error>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Document*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QList<Page*>>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Document* >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Page*> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Document* >(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<Page*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PageRenderThread::*)(DocPageNormalImageTask , QPixmap )>(_a, &PageRenderThread::sigDocPageNormalImageTaskFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageRenderThread::*)(DocPageThumbnailTask , QPixmap )>(_a, &PageRenderThread::sigDocPageThumbnailTaskFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PageRenderThread::*)(DocOpenTask , Document::Error , Document * , QList<Page*> )>(_a, &PageRenderThread::sigDocOpenTask, 2))
            return;
    }
}

const QMetaObject *plugin_filepreview::PageRenderThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *plugin_filepreview::PageRenderThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18plugin_filepreview16PageRenderThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int plugin_filepreview::PageRenderThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void plugin_filepreview::PageRenderThread::sigDocPageNormalImageTaskFinished(DocPageNormalImageTask _t1, QPixmap _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void plugin_filepreview::PageRenderThread::sigDocPageThumbnailTaskFinished(DocPageThumbnailTask _t1, QPixmap _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void plugin_filepreview::PageRenderThread::sigDocOpenTask(DocOpenTask _t1, Document::Error _t2, Document * _t3, QList<Page*> _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
