/****************************************************************************
** Meta object code from reading C++ file 'workspaceeventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-workspace/events/workspaceeventreceiver.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'workspaceeventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_workspace::WorkspaceEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_workspace::WorkspaceEventReceiver",
        "handleTileBarSwitchModeTriggered",
        "",
        "windowId",
        "mode",
        "handleShowCustomTopWidget",
        "scheme",
        "visible",
        "handleSelectFiles",
        "QList<QUrl>",
        "files",
        "handleSelectAll",
        "handleReverseSelect",
        "handleSetSort",
        "dfmbase::Global::ItemRoles",
        "role",
        "handleNotSupportTreeView",
        "handleSetSelectionMode",
        "QAbstractItemView::SelectionMode",
        "handleSetEnabledSelectionModes",
        "QList<QAbstractItemView::SelectionMode>",
        "modes",
        "handleSetViewDragEnabled",
        "enabled",
        "handleSetViewDragDropMode",
        "QAbstractItemView::DragDropMode",
        "handleClosePersistentEditor",
        "handleGetViewFilter",
        "handleGetNameFilter",
        "handleSetViewFilter",
        "QDir::Filters",
        "filters",
        "handleSetNameFilter",
        "handleSetReadOnly",
        "readOnly",
        "handlePasteFileResult",
        "srcUrls",
        "destUrls",
        "ok",
        "errMsg",
        "handleMoveToTrashFileResult",
        "handleRenameFileResult",
        "QMap<QUrl,QUrl>",
        "renamedUrls",
        "handleFileUpdate",
        "QUrl",
        "url",
        "handleCurrentSortRole",
        "handleColumnRoles",
        "QList<dfmbase::Global::ItemRoles>",
        "handleGetVisualGeometry",
        "QRectF",
        "windowID",
        "handleGetViewItemRect",
        "handleSetDefaultViewMode",
        "dfmbase::Global::ViewMode",
        "handleGetDefaultViewMode",
        "handleGetCurrentViewMode",
        "handleRegisterFileView",
        "handleRegisterMenuScene",
        "scene",
        "handleFindMenuScene",
        "handleRegisterCustomTopWidget",
        "QVariantMap",
        "dataMap",
        "handleGetCustomTopWidgetVisible",
        "handleCheckSchemeViewIsFileView",
        "handleGetSelectedUrls",
        "handleSetCustomFilterData",
        "QVariant",
        "data",
        "handleSetCustomFilterCallback",
        "callback",
        "handleRegisterRoutePrehandle",
        "FileViewRoutePrehaldler",
        "prehandler",
        "handleRegisterDataCache",
        "handleSetAlwaysOpenInCurrentWindow",
        "handleAboutToChangeViewWidth",
        "deltaWidth",
        "handleCheckMountedDevPath",
        "handleTabCreated",
        "uniqueId",
        "handleTabRemoved",
        "removedId",
        "nextId",
        "handleTabChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleTileBarSwitchModeTriggered'
        QtMocHelpers::SlotData<void(quint64, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'handleShowCustomTopWidget'
        QtMocHelpers::SlotData<void(quint64, const QString &, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'handleSelectFiles'
        QtMocHelpers::SlotData<void(quint64, const QList<QUrl> &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'handleSelectAll'
        QtMocHelpers::SlotData<void(quint64)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleReverseSelect'
        QtMocHelpers::SlotData<void(quint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleSetSort'
        QtMocHelpers::SlotData<void(quint64, dfmbase::Global::ItemRoles)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleNotSupportTreeView'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleSetSelectionMode'
        QtMocHelpers::SlotData<void(const quint64, const QAbstractItemView::SelectionMode)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 18, 4 },
        }}),
        // Slot 'handleSetEnabledSelectionModes'
        QtMocHelpers::SlotData<void(const quint64, const QList<QAbstractItemView::SelectionMode> &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'handleSetViewDragEnabled'
        QtMocHelpers::SlotData<void(const quint64, const bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'handleSetViewDragDropMode'
        QtMocHelpers::SlotData<void(const quint64, const QAbstractItemView::DragDropMode)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 25, 4 },
        }}),
        // Slot 'handleClosePersistentEditor'
        QtMocHelpers::SlotData<void(const quint64)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleGetViewFilter'
        QtMocHelpers::SlotData<int(const quint64)>(27, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleGetNameFilter'
        QtMocHelpers::SlotData<QStringList(const quint64)>(28, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleSetViewFilter'
        QtMocHelpers::SlotData<void(const quint64, const QDir::Filters &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'handleSetNameFilter'
        QtMocHelpers::SlotData<void(const quint64, const QStringList &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QStringList, 31 },
        }}),
        // Slot 'handleSetReadOnly'
        QtMocHelpers::SlotData<void(const quint64, const bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'handlePasteFileResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QList<QUrl> &, bool, const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 36 }, { 0x80000000 | 9, 37 }, { QMetaType::Bool, 38 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'handleMoveToTrashFileResult'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, bool, const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 36 }, { QMetaType::Bool, 38 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'handleRenameFileResult'
        QtMocHelpers::SlotData<void(const quint64, const QMap<QUrl,QUrl> &, bool, const QString &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { 0x80000000 | 42, 43 }, { QMetaType::Bool, 38 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'handleFileUpdate'
        QtMocHelpers::SlotData<void(const QUrl &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'handleCurrentSortRole'
        QtMocHelpers::SlotData<dfmbase::Global::ItemRoles(quint64)>(47, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleColumnRoles'
        QtMocHelpers::SlotData<QList<dfmbase::Global::ItemRoles>(quint64)>(48, 2, QMC::AccessPublic, 0x80000000 | 49, {{
            { QMetaType::ULongLong, 3 },
        }}),
        // Slot 'handleGetVisualGeometry'
        QtMocHelpers::SlotData<QRectF(const quint64)>(50, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::ULongLong, 52 },
        }}),
        // Slot 'handleGetViewItemRect'
        QtMocHelpers::SlotData<QRectF(const quint64, const QUrl &, const dfmbase::Global::ItemRoles)>(53, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::ULongLong, 52 }, { 0x80000000 | 45, 46 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleSetDefaultViewMode'
        QtMocHelpers::SlotData<void(const QString &, const dfmbase::Global::ViewMode)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 55, 4 },
        }}),
        // Slot 'handleGetDefaultViewMode'
        QtMocHelpers::SlotData<dfmbase::Global::ViewMode(const QString &)>(56, 2, QMC::AccessPublic, 0x80000000 | 55, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleGetCurrentViewMode'
        QtMocHelpers::SlotData<dfmbase::Global::ViewMode(const quint64)>(57, 2, QMC::AccessPublic, 0x80000000 | 55, {{
            { QMetaType::ULongLong, 52 },
        }}),
        // Slot 'handleRegisterFileView'
        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleRegisterMenuScene'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 60 },
        }}),
        // Slot 'handleFindMenuScene'
        QtMocHelpers::SlotData<QString(const QString &)>(61, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleRegisterCustomTopWidget'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'handleGetCustomTopWidgetVisible'
        QtMocHelpers::SlotData<bool(const quint64, const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 52 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'handleCheckSchemeViewIsFileView'
        QtMocHelpers::SlotData<bool(const QString &)>(66, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleGetSelectedUrls'
        QtMocHelpers::SlotData<QList<QUrl>(const quint64)>(67, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::ULongLong, 52 },
        }}),
        // Slot 'handleSetCustomFilterData'
        QtMocHelpers::SlotData<void(quint64, const QUrl &, const QVariant &)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 52 }, { 0x80000000 | 45, 46 }, { 0x80000000 | 69, 70 },
        }}),
        // Slot 'handleSetCustomFilterCallback'
        QtMocHelpers::SlotData<void(quint64, const QUrl &, const QVariant)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 52 }, { 0x80000000 | 45, 46 }, { 0x80000000 | 69, 72 },
        }}),
        // Slot 'handleRegisterRoutePrehandle'
        QtMocHelpers::SlotData<bool(const QString &, const FileViewRoutePrehaldler &)>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 74, 75 },
        }}),
        // Slot 'handleRegisterDataCache'
        QtMocHelpers::SlotData<void(const QString &)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'handleSetAlwaysOpenInCurrentWindow'
        QtMocHelpers::SlotData<void(const quint64)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 52 },
        }}),
        // Slot 'handleAboutToChangeViewWidth'
        QtMocHelpers::SlotData<void(const quint64, int)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 52 }, { QMetaType::Int, 79 },
        }}),
        // Slot 'handleCheckMountedDevPath'
        QtMocHelpers::SlotData<bool(const QUrl &)>(80, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'handleTabCreated'
        QtMocHelpers::SlotData<void(const quint64, const QString &)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 82 },
        }}),
        // Slot 'handleTabRemoved'
        QtMocHelpers::SlotData<void(const quint64, const QString &, const QString &)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 84 }, { QMetaType::QString, 85 },
        }}),
        // Slot 'handleTabChanged'
        QtMocHelpers::SlotData<void(const quint64, const QString &)>(86, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 3 }, { QMetaType::QString, 82 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WorkspaceEventReceiver, qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_workspace::WorkspaceEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_workspace::WorkspaceEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkspaceEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->handleTileBarSwitchModeTriggered((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->handleShowCustomTopWidget((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->handleSelectFiles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2]))); break;
        case 3: _t->handleSelectAll((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 4: _t->handleReverseSelect((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 5: _t->handleSetSort((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ItemRoles>>(_a[2]))); break;
        case 6: _t->handleNotSupportTreeView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->handleSetSelectionMode((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemView::SelectionMode>>(_a[2]))); break;
        case 8: _t->handleSetEnabledSelectionModes((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QAbstractItemView::SelectionMode>>>(_a[2]))); break;
        case 9: _t->handleSetViewDragEnabled((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 10: _t->handleSetViewDragDropMode((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemView::DragDropMode>>(_a[2]))); break;
        case 11: _t->handleClosePersistentEditor((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 12: { int _r = _t->handleGetViewFilter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { QStringList _r = _t->handleGetNameFilter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->handleSetViewFilter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDir::Filters>>(_a[2]))); break;
        case 15: _t->handleSetNameFilter((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 16: _t->handleSetReadOnly((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 17: _t->handlePasteFileResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 18: _t->handleMoveToTrashFileResult((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 19: _t->handleRenameFileResult((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QUrl,QUrl>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 20: _t->handleFileUpdate((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 21: { dfmbase::Global::ItemRoles _r = _t->handleCurrentSortRole((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<dfmbase::Global::ItemRoles*>(_a[0]) = std::move(_r); }  break;
        case 22: { QList<dfmbase::Global::ItemRoles> _r = _t->handleColumnRoles((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<dfmbase::Global::ItemRoles>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QRectF _r = _t->handleGetVisualGeometry((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 24: { QRectF _r = _t->handleGetViewItemRect((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ItemRoles>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QRectF*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->handleSetDefaultViewMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<dfmbase::Global::ViewMode>>(_a[2]))); break;
        case 26: { dfmbase::Global::ViewMode _r = _t->handleGetDefaultViewMode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<dfmbase::Global::ViewMode*>(_a[0]) = std::move(_r); }  break;
        case 27: { dfmbase::Global::ViewMode _r = _t->handleGetCurrentViewMode((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<dfmbase::Global::ViewMode*>(_a[0]) = std::move(_r); }  break;
        case 28: _t->handleRegisterFileView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->handleRegisterMenuScene((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 30: { QString _r = _t->handleFindMenuScene((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->handleRegisterCustomTopWidget((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 32: { bool _r = _t->handleGetCustomTopWidgetVisible((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { bool _r = _t->handleCheckSchemeViewIsFileView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { QList<QUrl> _r = _t->handleGetSelectedUrls((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QUrl>*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->handleSetCustomFilterData((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 36: _t->handleSetCustomFilterCallback((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 37: { bool _r = _t->handleRegisterRoutePrehandle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FileViewRoutePrehaldler>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->handleRegisterDataCache((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->handleSetAlwaysOpenInCurrentWindow((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 40: _t->handleAboutToChangeViewWidth((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 41: { bool _r = _t->handleCheckMountedDevPath((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->handleTabCreated((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 43: _t->handleTabRemoved((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 44: _t->handleTabChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ItemRoles >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDir::Filters >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ItemRoles >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< dfmbase::Global::ViewMode >(); break;
            }
            break;
        }
    }
}

const QMetaObject *dfmplugin_workspace::WorkspaceEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_workspace::WorkspaceEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19dfmplugin_workspace22WorkspaceEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_workspace::WorkspaceEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
