/****************************************************************************
** Meta object code from reading C++ file 'filemanager1adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filemanager1adaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filemanager1adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19FileManager1AdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto FileManager1Adaptor::qt_create_metaobjectdata<qt_meta_tag_ZN19FileManager1AdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileManager1Adaptor",
        "D-Bus Interface",
        "org.freedesktop.FileManager1",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.FileManager1\">\n    <method n"
        "ame=\"ShowFolders\">\n      <arg direction=\"in\" type=\"as\" name"
        "=\"URIs\"/>\n      <arg direction=\"in\" type=\"s\" name=\"Startup"
        "Id\"/>\n    </method>\n    <method name=\"ShowItemProperties\">\n "
        "     <arg direction=\"in\" type=\"as\" name=\"URIs\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"StartupId\"/>\n    </method>\n"
        "    <method name=\"ShowItems\">\n      <arg direction=\"in\" type="
        "\"as\" name=\"URIs\"/>\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"StartupId\"/>\n    </method>\n    <method name=\"Trash\">\n   "
        "   <arg direction=\"in\" type=\"as\" name=\"URIs\"/>\n    </method"
        ">\n    <method name=\"Open\">\n      <arg direction=\"in\" type=\""
        "as\" name=\"Args\"/>\n    </method>\n  </interface>\n",
        "Open",
        "",
        "Args",
        "ShowFolders",
        "URIs",
        "StartupId",
        "ShowItemProperties",
        "ShowItems",
        "Trash"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Open'
        QtMocHelpers::SlotData<void(const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'ShowFolders'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'ShowItemProperties'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'ShowItems'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'Trash'
        QtMocHelpers::SlotData<void(const QStringList &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<FileManager1Adaptor, qt_meta_tag_ZN19FileManager1AdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FileManager1Adaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FileManager1AdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FileManager1AdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19FileManager1AdaptorE_t>.metaTypes,
    nullptr
} };

void FileManager1Adaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileManager1Adaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->Open((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->ShowFolders((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->ShowItemProperties((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->ShowItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->Trash((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *FileManager1Adaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileManager1Adaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FileManager1AdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int FileManager1Adaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
