/****************************************************************************
** Meta object code from reading C++ file 'titlebareventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../dde-file-manager/src/plugins/filemanager/dfmplugin-titlebar/events/titlebareventreceiver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'titlebareventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t {};
} // unnamed namespace

template <> constexpr inline auto dfmplugin_titlebar::TitleBarEventReceiver::qt_create_metaobjectdata<qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dfmplugin_titlebar::TitleBarEventReceiver",
        "handleCustomRegister",
        "",
        "scheme",
        "QVariantMap",
        "properties",
        "handleStartSpinner",
        "windowId",
        "handleStopSpinner",
        "handleShowFilterButton",
        "visible",
        "handleViewModeChanged",
        "mode",
        "handleSetNewWindowAndTabEnable",
        "enable",
        "handleWindowForward",
        "handleWindowBackward",
        "handleRemoveHistory",
        "QUrl",
        "url",
        "handleTabAddable",
        "handleCloseTabs",
        "handleSetTabAlias",
        "name",
        "handleOpenNewTabTriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'handleCustomRegister'
        QtMocHelpers::SlotData<bool(const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Slot 'handleStartSpinner'
        QtMocHelpers::SlotData<void(quint64)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'handleStopSpinner'
        QtMocHelpers::SlotData<void(quint64)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'handleShowFilterButton'
        QtMocHelpers::SlotData<void(quint64, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'handleViewModeChanged'
        QtMocHelpers::SlotData<void(quint64, int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'handleSetNewWindowAndTabEnable'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'handleWindowForward'
        QtMocHelpers::SlotData<void(quint64)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'handleWindowBackward'
        QtMocHelpers::SlotData<void(quint64)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'handleRemoveHistory'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 18, 19 },
        }}),
        // Slot 'handleTabAddable'
        QtMocHelpers::SlotData<bool(quint64)>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::ULongLong, 7 },
        }}),
        // Slot 'handleCloseTabs'
        QtMocHelpers::SlotData<void(const QUrl &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'handleSetTabAlias'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'handleOpenNewTabTriggered'
        QtMocHelpers::SlotData<void(quint64, const QUrl &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 7 }, { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TitleBarEventReceiver, qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dfmplugin_titlebar::TitleBarEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>.metaTypes,
    nullptr
} };

void dfmplugin_titlebar::TitleBarEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TitleBarEventReceiver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->handleCustomRegister((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->handleStartSpinner((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 2: _t->handleStopSpinner((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 3: _t->handleShowFilterButton((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->handleViewModeChanged((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->handleSetNewWindowAndTabEnable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->handleWindowForward((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 7: _t->handleWindowBackward((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1]))); break;
        case 8: _t->handleRemoveHistory((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 9: { bool _r = _t->handleTabAddable((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->handleCloseTabs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 11: _t->handleSetTabAlias((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->handleOpenNewTabTriggered((*reinterpret_cast<std::add_pointer_t<quint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *dfmplugin_titlebar::TitleBarEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_titlebar::TitleBarEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18dfmplugin_titlebar21TitleBarEventReceiverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_titlebar::TitleBarEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
